# -*- coding: utf-8 -*-
#COPYRIGHT 2014 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
from arcpy.arcobjects._base import _ObjectWithoutInitCall, passthrough_attr
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
from arcpy.geoprocessing._base import gp_fixargs
from arcpy.pdfdocument import PDFDocument, PDFDocumentOpen, PDFDocumentCreate
from arcpy.utils import ArgAdaptor
from arcpy._symbology import Symbology, ColorRamp, ClassBreak, RasterClassBreak, Symbol, Item, RasterItem, ItemGroup
from arcpy._renderer import UniqueValueRenderer, SimpleRenderer, Graduated_colors_renderer, Graduated_symbols_renderer
class constants(ArgAdaptor):
    """Represents the constants that can be passed into various ExportTo* mp functions"""
    __args__ = {
        # For add position
        'add_position': {
            'AUTO_ARRANGE': 'auto_arrange',
            'BOTTOM': 'bottom',
            'TOP': 'top'
        },
        # For color mode
        'color_mode': {
            '24-BIT_TRUE_COLOR': 1,
            '8-BIT_ADAPTIVE_PALETTE': 2,
            '8-BIT_GRAYSCALE': 3,
            '32-BIT_WITH_ALPHA': 4
        },
        # For element type
        'element_type': {
            '': '',
            'GRAPHIC_ELEMENT': 'GRAPHIC_ELEMENT',
            'LEGEND_ELEMENT': 'LEGEND_ELEMENT',
            'MAPFRAME_ELEMENT': 'MAPFRAME_ELEMENT',
            'MAPSURROUND_ELEMENT': 'MAPSURROUND_ELEMENT',
            'PICTURE_ELEMENT': 'PICTURE_ELEMENT',
            'TEXT_ELEMENT': 'TEXT_ELEMENT'
        },
        # For encryption
        'encryption': {
            'RC4': 2
        },
        # For extrusion type
        'extrusion_type': {
            'ABSOLUTE_HEIGHT': 'ABSOLUTE_HEIGHT',
            'BASE_HEIGHT': 'BASE_HEIGHT',
            'MAX_HEIGHT': 'MAX_HEIGHT',
            'MIN_HEIGHT': 'MIN_HEIGHT',
            'NONE': 'NONE'
        },
        # For image compression
        'image_compression': {
            'NONE': 1,
            'RLE': 2,
            'LZW': 3,
            'DEFLATE': 4,
            'JPEG': 5,
            'ADAPTIVE': 6
        },
        # For image quality
        'image_quality': {
            'BEST': 1,
            'BETTER': 2,
            'NORMAL': 3,
            'FASTER': 4,
            'FASTEST': 5
        },
        # For insert position
        'insert_position': {
            'AFTER': 'after',
            'BEFORE': 'before'
        },
        # For jpeg color mode
        'jpeg_color_mode': {
            '24-BIT_TRUE_COLOR': 1,
            '8-BIT_GRAYSCALE': 3
        },
        # For layer property
        'layer_property': {
            'BRIGHTNESS': 'brightness',
            'CONTRAST': 'contrast',
            'DATASOURCE': 'dataSource',
            'DEFINITIONQUERY': 'definitionQuery',
            'LONGNAME': 'longName',
            'MAXTHRESHOLD': 'maxThreshold',
            'MINTHRESHOLD': 'minThreshold',
            'NAME': 'name',
            'TRANSPARENCY': 'transparency',
            'VISIBLE': 'visible'
        },
        # For layers attributes
        'layers_attributes': {
            'NONE': 1,
            'LAYERS_ONLY': 2,
            'LAYERS_AND_ATTRIBUTES': 3
        },
        # For method
        'method': {
            'DIFFERENCE': 'DIFFERENCE',
            'INTERSECT': 'INTERSECT',
            'NEW': 'NEW',
            'SYMDIFFERENCE': 'SYMDIFFERENCE',
            'UNION': 'UNION'
        },
        # For pdf layout
        'pdf_layout': {
            'DONT_CARE': 0,
            'SINGLE_PAGE': 1,
            'ONE_COLUMN': 2,
            'TWO_COLUMN_LEFT': 3,
            'TWO_COLUMN_RIGHT': 4,
            'TWO_PAGE_LEFT': 5,
            'TWO_PAGE_RIGHT': 6
        },
        # For pdf open view
        'pdf_open_view': {
            'VIEWER_DEFAULT': 0,
            'USE_NONE': 1,
            'USE_THUMBS': 2,
            'USE_BOOKMARKS': 3,
            'FULL_SCREEN': 4,
            'LAYERS': 5,
            'ATTACHMENT': 6
        },
        # For permissions
        'permissions': {
            'ALL': -268435457,
            'OPEN': 1,
            'SECURE': 2,
            'PRINT': 4,
            'EDIT': 8,
            'COPY': 16,
            'EDIT_NOTES': 32,
            'FILL_AND_SIGN': 256,
            'DOC_ASSEMBLY': 1024,
            'HIGH_PRINT': 2052,
            'ALL_MASTER': 2104
        },
        # For server type
        'server_type': {
            'MY_HOSTED_SERVICES': 'MY_HOSTED_SERVICES'
        },
        # For service type
        'service_type': {
            'FEATURE_ACCESS': 'FEATURE_ACCESS',
            'TILED': 'TILED'
        },
        # For tiff compression
        'tiff_compression': {
            'NONE': 1,
            'JPEG': 2,
            'PACK_BITS': 3,
            'LZW': 4,
            'DEFLATE': 5
        }}
class ArcGISProject(_ObjectWithoutInitCall):
    """ArcGISProject(aprx_path)

       Provides a reference to an ArcGIS project ( .aprx ) stored on disk or to
       the project currently loaded within the ArcGIS Pro application using the
       CURRENT keyword.

         aprx_path(String):
       A string that includes the full system path and file name of an existing
       ArcGIS project ( .aprx ) or a string that contains the CURRENT keyword."""
    dateSaved = passthrough_attr('dateSaved')
    defaultGeodatabase = passthrough_attr('defaultGeodatabase')
    defaultToolbox = passthrough_attr('defaultToolbox')
    filePath = passthrough_attr('filePath')
    activeMap = passthrough_attr('activeMap')
    homeFolder = passthrough_attr('homeFolder')
    documentVersion = passthrough_attr('version')
    def importDocument(self, document_path, include_layout=True):
        """ArcGISProject.importDocument(document_path, {include_layout})

           Imports map ( .mxd ), globe ( .3dd ) and scene ( .sxd ) documents
           into an ArcGIS Pro project.

             document_path(String):
           A string that includes the system path and name of a ( .mxd , .3dd ,
           or .sxd ) document  to import.

             include_layout{Boolean}:
           A Boolean indicating if the layout from a map document ( .mxd ) is
           imported.  If  set to True , the layout and all data frames are
           imported. If set to False , only the data frames are imported.  This
           parameter is ignored for globe ( .3dd ) and scene ( .sxd ) documents."""
        return convertArcObjectToPythonObject(self._arc_object.importDocument(*gp_fixargs((document_path, include_layout), True)))

    def listBrokenDataSources(self):
        """ArcGISProject.listBrokenDataSources()

           Returns a Python list of Layer and/or Table objects that have broken
           connections to their original source data for all maps in a project."""
        return convertArcObjectToPythonObject(self._arc_object.listBrokenDataSources(*gp_fixargs((), True)))

    def listLayouts(self, wildcard=None):
        """ArcGISProject.listLayouts({wildcard})

           Returns a Python list of Layout objects in an ArcGIS project ( .aprx
           ).

             wildcard{String}:
           A wildcard is based on the layout name and is not case sensitive.  A
           combination of asterisks (*) and characters can be used to help
           limit the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listLayouts(*gp_fixargs((wildcard,), True)))

    def listMaps(self, wildcard=None):
        """ArcGISProject.listMaps({wildcard})

           Returns a Python list of Map objects in an ArcGIS project ( .aprx ).

             wildcard{String}:
           A wildcard is based on the map name and is not case sensitive. A
           combination of asterisks (*) and characters can be used to help
           limit the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listMaps(*gp_fixargs((wildcard,), True)))

    def save(self):
        """ArcGISProject.save()

           Saves changes to an ArcGISProject ( .aprx )."""
        return convertArcObjectToPythonObject(self._arc_object.save(*gp_fixargs((), True)))

    def saveACopy(self, file_name):
        """ArcGISProject.saveACopy(file_name)

           Saves an ArcGISProject ( .aprx ) to a new file path or name.

             file_name(String):
           A string used to save an ArcGISProject ( .aprx ) to a new file path
           or file name."""
        return convertArcObjectToPythonObject(self._arc_object.saveACopy(*gp_fixargs((file_name,), True)))

    def updateConnectionProperties(self, current_connection_info, new_connection_info, auto_update_joins_and_relates=True, validate=True):
        """ArcGISProject.updateConnectionProperties(current_connection_info,
           new_connection_info, {auto_update_joins_and_relates}, {validate})

           Replaces connection properties using a dictionary or a path to a
           workspace.

             current_connection_info(String):
           A string that represents the workspace path or a Python dictionary
           that contains connection properties to the source you want to update.

             new_connection_info(String):
           A string that represents the workspace path or a Python dictionary
           that contains connection properties with the new source information.

             auto_update_joins_and_relates{Boolean}:
           If  set to True , the updateConnectionProperties method will also
           update the connections for associated joins or relates.

             validate{Boolean}:
           If  set to True , the connection properties will only be updated if
           the new_connection_info value is a valid connection.  If it is not
           valid, the connection will not be replaced.   If set to False , the
           method will set all connections to match the new_connection_info ,
           regardless of a valid match.  In this case, if a match does not
           exist, then the data sources would be broken."""
        return convertArcObjectToPythonObject(self._arc_object.updateConnectionProperties(*gp_fixargs((current_connection_info, new_connection_info, auto_update_joins_and_relates, validate), True)))

    def listColorRamps(self, wildcard=None):
        return convertArcObjectToPythonObject(self._arc_object.listColorRamps(*gp_fixargs((wildcard,), True)))

    def __init__(self, aprx_path):
        """ArcGISProject(aprx_path)

           Provides a reference to an ArcGIS project ( .aprx ) stored on disk or to the project currently loaded within the ArcGIS Pro application using the CURRENT keyword.

             aprx_path(String):
           A string that includes the full system path and file name of an existing ArcGIS project ( .aprx ) or a string that contains the CURRENT keyword."""
        import arcgisscripting
        self._arc_object = arcgisscripting._mapping.ArcGISProject(*gp_fixargs((aprx_path,), True))

class Bookmark(_ObjectWithoutInitCall):
    """Provides access to bookmark methods and properties."""
    hasThumbnail = passthrough_attr('hasThumbnail')
    map = passthrough_attr('map')
    name = passthrough_attr('name')
    def updateThumbnail(self):
        """Bookmark.updateThumbnail()

           Updates a bookmark's thumbnail image."""
        return convertArcObjectToPythonObject(self._arc_object.updateThumbnail(*gp_fixargs((), True)))

class Camera(_ObjectWithoutInitCall):
    """The Camera object provides access to  2D and 3D viewer properties that
       control the display in a MapFrame ."""
    heading = passthrough_attr('heading')
    mode = passthrough_attr('mode')
    pitch = passthrough_attr('pitch')
    roll = passthrough_attr('roll')
    scale = passthrough_attr('scale')
    X = passthrough_attr('X')
    Y = passthrough_attr('Y')
    Z = passthrough_attr('Z')
    def getExtent(self):
        """Camera.getExtent()

           Returns an Extent object for a 2D map frame."""
        return convertArcObjectToPythonObject(self._arc_object.getExtent(*gp_fixargs((), True)))

    def setExtent(self, extent):
        """Camera.setExtent(extent)

           Sets the Extent for a map frame in a layout.

             extent(Extent):
           A geoprocessing Extent object."""
        return convertArcObjectToPythonObject(self._arc_object.setExtent(*gp_fixargs((extent,), True)))

class GraphicElement(_ObjectWithoutInitCall):
    """The GraphicElement object provides access to properties that enables its
       repositioning on the page layout, as well as methods that allow for
       duplicating and deleting existing graphic elements."""
    elementHeight = passthrough_attr('elementHeight')
    elementPositionX = passthrough_attr('elementPositionX')
    elementPositionY = passthrough_attr('elementPositionY')
    elementRotation = passthrough_attr('elementRotation')
    elementWidth = passthrough_attr('elementWidth')
    isGroup = passthrough_attr('isGroup')
    name = passthrough_attr('name')
    type = passthrough_attr('type')
    visible = passthrough_attr('visible')
    def clone(self, suffix=None):
        """GraphicElement.clone({suffix})

           Provides a mechanism to clone an existing graphic element on a page
           layout.

             suffix{String}:
           An optional string that is used to tag each newly created graphic
           element.  The new element will get the same element name as the
           parent graphic plus the suffix value along with  a numeric sequencer.
           For example, if the parent element name is Line and the suffix value
           is _copy , the newly cloned elements are named Line_copy ,
           Line_copy_1 , Line_copy_2 , and so on.  If a suffix is not provided,
           the results resemble Line_1 , Line_2 , Line_3 , and so on."""
        return convertArcObjectToPythonObject(self._arc_object.clone(*gp_fixargs((suffix,), True)))

    def delete(self):
        """GraphicElement.delete()

           Provides a mechanism to delete an existing graphic element on a page
           layout."""
        return convertArcObjectToPythonObject(self._arc_object.delete(*gp_fixargs((), True)))

class LabelClass(_ObjectWithoutInitCall):
    """Provides access to a layer's label class properties."""
    expression = passthrough_attr('expression')
    name = passthrough_attr('name')
    SQLQuery = passthrough_attr('SQLQuery')
    visible = passthrough_attr('visible')
class Layer(_ObjectWithoutInitCall):
    """Layer(lyr_file_path)

       References a layer file stored on disk.

         lyr_file_path(String):
       A string that includes the full path and file name of an existing layer
       file.  The supported extensions are .lyr or .lyrx ."""
    brightness = passthrough_attr('brightness')
    contrast = passthrough_attr('contrast')
    connectionProperties = passthrough_attr('connectionProperties', True)
    dataSource = passthrough_attr('dataSource', True)
    definitionQuery = passthrough_attr('definitionQuery')
    is3DLayer = passthrough_attr('is3DLayer')
    isBroken = passthrough_attr('isBroken')
    isFeatureLayer = passthrough_attr('isFeatureLayer')
    isBasemapLayer = passthrough_attr('isBasemapLayer')
    isGroupLayer = passthrough_attr('isGroupLayer')
    isNetworkAnalystLayer = passthrough_attr('isNetworkAnalystLayer')
    isNetworkDatasetLayer = passthrough_attr('isNetworkDatasetLayer')
    isRasterLayer = passthrough_attr('isRasterLayer')
    isWebLayer = passthrough_attr('isWebLayer')
    longName = passthrough_attr('longName')
    maxThreshold = passthrough_attr('maxThreshold')
    minThreshold = passthrough_attr('minThreshold')
    name = passthrough_attr('name')
    showLabels = passthrough_attr('showLabels')
    transparency = passthrough_attr('transparency')
    visible = passthrough_attr('visible')
    symbology = passthrough_attr('symbology')
    @constants.maskargs
    def extrusion(self, extrusion_type='NONE', expression=None):
        """Layer.extrusion({extrusion_type}, {expression})

           Extrudes 2D features in a layer to display 3D symbology.

             extrusion_type{String}:
           A string that specifies the extrusion method.  The default value is
           NONE which turns off layer extrusion.

            * ABSOLUTE_HEIGHT: The feature is extruded to the specified z-value,
            as a flat top, regardless of the z-values of the feature.

            * BASE_HEIGHT: A z-value is calculated for each vertex of the
            feature's base, and the feature is extruded to the various z-values
            creating a multifaceted top.

            * MAX_HEIGHT: Adds extrusion height to the minimum z-value of the
            feature, and the feature is extruded to a flat top at that value.

            * MIN_HEIGHT: Adds extrusion height to the minimum z-value of the
            feature, and the feature is extruded to a flat top at that value.

            * NONE: Features are not extruded.

             expression{String}:
           A string that defines the extrusion expression, which provides an
           absolute extrusion height  for each feature."""
        return convertArcObjectToPythonObject(self._arc_object.extrusion(*gp_fixargs((extrusion_type, expression), True)))

    def getSelectionSet(self):
        """Layer.getSelectionSet()

           Returns a layer's selection as a Python set of object IDs."""
        return convertArcObjectToPythonObject(self._arc_object.getSelectionSet(*gp_fixargs((), True)))

    def listLabelClasses(self, wildcard=None):
        """Layer.listLabelClasses({wildcard})

           Returns a Python list of LabelClass objects in a layer.

             wildcard{String}:
           A wildcard is based on the label class name and is not case
           sensitive. A combination of asterisks (*) and characters can be used
           to help
           limit the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listLabelClasses(*gp_fixargs((wildcard,), True)))

    def listLayers(self, wildcard=None):
        """Layer.listLayers({wildcard})

           Returns a Python list of Layer objects in a layer file.

             wildcard{String}:
           A wildcard is based on the layer name and is not case sensitive. A
           combination of asterisks (*) and characters can be used to help
           limit the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listLayers(*gp_fixargs((wildcard,), True)))

    def saveACopy(self, file_name):
        """Layer.saveACopy(file_name)

           Saves a layer to a layer file ( .lyrx ).

             file_name(String):
           A string that includes the location and name of the output layer file
           ( .lyrx )."""
        return convertArcObjectToPythonObject(self._arc_object.saveACopy(*gp_fixargs((file_name,), True)))

    @constants.maskargs
    def setSelectionSet(self, oidList=None, method='NEW'):
        """Layer.setSelectionSet({oidList}, {method})

           Sets a layer's selection using a Python set of Object IDs.

             oidList{Integer}:
           A Python set of Object IDs to use along with the appropriate
           selection method.

             method{String}:
           A string that specifies which selection method to use.

            * NEW: Creates a new feature selection from the oidList .

            * DIFFERENCE: Selects the features that are not in the current
            selection but are in the oidList .

            * INTERSECT: Selects the features that are in the current selection
            and the oidList .

            * SYMDIFFERENCE: Selects the features that are in the current
            selection or the oidList but not both.

            * UNION: Selects all the features in both the current selection and
            those in the oidList ."""
        return convertArcObjectToPythonObject(self._arc_object.setSelectionSet(*gp_fixargs((oidList, method), True)))

    def supports(self, layer_property):
        """Layer.supports(layer_property)

           Used to determine if a particular layer type supports a property on
           the layer object.  Not all layers support the same set of properties;
           the supports property can be used to test if a layer supports that
           property before attempting to set it.

             layer_property(String):
           The name of a particular layer property that will be tested.

            * BRIGHTNESS:   A raster layer's brightness value.

            * CONNECTIONPROPERTIES: A Layer's connection information.

            * CONTRAST:   A raster layer's contrast value

            * CREDITS:   A layer's credit information.

            * DATASOURCE:   A layer's file path or connection file.

            * DEFINITIONQUERY:   A layer's definition query string.

            * LONGNAME:   A layer's path including the group layers it may be
            nested within.

            * MAXTHRESHOLD:   A layer's maximum threshold to display the
            features.

            * MINTHRESHOLD:   A layer's minimum threshold to display the
            features.

            * NAME:   A layer's name.

            * TRANSPARENCY:   A layer's transparency value."""
        return convertArcObjectToPythonObject(self._arc_object.supports(*gp_fixargs((layer_property,), True)))

    def updateConnectionProperties(self, current_connection_info, new_connection_info, auto_update_joins_and_relates=True, validate=True):
        """Layer.updateConnectionProperties(current_connection_info,
           new_connection_info, {auto_update_joins_and_relates}, {validate})

           Replaces connection properties using a dictionary or a path to a
           workspace.

             current_connection_info(String):
           A string that represents the workspace path or a Python dictionary
           that contains connection properties to the source you want to update.

             new_connection_info(String):
           A string that represents the workspace path or a Python dictionary
           that contains connection properties with the new source information.

             auto_update_joins_and_relates{Boolean}:
           If  set to True , the updateConnectionProperties method will also
           update the connections for associated joins or relates.

             validate{Boolean}:
           If  set to True , the connection properties will only be updated if
           the new_connection_info value is a valid connection.  If it is not
           valid, the connection will not be replaced.   If set to False , the
           method will set all connections to match the new_connection_info ,
           regardless of a valid match.  In this case, if a match does not
           exist, then the data sources would be broken."""
        return convertArcObjectToPythonObject(self._arc_object.updateConnectionProperties(*gp_fixargs((current_connection_info, new_connection_info, auto_update_joins_and_relates, validate), True)))

    def updateLayerFromJSON(self, json_data):
        """
        Layer.updateLayerFromJSON(json_data)

        """
        return convertArcObjectToPythonObject(self._arc_object.updateLayerFromJSON(*gp_fixargs((json_data,), True)))


    def __str__(self):
        return self.longName

class LayerFile(_ObjectWithoutInitCall):
    """LayerFile(layer_file_path)

       References a layer file ( .lyr or .lyrx ) stored on disk.

         layer_file_path(String):
       A string that includes the full system path and file name of an existing
       layer file."""
    filePath = passthrough_attr('filePath')
    version = passthrough_attr('version')
    @constants.maskargs
    def addLayer(self, add_layer_or_layerfile, add_position='AUTO_ARRANGE'):
        """LayerFile.addLayer(add_layer_or_layerfile, {add_position})

           Provides the ability to add a Layer or LayerFile to a map within a
           project ( .aprx ) using basic placement options.

             add_layer_or_layerfile(Layer):
           A reference to a Layer or LayerFile object representing the layer or
           layers  to be added.

             add_position{String}:
           A constant that determines the placement of the added layer or layers
           in a map.

            * AUTO_ARRANGE: Automatically places the layer or layers based on
            its layer weight rules and geometry.

            * BOTTOM: Places the layer or layers at the bottom of the TOC layer
            stack.

            * TOP: Places the layer or layers at the top of the TOC layer stack."""
        return convertArcObjectToPythonObject(self._arc_object.addLayer(*gp_fixargs((add_layer_or_layerfile, add_position), True)))

    @constants.maskargs
    def addLayerToGroup(self, target_group_layer, add_layer_or_layerfile, add_position='AUTO_ARRANGE'):
        """LayerFile.addLayerToGroup(target_group_layer, add_layer_or_layerfile,
           {add_position})

           Provides the ability to add a Layer or the contents of a LayerFile to
           an existing group layer in a map within a project ( .aprx ) using
           basic placement options.

             target_group_layer(Layer):
           A reference to an existing group Layer object.

             add_layer_or_layerfile(Layer):
           A reference to a Layer or LayerFile object representing the layer or
           layers  to be added.

             add_position{String}:
           A constant that determines the placement of the added layer or layers
           in the target_group_layer .

            * AUTO_ARRANGE: Automatically places the layer based on its layer
            weight rules and geometry.

            * BOTTOM: Places the layer at the bottom of the TOC layer stack.

            * TOP: Places the layer at the top of the TOC layer stack."""
        return convertArcObjectToPythonObject(self._arc_object.addLayerToGroup(*gp_fixargs((target_group_layer, add_layer_or_layerfile, add_position), True)))

    @constants.maskargs
    def insertLayer(self, reference_layer, insert_layer_or_layerfile, insert_position='BEFORE'):
        """LayerFile.insertLayer(reference_layer, insert_layer_or_layerfile,
           {insert_position})

           Provides the ability to add a Layer or LayerFile to a map within a
           project ( .aprx ) by specifying  a specific location.

             reference_layer(Layer):
           A Layer object representing an existing layer that determines the
           location where the new layer will be inserted.

             insert_layer_or_layerfile(Layer):
           A reference to a Layer or LayerFile object representing the layer or
           layers  to be added.

             insert_position{String}:
           A constant that determines the placement of the added layer or layers
           relative to the reference_layer .

            * AFTER: Inserts the new layer after or below the reference layer.

            * BEFORE: Inserts the new layer before or above the reference layer."""
        return convertArcObjectToPythonObject(self._arc_object.insertLayer(*gp_fixargs((reference_layer, insert_layer_or_layerfile, insert_position), True)))

    def listBrokenDataSources(self):
        """LayerFile.listBrokenDataSources()

           Returns a Python list of Layer objects in a layer file that have
           broken connections to their original source data."""
        return convertArcObjectToPythonObject(self._arc_object.listBrokenDataSources(*gp_fixargs((), True)))

    def listLayers(self, wildcard=None):
        """LayerFile.listLayers({wildcard})

           Returns a Python list of Layer objects in a layer file.

             wildcard{String}:
           A wildcard is based on the layer name and is not case sensitive. A
           combination of asterisks (*) and characters can be used to help
           limit the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listLayers(*gp_fixargs((wildcard,), True)))

    @constants.maskargs
    def moveLayer(self, reference_layer, move_layer, insert_position='BEFORE'):
        """LayerFile.moveLayer(reference_layer, move_layer, {insert_position})

           Provides the ability to move a layer or group layer in a map to  a
           specific location in the layer stack.

             reference_layer(Layer):
           A Layer object representing an existing layer that determines the
           location where the new layer will be moved.

             move_layer(Layer):
           A reference to a Layer object representing the layer to be moved.

             insert_position{String}:
           A constant that determines the placement of the moved layer relative
           to the reference layer.

            * AFTER: Moves the  layer after or below the reference layer.

            * BEFORE: Moves the layer before or above the reference layer."""
        return convertArcObjectToPythonObject(self._arc_object.moveLayer(*gp_fixargs((reference_layer, move_layer, insert_position), True)))

    def removeLayer(self, remove_layer):
        """LayerFile.removeLayer(remove_layer)

           Provides the ability to remove a layer from a map in a project.

             remove_layer(Layer):
           A reference to a Layer object representing the layer to be removed."""
        return convertArcObjectToPythonObject(self._arc_object.removeLayer(*gp_fixargs((remove_layer,), True)))

    def save(self):
        """LayerFile.save()

           Saves an existing layer file reference to a .lyrx file, even if the
           file referenced was a .lyr file."""
        return convertArcObjectToPythonObject(self._arc_object.save(*gp_fixargs((), True)))

    def saveACopy(self, file_name):
        """LayerFile.saveACopy(file_name)

           Saves a LayerFile to a new path or file name.

             file_name(String):
           A string used to save a LayerFile to a new path or file name.  You
           can only save to .lyrx files."""
        return convertArcObjectToPythonObject(self._arc_object.saveACopy(*gp_fixargs((file_name,), True)))

    def updateConnectionProperties(self, current_connection_info, new_connection_info, auto_update_joins_and_relates=True, validate=True):
        """LayerFile.updateConnectionProperties(current_connection_info,
           new_connection_info, {auto_update_joins_and_relates}, {validate})

           Replaces connection properties using a dictionary or a path to a
           workspace.

             current_connection_info(String):
           A string that represents the workspace path or a Python dictionary
           that contains connection properties to the source you want to update.

             new_connection_info(String):
           A string that represents the workspace path or a Python dictionary
           that contains connection properties with the new source information.

             auto_update_joins_and_relates{Boolean}:
           If  set to True , the updateConnectionProperties method will also
           update the connections for associated joins or relates.

             validate{Boolean}:
           If  set to True , the connection properties will only be updated if
           the new_connection_info value is a valid connection.  If it is not
           valid, the connection will not be replaced.   If set to False , the
           method will set all connections to match the new_connection_info ,
           regardless of a valid match.  In this case, if a match does not
           exist, then the data sources would be broken."""
        return convertArcObjectToPythonObject(self._arc_object.updateConnectionProperties(*gp_fixargs((current_connection_info, new_connection_info, auto_update_joins_and_relates, validate), True)))

    def __init__(self, layer_file_path):
        """LayerFile(layer_file_path)

           References a layer file ( .lyr or .lyrx ) stored on disk.

             layer_file_path(String):
           A string that includes the full system path and file name of an existing layer file."""
        import arcgisscripting
        self._arc_object = arcgisscripting._mapping.LayerFile(*gp_fixargs((layer_file_path,), True))

    def __str__(self):
        return self.filePath

class Layout(_ObjectWithoutInitCall):
    """The Layout object references a single-page layout in an ArcGIS Pro
       project ( .aprx ).  It provides access to common properties like page
       size and a number of different export methods."""
    name = passthrough_attr('name')
    pageHeight = passthrough_attr('pageHeight')
    pageUnits = passthrough_attr('pageUnits')
    pageWidth = passthrough_attr('pageWidth')
    mapSeries = passthrough_attr('mapSeries')
    def exportToBMP(self, out_bmp, resolution=96):
        """Layout.exportToBMP(out_bmp, {resolution})

           Exports the page layout to the Microsoft Windows Bitmap format (BMP).

             out_bmp(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi)."""
        return convertArcObjectToPythonObject(self._arc_object.exportToBMP(*gp_fixargs((out_bmp, resolution), True)))

    def exportToEMF(self, out_emf, resolution=96):
        """Layout.exportToEMF(out_emf, {resolution})

           Exports the page layout to the Enhanced Metafile (EMF) format.

             out_emf(String):
           A string that represents the system path and file name for the output
           export file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi)."""
        return convertArcObjectToPythonObject(self._arc_object.exportToEMF(*gp_fixargs((out_emf, resolution), True)))

    def exportToEPS(self, out_eps, resolution=96):
        """Layout.exportToEPS(out_eps, {resolution})

           Exports the page layout to an Encapsulated PostScript (EPS) format.

             out_eps(String):
           A string that represents the system path and file name for the output
           export file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi)."""
        return convertArcObjectToPythonObject(self._arc_object.exportToEPS(*gp_fixargs((out_eps, resolution), True)))

    def exportToGIF(self, out_gif, resolution=96):
        """Layout.exportToGIF(out_gif, {resolution})

           Exports the page layout to the Graphic Interchange format (GIF).

             out_gif(String):
           A string that represents the system path and file name for the output
           export file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi)."""
        return convertArcObjectToPythonObject(self._arc_object.exportToGIF(*gp_fixargs((out_gif, resolution), True)))

    def exportToJPEG(self, out_jpg, resolution=96, jpeg_color_mode='24-BIT_TRUE_COLOR', jpeg_quality=80):
        """Layout.exportToJPEG(out_jpg, {resolution}, {jpeg_color_mode},
           {jpeg_quality})

           Exports the page layout to the Joint Photographic Experts Group
           format (JPEG) .

             out_jpg(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             jpeg_color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

             jpeg_quality{Integer}:
           This value (0–100) controls the amount of compression applied to the
           output image. For JPEG, image quality is adversely affected the more
           compression is applied. A higher quality (highest = 100) setting will
           produce sharper images and larger file sizes. A lower quality setting
           will produce more image artifacts and smaller files."""
        return convertArcObjectToPythonObject(self._arc_object.exportToJPEG(*gp_fixargs((out_jpg, resolution, False, jpeg_color_mode, jpeg_quality), True)))

    @constants.maskargs
    def exportToPDF(self, out_pdf, resolution=96, image_quality='BEST', compress_vector_graphics=True, image_compression='ADAPTIVE', embed_fonts=True, layers_attributes='LAYERS_ONLY', georef_info=True, jpeg_compression_quality=80, clip_to_elements=False):
        """Layout.exportToPDF(out_pdf, {resolution}, {image_quality},
           {compress_vector_graphics}, {image_compression}, {embed_fonts},
           {layers_attributes}, {georef_info}, {jpeg_compression_quality},
           clip_to_elements)

           Exports the page layout  to the Portable Document Format (PDF).

             out_pdf(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (DPI).

             image_quality{String}:
           A string that defines output image quality, the draw resolution of
           map layers that draw as rasters.

            * BEST:  An output image quality resample ratio of 1.

            * BETTER:  An output image quality resample ratio of 2.

            * NORMAL:  An output image quality resample ratio of 3.

            * FASTER:  An output image quality resample ratio of 4.

            * FASTEST:  An output image quality resample ratio of 5.

             compress_vector_graphics{Boolean}:
           A Boolean that controls compression of vector and text portions of
           the output file. Image compression is defined separately.

             image_compression{String}:
           A string that defines the compression scheme used to compress image
           or raster data in the output file.

            * ADAPTIVE:   Automatically selects the best compression type for
            each image on the page.   JPEG will be used for large images with
            many unique colors.  DEFLATE will be used for all other images.

            * DEFLATE:   A lossless data compression.

            * JPEG:   A lossy data compression.

            * LZW:   Lempel-Ziv-Welch, a lossless data compression.

            * NONE:   Compression is not applied.

            * RLE:   Run-length encoded compression.

             embed_fonts{Boolean}:
           A Boolean that controls the embedding of fonts in the export file.
           Font embedding allows text and character markers to be displayed
           correctly when the document is viewed on a computer that does not
           have the necessary fonts installed.

             layers_attributes{String}:
           A string that controls inclusion of PDF layer and PDF object data
           (attributes) in the export file.

            * LAYERS_ONLY:  Export PDF layers only

            * LAYERS_AND_ATTRIBUTES:  Export PDF layers and feature attributes

            * NONE:  None

             georef_info{Boolean}:
           A Boolean that enables the export of coordinate system information
           for each data frame into the output PDF file.

             jpeg_compression_quality{Integer}:
           A number that controls compression quality value when
           image_compression is set to ADAPTIVE or JPEG . The valid range is 1
           to 100.    A jpeg_compression_quality of 100 provides the best-
           quality images but creates large export files.   The recommended
           range is between 70 and 90.

             clip_to_elements(Boolean):
           If set to True , the layout is clipped to the smallest bounding box
           that includes all layout elements."""
        return convertArcObjectToPythonObject(self._arc_object.exportToPDF(*gp_fixargs((out_pdf, resolution, image_quality, compress_vector_graphics, image_compression, embed_fonts, layers_attributes, georef_info, jpeg_compression_quality, clip_to_elements), True)))

    def exportToPNG(self, out_png, resolution=96, color_mode='24-BIT_TRUE_COLOR'):
        """Layout.exportToPNG(out_png, {resolution}, {color_mode})

           Exports the page layout to the Portable Network Graphics format
           (PNG).

             out_png(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

            * 32-BIT_WITH_ALPHA:   32-bit with alpha"""
        return convertArcObjectToPythonObject(self._arc_object.exportToPNG(*gp_fixargs((out_png, resolution, False, color_mode), True)))

    def exportToSVG(self, out_svg, resolution=96, compress_to_svgz=False):
        """Layout.exportToSVG(out_svg, {resolution}, {compress_to_svgz})

           Exports the page layout to the Scalable Vector Graphics format (SVG).

             out_svg(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             compress_to_svgz{Boolean}:
           If set to True , the output is compressed."""
        return convertArcObjectToPythonObject(self._arc_object.exportToSVG(*gp_fixargs((out_svg, resolution, compress_to_svgz), True)))

    def exportToTGA(self, out_tga, resolution=96):
        """Layout.exportToTGA(out_tga, {resolution})

           Exports the page layout to the Truevision Graphics Adapter format
           (TGA).

             out_tga(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi)."""
        return convertArcObjectToPythonObject(self._arc_object.exportToTGA(*gp_fixargs((out_tga, resolution), True)))

    def exportToTIFF(self, out_tif, resolution=96, color_mode='24-BIT_TRUE_COLOR', tiff_compression='LZW'):
        """Layout.exportToTIFF(out_tif, {resolution}, {color_mode},
           {tiff_compression})

           Exports the page layout to the Tagged Image File Format (TIFF).

             out_tif(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

            * 32-BIT_WITH_ALPHA:   32-bit with alpha

             tiff_compression{String}:
           This value represents a compression scheme.

            * DEFLATE:   A lossless data compression.

            * JPEG: JPEG compression.

            * LZW:   Lempel-Ziv-Welch, a lossless data compression.

            * NONE:   Compression is not applied.

            * PACK_BITS:   Pack bits compression."""
        return convertArcObjectToPythonObject(self._arc_object.exportToTIFF(*gp_fixargs((out_tif, resolution, False, color_mode, tiff_compression, False), True)))

    @constants.maskargs
    def listElements(self, element_type=None, wildcard=None):
        """Layout.listElements({element_type}, {wildcard})

           Returns a Python list of page layout elements  that exist on  a
           Layout object.

             element_type{String}:
           A string that represents the element type that will be used to filter
           the returned list of elements.

            * GRAPHIC_ELEMENT:   Filter for GraphicElement objects.

            * LEGEND_ELEMENT:   Filter for LegendElement objects.

            * MAPFRAME_ELEMENT: Filter for MapFrame objects.

            * MAPSURROUND_ELEMENT:   Filter for MapsurroundElement objects.

            * PICTURE_ELEMENT:   Filter for PictureElement objects.

            * TEXT_ELEMENT:   Filter for TextElement objects.

             wildcard{String}:
           A wildcard is based on the element name and is not case sensitive.  A
           combination of asterisks (*) and characters can be used to help limit
           the results."""
        return convertArcObjectToPythonObject(self._arc_object.listElements(*gp_fixargs((element_type, wildcard), True)))

class LegendElement(_ObjectWithoutInitCall):
    """The LegendElement object provides access to properties  that enable its
       positioning and resizing on the page layout as well as modifying its
       title."""
    elementHeight = passthrough_attr('elementHeight')
    elementPositionX = passthrough_attr('elementPositionX')
    elementPositionY = passthrough_attr('elementPositionY')
    elementWidth = passthrough_attr('elementWidth')
    name = passthrough_attr('name')
    mapFrame = passthrough_attr('mapFrame')
    title = passthrough_attr('title')
    type = passthrough_attr('type')
    visible = passthrough_attr('visible')
    elementRotation = passthrough_attr('elementRotation')
    showTitle = passthrough_attr('showTitle')
    syncNewLayer = passthrough_attr('syncNewLayer')
    syncLayerOrder = passthrough_attr('syncLayerOrder')
    syncLayerVisibility = passthrough_attr('syncLayerVisibility')
    syncReferenceScale = passthrough_attr('syncReferenceScale')

class Map(_ObjectWithoutInitCall):
    """The Map is the primary object for referencing and managing layers and
       tables within an ArcGIS Pro project."""
    defaultCamera = passthrough_attr('defaultCamera')
    defaultView = passthrough_attr('defaultView', True)
    mapType = passthrough_attr('mapType')
    name = passthrough_attr('name')
    referenceScale = passthrough_attr('referenceScale')
    mapUnits = passthrough_attr('mapUnits')
    @constants.maskargs
    def addLayer(self, add_layer_or_layerfile, add_position='AUTO_ARRANGE'):
        """Map.addLayer(add_layer_or_layerfile, {add_position})

           Provides the ability to add a Layer or LayerFile to a map within a
           project ( .aprx ) using basic placement options.

             add_layer_or_layerfile(Layer):
           A reference to a Layer or LayerFile object representing the layer or
           layers  to be added.

             add_position{String}:
           A constant that determines the placement of the added layer or layers
           in a map.

            * AUTO_ARRANGE: Automatically places the layer or layers based on
            its layer weight rules and geometry.

            * BOTTOM: Places the layer or layers at the bottom of the TOC layer
            stack.

            * TOP: Places the layer or layers at the top of the TOC layer stack."""
        return convertArcObjectToPythonObject(self._arc_object.addLayer(*gp_fixargs((add_layer_or_layerfile, add_position), True)))

    @constants.maskargs
    def addLayerToGroup(self, target_group_layer, add_layer_or_layerfile, add_position='AUTO_ARRANGE'):
        """Map.addLayerToGroup(target_group_layer, add_layer_or_layerfile,
           {add_position})

           Provides the ability to add a Layer or the contents of a LayerFile to
           an existing group layer in a map within a project ( .aprx ) using
           basic placement options.

             target_group_layer(Layer):
           A reference to an existing group Layer object.

             add_layer_or_layerfile(Layer):
           A reference to a Layer or LayerFile object representing the layer or
           layers  to be added.

             add_position{String}:
           A constant that determines the placement of the added layer or layers
           in the target_group_layer .

            * AUTO_ARRANGE: Automatically places the layer based on its layer
            weight rules and geometry.

            * BOTTOM: Places the layer at the bottom of the TOC layer stack.

            * TOP: Places the layer at the top of the TOC layer stack."""
        return convertArcObjectToPythonObject(self._arc_object.addLayerToGroup(*gp_fixargs((target_group_layer, add_layer_or_layerfile, add_position), True)))

    def addTable(self, add_table):
        """Map.addTable(add_table)

           Provides the ability to add a Table to a map within a project ( .aprx
           ).

             add_table(Table):
           A reference to a Table object representing the table  to be added."""
        return convertArcObjectToPythonObject(self._arc_object.addTable(*gp_fixargs((add_table,), True)))

    def clearSelection(self):
        """Map.clearSelection()

           Clears the selection for all layers and tables in a map."""
        return convertArcObjectToPythonObject(self._arc_object.clearSelection(*gp_fixargs((), True)))

    @constants.maskargs
    def insertLayer(self, reference_layer, insert_layer_or_layerfile, insert_position='BEFORE'):
        """Map.insertLayer(reference_layer, insert_layer_or_layerfile,
           {insert_position})

           Provides the ability to add a Layer or LayerFile to a map within a
           project ( .aprx ) by specifying  a specific location.

             reference_layer(Layer):
           A Layer object representing an existing layer that determines the
           location where the new layer will be inserted.

             insert_layer_or_layerfile(Layer):
           A reference to a Layer or LayerFile object representing the layer or
           layers  to be added.

             insert_position{String}:
           A constant that determines the placement of the added layer or layers
           relative to the reference_layer .

            * AFTER: Inserts the new layer after or below the reference layer.

            * BEFORE: Inserts the new layer before or above the reference layer."""
        return convertArcObjectToPythonObject(self._arc_object.insertLayer(*gp_fixargs((reference_layer, insert_layer_or_layerfile, insert_position), True)))

    def listBookmarks(self, wildcard=None):
        """Map.listBookmarks({wildcard})

           Returns a Python list of bookmark objects in a Map .

             wildcard{String}:
           A wildcard is based on the bookmark name and is not case sensitive. A
           combination of asterisks (*) and characters can be used to help
           limit the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listBookmarks(*gp_fixargs((wildcard,), True)))

    def listBrokenDataSources(self):
        """Map.listBrokenDataSources()

           Returns a Python list of Layer or Table objects that have broken
           connections to their original source data within a map."""
        return convertArcObjectToPythonObject(self._arc_object.listBrokenDataSources(*gp_fixargs((), True)))

    def listLayers(self, wildcard=None):
        """Map.listLayers({wildcard})

           Returns a Python list of Layer objects that exist within a map.

             wildcard{String}:
           A wildcard is based on the layer name and is not case sensitive. A
           combination of asterisks (*) and characters can be used to help
           limit the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listLayers(*gp_fixargs((wildcard,), True)))

    def listTables(self, wildcard=None):
        """Map.listTables({wildcard})

           Returns a Python list of Table objects that exist within a map.

             wildcard{String}:
           A wildcard is based on the layer name and is not case sensitive.  A
           combination of asterisks (*) and characters can be used to help limit
           the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listTables(*gp_fixargs((wildcard,), True)))

    def addBasemap(self, basemap_name):
        """Map.addBasemap({basemap_name})

           Add a basemap to the map.

             basemap_name{String}:
           The string representation of the basemap to be added."""
        return convertArcObjectToPythonObject(self._arc_object.addBasemap(*gp_fixargs((basemap_name,), True)))

    def addDataFromPath(self, data_path):
        """Map.addDataFromPath(data_path)

           Provides the ability to add data from a path to a map within a project ( .aprx
           ).

             data_path(URL):
           A reference to a string object representing the path of the layer to be added."""
        return convertArcObjectToPythonObject(self._arc_object.addDataFromPath(*gp_fixargs((data_path,), True)))
    
    @constants.maskargs
    def moveLayer(self, reference_layer, move_layer, insert_position='BEFORE'):
        """Map.moveLayer(reference_layer, move_layer, {insert_position})

           Provides the ability to move a layer or group layer in a map to  a
           specific location in the layer stack.

             reference_layer(Layer):
           A Layer object representing an existing layer that determines the
           location where the new layer will be moved.

             move_layer(Layer):
           A reference to a Layer object representing the layer to be moved.

             insert_position{String}:
           A constant that determines the placement of the moved layer relative
           to the reference layer.

            * AFTER: Moves the  layer after or below the reference layer.

            * BEFORE: Moves the layer before or above the reference layer."""
        return convertArcObjectToPythonObject(self._arc_object.moveLayer(*gp_fixargs((reference_layer, move_layer, insert_position), True)))

    def removeLayer(self, remove_layer):
        """Map.removeLayer(remove_layer)

           Provides the ability to remove a layer from a map in a project.

             remove_layer(Layer):
           A reference to a Layer object representing the layer to be removed."""
        return convertArcObjectToPythonObject(self._arc_object.removeLayer(*gp_fixargs((remove_layer,), True)))

    def removeTable(self, remove_table):
        """Map.removeTable(remove_table)

           Provides the ability to remove a table from a map in a project.

             remove_table(Table):
           A reference to a Table object representing the layer to be removed."""
        return convertArcObjectToPythonObject(self._arc_object.removeTable(*gp_fixargs((remove_table,), True)))

    def updateConnectionProperties(self, current_connection_info, new_connection_info, auto_update_joins_and_relates=True, validate=True):
        """Map.updateConnectionProperties(current_connection_info,
           new_connection_info, {auto_update_joins_and_relates}, {validate})

           Replaces connection properties using a dictionary or a path to a
           workspace.

             current_connection_info(String):
           A string that represents the workspace path or a Python dictionary
           that contains connection properties to the source you want to update.

             new_connection_info(String):
           A string that represents the workspace path or a Python dictionary
           that contains connection properties with the new source information.

             auto_update_joins_and_relates{Boolean}:
           If  set to True , the updateConnectionProperties method will also
           update the connections for associated joins or relates.

             validate{Boolean}:
           If  set to True , the connection properties will only be updated if
           the new_connection_info value is a valid connection.  If it is not
           valid, the connection will not be replaced.   If set to False , the
           method will set all connections to match the new_connection_info ,
           regardless of a valid match.  In this case, if a match does not
           exist, then the data sources would be broken."""
        return convertArcObjectToPythonObject(self._arc_object.updateConnectionProperties(*gp_fixargs((current_connection_info, new_connection_info, auto_update_joins_and_relates, validate), True)))

class MapFrame(_ObjectWithoutInitCall):
    """The MapFrame object is a page layout element that is used to display the
       contents of a map on a layout.      It also provides access to page size
       and positioning, basic navigation methods,  and export options."""
    camera = passthrough_attr('camera')
    elementHeight = passthrough_attr('elementHeight')
    elementPositionX = passthrough_attr('elementPositionX')
    elementPositionY = passthrough_attr('elementPositionY')
    elementRotation = passthrough_attr('elementRotation')
    elementWidth = passthrough_attr('elementWidth')
    map = passthrough_attr('map')
    name = passthrough_attr('name')
    type = passthrough_attr('type')
    visible = passthrough_attr('visible')
    def getLayerExtent(self, layer, selection_only=True, symbolized_extent=True):
        """MapFrame.getLayerExtent(layer, {selection_only}, {symbolized_extent})

           Returns a layer's extent for all features or only the selected
           features in a layer.

             layer(Layer):
           A reference to a Layer object.

             selection_only{Boolean}:
           If True , it returns the extent for selected features; if False , it
           returns the extent for all features.

             symbolized_extent{Boolean}:
           A value of True will return the layer's symbolized extent; otherwise,
           it will return the geometric extent.  The symbolized extent takes
           into account the area the symbology covers so that it does not get
           cut off by the data frame's boundary."""
        return convertArcObjectToPythonObject(self._arc_object.getLayerExtent(*gp_fixargs((layer, selection_only, symbolized_extent), True)))

    def panToExtent(self, extent):
        """MapFrame.panToExtent(extent)

           Pans and centers the MapFrame using a new Extent object without
           changing the map frame's scale.

             extent(Extent):
           A geoprocessing Extent object."""
        return convertArcObjectToPythonObject(self._arc_object.panToExtent(*gp_fixargs((extent,), True)))

    def zoomToAllLayers(self, selection_only=True, symbolized_extent=True):
        """MapFrame.zoomToAllLayers({selection_only}, {symbolized_extent})

           Modifies the MapFrame view to match the extent of all layers or
           selected layers in a map.

             selection_only{Boolean}:
           If True , it sets the extent based on the selected  features; if
           False , it sets the extent for all  features in a map.

             symbolized_extent{Boolean}:
           A value of True will return the layer's symbolized extent; otherwise,
           it will return the geometric extent.  The symbolized extent takes
           into account the area the symbology covers so that it does not get
           cut off by the map frame's boundary."""
        return convertArcObjectToPythonObject(self._arc_object.zoomToAllLayers(*gp_fixargs((selection_only, symbolized_extent), True)))

    def zoomToBookmark(self, bookmark):
        """MapFrame.zoomToBookmark(bookmark)

           Modifies the MapFrame view to match the view information stored with
           a spatial bookmark.

             bookmark(Bookmark):
           A reference to a Bookmark object."""
        return convertArcObjectToPythonObject(self._arc_object.zoomToBookmark(*gp_fixargs((bookmark,), True)))

    @constants.maskargs
    def exportToJPEG(self, out_jpg, resolution=96, world_file=False, jpeg_color_mode='24-BIT_TRUE_COLOR', jpeg_quality=80):
        """MapFrame.exportToJPEG(out_jpg, {resolution}, {world_file},
           {jpeg_color_mode}, {jpeg_quality})

           Exports the contents of a MapFrame to the Joint Photographic Experts
           Group format (JPEG).

             out_jpg(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             world_file{Boolean}:
           If set to True , a georeferenced world file is created. The file
           contains pixel scale information and real-world coordinate
           information.  If you export a 3D map frame, this parameter will be
           ignored regardless of the setting because world files are not
           applicable to 3D views.

             jpeg_color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

             jpeg_quality{Integer}:
           This value (0–100) controls the amount of compression applied to the
           output image. For JPEG, image quality is adversely affected the more
           compression is applied. A higher quality (highest = 100) setting will
           produce sharper images and larger file sizes. A lower quality setting
           will produce more image artifacts and smaller files."""
        return convertArcObjectToPythonObject(self._arc_object.exportToJPEG(*gp_fixargs((out_jpg, resolution, world_file, jpeg_color_mode, jpeg_quality), True)))

    @constants.maskargs
    def exportToPNG(self, out_png, resolution=96, world_file=False, color_mode='24-BIT_TRUE_COLOR'):
        """MapFrame.exportToPNG(out_png, {resolution}, {world_file},
           {color_mode})

           Exports the contents of a MapFrame to Portable Network Graphics
           format (PNG).

             out_png(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             world_file{Boolean}:
           If set to True , a georeferenced world file is created. The file
           contains pixel scale information and real-world coordinate
           information.  If you export a 3D map frame, this parameter will be
           ignored regardless of the setting because world files are not
           applicable to 3D views.

             color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

            * 32-BIT_WITH_ALPHA:   32-bit with alpha"""
        return convertArcObjectToPythonObject(self._arc_object.exportToPNG(*gp_fixargs((out_png, resolution, world_file, color_mode), True)))

    @constants.maskargs
    def exportToTIFF(self, out_tif, resolution=96, world_file=False, color_mode='24-BIT_TRUE_COLOR', tiff_compression='LZW', geoTIFF_tags=False):
        """MapFrame.exportToTIFF(out_tif, {resolution}, {world_file},
           {color_mode}, {tiff_compression}, {geoTIFF_tags})

           Exports the page layout to the Tagged Image File Format (TIFF).

             out_tif(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             world_file{Boolean}:
           If set to True , a georeferenced world file is created. The file
           contains pixel scale information and real-world coordinate
           information.  If you export a 3D map frame, this parameter will be
           ignored regardless of the setting because world files are not
           applicable to 3D views.

             color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

            * 32-BIT_WITH_ALPHA:   32-bit with alpha

             tiff_compression{String}:
           This value represents a compression scheme.

            * DEFLATE:   A lossless data compression.

            * JPEG: JPEG compression.

            * LZW:   Lempel-Ziv-Welch, a lossless data compression.

            * NONE:   Compression is not applied.

            * PACK_BITS:   Pack bits compression.

             geoTIFF_tags{Boolean}:
           If set to True , georeferencing tags are included in the structure of
           the TIFF export file. The tags contain pixel scale information and
           real-world coordinate information. These tags can be read by
           applications that support GeoTIFF format."""
        return convertArcObjectToPythonObject(self._arc_object.exportToTIFF(*gp_fixargs((out_tif, resolution, world_file, color_mode, tiff_compression, geoTIFF_tags), True)))

    @constants.maskargs
    def exportToBMP(self, out_bmp, resolution=96):
        """MapFrame.exportToBMP(out_bmp, {resolution})

           Exports the MapFrame to the Microsoft Windows Bitmap format (BMP).

             out_bmp(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi)."""
        return convertArcObjectToPythonObject(self._arc_object.exportToBMP(*gp_fixargs((out_bmp, resolution), True)))

    @constants.maskargs
    def exportToEMF(self, out_emf, resolution=96):
        """MapFrame.exportToEMF(out_emf, {resolution})

           Exports the map frame to the Enhanced Metafile (EMF) format.

             out_emf(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi)."""
        return convertArcObjectToPythonObject(self._arc_object.exportToEMF(*gp_fixargs((out_emf, resolution), True)))

    @constants.maskargs
    def exportToEPS(self, out_eps, resolution=96):
        """MapFrame.exportToEPS(out_eps, {resolution})

           Exports the map frame to an Encapsulated PostScript (EPS) format.

             out_eps(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi)."""
        return convertArcObjectToPythonObject(self._arc_object.exportToEPS(*gp_fixargs((out_eps, resolution), True)))

    @constants.maskargs
    def exportToGIF(self, out_gif, resolution=96):
        """MapFrame.exportToGIF(out_gif, {resolution})

           Exports the map frame to the Graphic Interchange format (GIF).

             out_gif(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi)."""
        return convertArcObjectToPythonObject(self._arc_object.exportToGIF(*gp_fixargs((out_gif, resolution), True)))

    @constants.maskargs
    def exportToTGA(self, out_tga, resolution=96):
        """MapFrame.exportToGIF(out_tga, {resolution})

           Exports the page layout to the Truevision Graphics Adapter format (TGA).

             out_tga(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi)."""
        return convertArcObjectToPythonObject(self._arc_object.exportToTGA(*gp_fixargs((out_tga, resolution), True)))

    @constants.maskargs
    def exportToSVG(self, out_svg, resolution=96, compress_to_svgz=False):
        """MapFrame.exportToSVG(out_svg, {resolution}, {compress_to_svgz})

           Exports the map frame to the Scalable Vector Graphics format (SVG).

             out_svg(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             compress_to_svgz{Boolean}:
           If set to True , the output is compressed."""
        return convertArcObjectToPythonObject(self._arc_object.exportToSVG(*gp_fixargs((out_svg, resolution, compress_to_svgz), True)))

    @constants.maskargs
    def exportToPDF(self, out_pdf, resolution=96, image_quality='BEST', compress_vector_graphics=True, image_compression='ADAPTIVE', embed_fonts=True, layers_attributes='LAYERS_ONLY', georef_info=True, jpeg_compression_quality=80):
        """MapFrame.exportToPDF(out_pdf, {resolution}, {image_quality},
           {compress_vector_graphics}, {image_compression}, {embed_fonts},
           {layers_attributes}, {georef_info}, {jpeg_compression_quality})

           Exports the MapFrame to the Portable Document Format (PDF).

             out_pdf(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (DPI).

             image_quality{String}:
           A string that defines output image quality, the draw resolution of
           map layers that draw as rasters.

            * BEST:  An output image quality resample ratio of 1.

            * BETTER:  An output image quality resample ratio of 2.

            * NORMAL:  An output image quality resample ratio of 3.

            * FASTER:  An output image quality resample ratio of 4.

            * FASTEST:  An output image quality resample ratio of 5.

             compress_vector_graphics{Boolean}:
           A Boolean that controls compression of vector and text portions of
           the output file. Image compression is defined separately.

             image_compression{String}:
           A string that defines the compression scheme used to compress image
           or raster data in the output file.

            * ADAPTIVE:   Automatically selects the best compression type for
            each image on the page.   JPEG will be used for large images with
            many unique colors.  DEFLATE will be used for all other images.

            * DEFLATE:   A lossless data compression.

            * JPEG:   A lossy data compression.

            * LZW:   Lempel-Ziv-Welch, a lossless data compression.

            * NONE:   Compression is not applied.

            * RLE:   Run-length encoded compression.

             embed_fonts{Boolean}:
           A Boolean that controls the embedding of fonts in the export file.
           Font embedding allows text and character markers to be displayed
           correctly when the document is viewed on a computer that does not
           have the necessary fonts installed.

             layers_attributes{String}:
           A string that controls inclusion of PDF layer and PDF object data
           (attributes) in the export file.

            * LAYERS_ONLY:  Export PDF layers only

            * LAYERS_AND_ATTRIBUTES:  Export PDF layers and feature attributes

            * NONE:  None

             georef_info{Boolean}:
           A Boolean that enables the export of coordinate system information
           for each data frame into the output PDF file.

             jpeg_compression_quality{Integer}:
           A number that controls compression quality value when
           image_compression is set to ADAPTIVE or JPEG . The valid range is 1
           to 100.    A jpeg_compression_quality of 100 provides the best-
           quality images but creates large export files.   The recommended
           range is between 70 and 90."""
        return convertArcObjectToPythonObject(self._arc_object.exportToPDF(*gp_fixargs((out_pdf, resolution, image_quality, compress_vector_graphics, image_compression, embed_fonts, layers_attributes, georef_info, jpeg_compression_quality, False), True)))

class MapSurroundElement(_ObjectWithoutInitCall):
    elementPositionX = passthrough_attr('elementPositionX')
    elementPositionY = passthrough_attr('elementPositionY')
    elementHeight = passthrough_attr('elementHeight')
    elementWidth = passthrough_attr('elementWidth')
    name = passthrough_attr('name')
    mapFrame = passthrough_attr('mapFrame')
    type = passthrough_attr('type')
    visible = passthrough_attr('visible')
class PictureElement(_ObjectWithoutInitCall):
    """Provides access to picture properties that enable the repositioning of a
       picture on the page layout as well as getting and setting its data
       source."""
    elementHeight = passthrough_attr('elementHeight')
    elementPositionX = passthrough_attr('elementPositionX')
    elementPositionY = passthrough_attr('elementPositionY')
    elementRotation = passthrough_attr('elementRotation')
    elementWidth = passthrough_attr('elementWidth')
    name = passthrough_attr('name')
    sourceImage = passthrough_attr('sourceImage')
    type = passthrough_attr('type')
    visible = passthrough_attr('visible')
class Table(_ObjectWithoutInitCall):
    """Table(table_data_source)

       Enables you to reference a table in a workspace so that it can be added
       to a Map .

         table_data_source(String):
       A string that includes the full workspace path, including the name of the
       table.  For SDE tables, the workspace path is the path to an SDE
       connection file."""
    connectionProperties = passthrough_attr('connectionProperties', True)
    dataSource = passthrough_attr('dataSource', True)
    definitionQuery = passthrough_attr('definitionQuery')
    isBroken = passthrough_attr('isBroken')
    name = passthrough_attr('name')
    def getSelectionSet(self):
        """Table.getSelectionSet()

           Returns a table's selection as a Python set of Object IDs."""
        return convertArcObjectToPythonObject(self._arc_object.getSelectionSet(*gp_fixargs((), True)))

    @constants.maskargs
    def setSelectionSet(self, oidList=None, method='NEW'):
        """Table.setSelectionSet({oidList}, {method})

           Sets a table's selection using a Python set of Object IDs.

             oidList{Integer}:
           A Python set of Object IDs to use along with the appropriate
           selection method.

             method{String}:
           A string that specifies which selection method to use.

            * NEW: Creates a new record selection from the oidList .

            * DIFFERENCE: Selects the records that are not in the current
            selection but are in the oidList .

            * INTERSECT: Selects the records that are in the current selection
            and the oidList .

            * SYMDIFFERENCE: Selects the records that are in the current
            selection or the oidList but not both.

            * UNION: Selects all the records in both the current selection and
            those in the oidList ."""
        return convertArcObjectToPythonObject(self._arc_object.setSelectionSet(*gp_fixargs((oidList, method), True)))

    def updateConnectionProperties(self, current_connection_info, new_connection_info, auto_update_joins_and_relates=True, validate=True):
        """updateConnectionProperties(current_connection_info,
           new_connection_info, {auto_update_joins_and_relates}, {validate})

           Replaces connection properties using a dictionary or a path to a
           workspace.

             current_connection_info(String):
           A string that represents the workspace path or a Python dictionary
           that contains connection properties to the source you want to update.

             new_connection_info(String):
           A string that represents the workspace path or a Python dictionary
           that contains connection properties with the new source information.

             auto_update_joins_and_relates{Boolean}:
           If  set to True , the updateConnectionProperties method will also
           update the connections for associated joins or relates.

             validate{Boolean}:
           If  set to True , the connection properties will only be updated if
           the new_connection_info value is a valid connection.  If it is not
           valid, the connection will not be replaced.   If set to False , the
           method will set all connections to match the new_connection_info ,
           regardless of a valid match.  In this case, if a match does not
           exist, then the data sources would be broken."""
        return convertArcObjectToPythonObject(self._arc_object.updateConnectionProperties(*gp_fixargs((current_connection_info, new_connection_info, auto_update_joins_and_relates, validate), True)))

    def __init__(self, table_data_source):
        """Table(table_data_source)

           Enables you to reference a table in a workspace so that it can be added to a Map .

             table_data_source(String):
           A string that includes the full workspace path, including the name of the table.  For SDE tables, the workspace path is the path to an SDE connection file."""
        import arcgisscripting
        self._arc_object = arcgisscripting._mapping.Table(*gp_fixargs((table_data_source,), True))

    def __str__(self):
        return self.name

class TextElement(_ObjectWithoutInitCall):
    """The TextElement object provides access to properties that enable its
       repositioning on the page layout as well as modifying the text string and
       font size."""
    elementHeight = passthrough_attr('elementHeight')
    elementPositionX = passthrough_attr('elementPositionX')
    elementPositionY = passthrough_attr('elementPositionY')
    elementRotation = passthrough_attr('elementRotation')
    elementWidth = passthrough_attr('elementWidth')
    textAngle = passthrough_attr('textAngle')
    textSize = passthrough_attr('textSize')
    name = passthrough_attr('name')
    text = passthrough_attr('text')
    type = passthrough_attr('type')
    visible = passthrough_attr('visible')
    def clone(self, suffix=None):
        """TextElement.clone({suffix})

           Provides a mechanism to clone an existing  text element on a page
           layout.

             suffix{String}:
           An optional string that is used to tag each newly created text
           element.  The new element gets the same element name as the parent
           text element, plus the suffix value, plus a numeric sequencer.  For
           example, if the parent element name is FieldLabel and the suffix
           value is _copy , the newly cloned elements are named FieldLabel_copy
           , FieldLabel_copy_1 , FieldLabel_copy_2 , and so on.  If a suffix is
           not provided, the results resemble FieldLabel_1 , FieldLabel_2 ,
           FieldLabel_3 , and so on."""
        return convertArcObjectToPythonObject(self._arc_object.clone(*gp_fixargs((suffix,), True)))

    def delete(self):
        """TextElement.delete()

           Provides a mechanism to delete an existing text element on a page
           layout."""
        return convertArcObjectToPythonObject(self._arc_object.delete(*gp_fixargs((), True)))

class MapView(_ObjectWithoutInitCall):
    """The MapView."""
    camera = passthrough_attr('camera')

    @constants.maskargs
    def exportToPDF(self, out_pdf, width, height, resolution=96, image_quality='BEST', compress_vector_graphics=True, image_compression='ADAPTIVE', embed_fonts=True, layers_attributes='LAYERS_ONLY', georef_info=True, jpeg_compression_quality=80):

        return convertArcObjectToPythonObject(self._arc_object.exportToPDF(*gp_fixargs((out_pdf, width, height, resolution, image_quality, compress_vector_graphics, image_compression, embed_fonts, layers_attributes, georef_info, jpeg_compression_quality, False), True)))
    
    @constants.maskargs
    def exportToPNG(self, out_png, width, height, resolution=96, world_file=False, color_mode='24-BIT_TRUE_COLOR'):
        """MapView.exportToPNG(out_png, width, height, {resolution}, {world_file},
           {color_mode})

           Exports the contents of a MapView to Portable Network Graphics
           format (PNG).

             out_png(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             world_file{Boolean}:
           If set to True , a georeferenced world file is created. The file
           contains pixel scale information and real-world coordinate
           information.  If you export a 3D map frame, this parameter will be
           ignored regardless of the setting because world files are not
           applicable to 3D views.

             color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

            * 32-BIT_WITH_ALPHA:   32-bit with alpha"""
        return convertArcObjectToPythonObject(self._arc_object.exportToPNG(*gp_fixargs((out_png, width, height, resolution, world_file, color_mode), True)))

    @constants.maskargs
    def exportToJPEG(self, out_jpg, width, height, resolution=96, world_file=False, jpeg_color_mode='24-BIT_TRUE_COLOR', jpeg_quality=80):
        """MapView.exportToJPEG(out_jpg, width, height, {resolution}, {world_file},
           {jpeg_color_mode}, {jpeg_quality})

           Exports the contents of a MapView to the Joint Photographic Experts
           Group format (JPEG).

             out_jpg(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             world_file{Boolean}:
           If set to True , a georeferenced world file is created. The file
           contains pixel scale information and real-world coordinate
           information.  If you export a 3D map frame, this parameter will be
           ignored regardless of the setting because world files are not
           applicable to 3D views.

             jpeg_color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

             jpeg_quality{Integer}:
           This value (0–100) controls the amount of compression applied to the
           output image. For JPEG, image quality is adversely affected the more
           compression is applied. A higher quality (highest = 100) setting will
           produce sharper images and larger file sizes. A lower quality setting
           will produce more image artifacts and smaller files."""
        return convertArcObjectToPythonObject(self._arc_object.exportToJPEG(*gp_fixargs((out_jpg, width, height, resolution, world_file, jpeg_color_mode, jpeg_quality), True)))
   
    @constants.maskargs
    def exportToTIFF(self, out_tif, width, height, resolution=96, world_file=False, color_mode='24-BIT_TRUE_COLOR', tiff_compression='LZW', geoTIFF_tags=False):
        """MapView.exportToTIFF(out_tif, width, height, {resolution}, {world_file},
           {color_mode}, {tiff_compression}, {geoTIFF_tags})

           Exports the map view to the Tagged Image File Format (TIFF).

             out_tif(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             world_file{Boolean}:
           If set to True , a georeferenced world file is created. The file
           contains pixel scale information and real-world coordinate
           information.  If you export a 3D map frame, this parameter will be
           ignored regardless of the setting because world files are not
           applicable to 3D views.

             color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

            * 32-BIT_WITH_ALPHA:   32-bit with alpha

             tiff_compression{String}:
           This value represents a compression scheme.

            * DEFLATE:   A lossless data compression.

            * JPEG: JPEG compression.

            * LZW:   Lempel-Ziv-Welch, a lossless data compression.

            * NONE:   Compression is not applied.

            * PACK_BITS:   Pack bits compression.

             geoTIFF_tags{Boolean}:
           If set to True , georeferencing tags are included in the structure of
           the TIFF export file. The tags contain pixel scale information and
           real-world coordinate information. These tags can be read by
           applications that support GeoTIFF format."""
        return convertArcObjectToPythonObject(self._arc_object.exportToTIFF(*gp_fixargs((out_tif, width, height, resolution, world_file, color_mode, tiff_compression, geoTIFF_tags), True)))

    @constants.maskargs
    def exportToSVG(self, out_svg, width, height, resolution=96, compress_to_svgz=False):
        """MapView.exportToSVG(out_svg, width, height, {resolution}, {compress_to_svgz})

           Exports the map view to the Scalable Vector Graphics format (SVG).

             out_svg(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             compress_to_svgz{Boolean}:
           If set to True , the output is compressed."""
        return convertArcObjectToPythonObject(self._arc_object.exportToSVG(*gp_fixargs((out_svg, width, height, resolution, compress_to_svgz), True)))

    @constants.maskargs
    def exportToEPS(self, out_eps, width, height, resolution=96):
        """MapView.exportToEPS(out_eps, width, height, {resolution})

           Exports the map view to an Encapsulated PostScript (EPS) format.

             out_eps(String):
           A string that represents the system path and file name for the output
           export file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi)."""
        return convertArcObjectToPythonObject(self._arc_object.exportToEPS(*gp_fixargs((out_eps, width, height, resolution), True)))

    @constants.maskargs
    def exportToGIF(self, out_gif, width, height, resolution=96):
        """MapView.exportToGIF(out_gif, width, height, {resolution})

           Exports the map viwe to the Graphic Interchange format (GIF).

             out_gif(String):
           A string that represents the system path and file name for the output
           export file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi)."""
        return convertArcObjectToPythonObject(self._arc_object.exportToGIF(*gp_fixargs((out_gif, width, height, resolution), True)))

class MapSeries(_ObjectWithoutInitCall):
    """ MapSeries object provides access to properties."""
    currentPageNumber = passthrough_attr('currentPageNumber')
    mapFrame = passthrough_attr('mapFrame')
    indexLayer = passthrough_attr('indexLayer')
    pageCount = passthrough_attr('pageCount')
    pageNameField = passthrough_attr('pageNameField')
    selectedIndexFeatures = passthrough_attr('selectedIndexFeatures')
    enabled = passthrough_attr('enabled')

    @constants.maskargs
    def exportToPDF(self, out_pdf, page_range_type="ALL", page_range_string="", multiple_files='PDF_SINGLE_FILE', resolution=96, image_quality='BEST', compress_vector_graphics=True, image_compression='ADAPTIVE', embed_fonts=True, layers_attributes='LAYERS_ONLY', georef_info=True, jpeg_compression_quality=80, clip_to_elements=False, show_selection_symbology=False):
        return convertArcObjectToPythonObject(self._arc_object.exportToPDF(*gp_fixargs((out_pdf, page_range_type, page_range_string, multiple_files ,resolution, image_quality, compress_vector_graphics, image_compression, embed_fonts, layers_attributes, georef_info, jpeg_compression_quality, clip_to_elements, show_selection_symbology), True)))

    def getPageNumberFromName(self, page_name):
        return convertArcObjectToPythonObject(self._arc_object.getPageNumberFromName(*gp_fixargs((page_name,), True)))

    def refresh(self):
        return convertArcObjectToPythonObject(self._arc_object.refresh(*gp_fixargs((), True)))

# Decorate PDFDocument methods with constants lists for Python window
PDFDocument.updateDocProperties.__esri_toolinfo__ = constants.maskargs(PDFDocument.updateDocProperties).__esri_toolinfo__
PDFDocument.updateDocSecurity.__esri_toolinfo__ = constants.maskargs(PDFDocument.updateDocSecurity).__esri_toolinfo__

ob_conversion = (
    ('MappingArcGISProjectObject', ArcGISProject),
    ('MappingBookmarkObject', Bookmark),
    ('MappingCameraObject', Camera),
    ('MappingGraphicElementObject', GraphicElement),
    ('MappingLabelClassObject', LabelClass),
    ('MappingLayerObject', Layer),
    ('MappingLayerFileObject', LayerFile),
    ('MappingLayoutObject', Layout),
    ('MappingLegendElementObject', LegendElement),
    ('MappingMapObject', Map),
    ('MappingMapFrameObject', MapFrame),
    ('MappingMapSurroundElementObject', MapSurroundElement),
    ('MappingPictureElementObject', PictureElement),
    ('MappingTableObject', Table),
    ('MappingTextElementObject', TextElement),
    ('MappingMapSeriesObject', MapSeries),
    ('MappingMapViewObject', MapView),
    ('MappingSymbologyObject', Symbology),
    ('MappingColorMapObject', ColorRamp),
    ('MappingSymbolObject', Symbol),
    ('MappingClassBreakObject', ClassBreak),
    ('MappingRasterClassBreakObject', RasterClassBreak),
    ('MappingItemGroupObject', ItemGroup),
    ('MappingItemObject', Item),
    ('MappingRasterItemObject', RasterItem),
)
