# -*- coding: utf-8 -*-
#COPYRIGHT 2017 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""The Utility Network toolbox contains an assortment of tools to create,
configure, and work with utility networks."""
__all__ = ['AddAngleDirectedLayout', 'AddCollapseContainerByAttributeRule',
           'AddCollapseContainerRule', 'AddCompressionLayout',
           'AddConnectivityAssociationsRule', 'AddDiagramTemplate',
           'AddDomainNetwork', 'AddExpandContainerByAttributeRule',
           'AddExpandContainerRule', 'AddForceDirectedLayout', 'AddGridLayout',
           'AddLinearDispatchLayout', 'AddMainlineTreeLayout',
           'AddNetworkAttribute', 'AddNetworkCategory',
           'AddPartialOverlappingEdgesLayout', 'AddRadialTreeLayout',
           'AddReduceEdgeByAttributeRule', 'AddReduceJunctionByAttributeRule',
           'AddReduceJunctionRule', 'AddRemoveFeatureByAttributeRule',
           'AddRemoveFeatureRule', 'AddReshapeDiagramEdgesLayout', 'AddRule',
           'AddSetRootJunctionByAttributeRule', 'AddSmartTreeLayout',
           'AddSpatialDispatchLayout', 'AddStartIterationRule',
           'AddStopIterationRule', 'AddStructuralAttachmentsRule',
           'AddTerminalConfiguration', 'AddTier', 'AddTierGroup',
           'AddTraceRule', 'AlterDiagramProperties', 'AlterDiagramTemplate',
           'AppendToDiagram', 'ApplyAngleDirectedLayout',
           'ApplyCompressionLayout', 'ApplyForceDirectedLayout',
           'ApplyGeoPositionsLayout', 'ApplyGridLayout',
           'ApplyLinearDispatchLayout', 'ApplyMainlineTreeLayout',
           'ApplyPartialOverlappingEdgesLayout', 'ApplyRadialTreeLayout',
           'ApplyRotateTreeLayout', 'ApplySmartTreeLayout',
           'ApplySpatialDispatchLayout', 'ApplyTemplateLayouts',
           'CreateDiagram', 'CreateDiagramLayerDefinition',
           'CreateUtilityNetwork', 'DeleteDiagram', 'DeleteDiagramTemplate',
           'DeleteNetworkCategory', 'DeleteRule', 'DeleteTerminalConfiguration',
           'DisableNetworkTopology', 'EnableNetworkTopology',
           'ExportAssociations', 'ExportDiagramLayerDefinition',
           'ExportDiagramTemplateDefinitions', 'ExportRules',
           'ExportSubnetwork', 'ExportSubnetworkControllers', 'ExtendDiagram',
           'GetDiagramTemplateNames', 'ImportAssociations',
           'ImportDiagramTemplateDefinitions', 'ImportRules',
           'ImportSubnetworkControllers', 'MakeDiagramLayer',
           'OverwriteDiagram', 'PurgeTemporaryDiagrams',
           'ReshapeDiagramEdgesLayout', 'SetAssociationRole',
           'SetEdgeConnectivity', 'SetNetworkAttribute', 'SetNetworkCategory',
           'SetSubnetworkDefinition', 'SetTerminalConfiguration',
           'StoreDiagram', 'Trace', 'UpdateDiagram', 'UpdateIsConnected',
           'UpdateSubnetwork', 'ValidateNetworkTopology']
__alias__ = 'un'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Tools
@gptooldoc('ExportSubnetwork_un', None)
def ExportSubnetwork(in_utility_network=None, domain_network=None, tier=None, subnetwork_name=None, export_acknowledged=None, out_json_file=None, condition_barriers=None, function_barriers=None, include_barriers=None, traversability_scope=None, propagators=None):
    """ExportSubnetwork_un(in_utility_network, domain_network, tier, subnetwork_name, export_acknowledged, out_json_file, {condition_barriers;condition_barriers...}, {function_barriers;function_barriers...}, {include_barriers}, {traversability_scope}, {propagators;propagators...})

        Exports subnetworks from a utility network into a JSON file.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network that contains the subnetwork to export.
      domain_network (String):
          The name of the domain network that the subnetwork belongs to.
      tier (String):
          The tier that contains the subnetwork.
      subnetwork_name (String):
          The name of the subnetwork to export. Use ALL to export all
          subnetworks in the specified utility network. Select a specific source
          to export the corresponding subnetwork information.
      export_acknowledged (Boolean):
          Whether the LASTACKEXPORTSUBNETWORK attribute for the corresponding
          source in the Subnetworks table is updated.

          * ACKNOWLEDGE-Update the LASTACKEXPORTSUBNETWORK attribute for the
          corresponding source in the Subnetworks table. If the source has been
          marked for deletion, choosing this option will delete it from the
          Subnetworks table.

          * NO_ACKNOWLEDGE-Do not update the LASTACKEXPORTSUBNETWORK attribute
          for the corresponding source in the Subnetworks table. This is the
          default.
      condition_barriers {Value Table}:
          Set a traversability barrier condition on features based on a
          comparison to a network attribute or check for a category string. A
          condition barrier uses a network attribute, an operator and type, and
          an attribute value. For example, stop a trace when a feature has the
          attribute Device Status equal to the specific value of Open. When a
          feature meets this condition, the trace stops. If using more than one
          attribute, you can use the Combine using parameter to define an And or
          an Or condition.Condition barrier components:

          * Name-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Type-Choose a specific value or network attribute from the value
          that is specified in the name parameter.

          * Value-Specific value of the input attribute type that would cause
          termination based on the operator value.

          * Combine Using-You can set this value if you have multiple attributes
          to add. You can choose to combine them using an Add or an Or
          condition.
          The condition barrier operator values are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          The condition barrier type options are as follows:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
          The Combine Using values are as follows:

          * AND-Combine the condition barriers.

          * OR-Use if either condition barrier is met.
          This parameter is only available via Python.
      function_barriers {Value Table}:
          Set a traversability barrier on features based on a function. Function
          barriers can be used to do such things as restrict how far the trace
          travels from the starting point, or set a maximum value to stop a
          trace at. For example, the length of each line traveled is added to
          the total distance traveled so far. When the total length traveled
          reaches the value specified, the trace stops.Function barrier
          components:

          * Function-Choose from a number of different calculation functions.

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Value-Specific value of the input attribute type that, if
          discovered, will cause the termination.

          * Use Local Values-Calculates values in each direction as opposed to
          an overall global value, for example, for a function barrier that is
          calculating the sum of Shape length where the trace terminates if the
          value is greater than or equal to 4. In the global case, after you
          have traversed two edges with a value of 2, you have already reached a
          shape length sum of 4, so the trace stops. If local values are used,
          the local values along each path change, so the trace goes farther.

          * TRUE-Use local values.

          * FALSE-Use global values. This is the default.
          Possible values for the function barrier function options are as
          follows:

          * AVERAGE-The average of the input values.

          * COUNT-The number of features.

          * MAX-The maximum of the input values.

          * MIN-The minimum of the input values.

          * ADD-Add the values.

          * SUBTRACT-Subtract the values.
          For example, there is a starting point feature with a value of 20. The
          next feature has a value of 30. If you are using the MIN function, the
          result is 20. MAX is 30, ADD is 50, AVERAGE is 25, COUNT is 2, and
          SUBTRACT is -10.The function barrier operator value options are as
          follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          This parameter is only available via Python.
      include_barriers {Boolean}:
          Whether the traversability barrier features are included in the trace
          results. Traversability barriers are optional even if they have been
          preset in the subnetwork definition.

          * INCLUDE_BARRIERS-Traversability barriers are included in the trace
          results. This is the default.

          * EXCLUDE_BARRIERS-Traversability barriers are ignored in the trace
          results.
          This parameter is only available via Python.
      traversability_scope {String}:
          The type of traversability to enforce. Traversability scope dictates
          whether traversability is enforced at junctions, edges, or both. For
          example, if a condition barrier is defined to stop the trace if
          DEVICESTATUS is set to Open and the traversability scope is set to
          edges only, then even if the trace encounters an open device the trace
          would not stop, because the DEVICESTATUS is only applicable for
          junctions. In other words, this parameter tells the trace whether or
          not to ignore junctions, edges, or both.

          * BOTH_JUNCTIONS_AND_EDGES-Apply traversability to both junctions and
          edges.

          * JUNCTIONS_ONLY-Apply traversability to only junctions.

          * EDGES_ONLY-Apply traversability to only edges.
          This parameter is only available via Python.
      propagators {Value Table}:
          Define which network attributes to propagate as well as how that
          propagation should happen during a trace. Propagated class attributes
          denote the key values on subnetwork controllers that are disseminated
          to the rest of the features in the subnetwork. For example, in an
          electric distribution model, you may propagate the phase
          value.Propagators components:

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Substitution Attribute-Use a substituted value instead of bitset
          network attribute values. Substitutions are encoded based on the
          number of bits in the network attribute being propagated.

          * Function-Choose from a number of different calculation functions.

          * Operator-Choose from a number of different operators.

          * Value-Specific value of the input attribute type that would cause
          termination based on the operator value.
          Possible values for the propagators function are as follows:

          * PROPAGATED_BITWISE_AND-Compare the values from one feature to the
          next.

          * PROPAGATED_MIN-Get the minimum value.

          * PROPAGATED_MAX-Get the maximum value.
          The propagator operator values are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          This parameter is only available via Python.

     OUTPUTS:
      out_json_file (File):
          The name and location of the JSON file to be generated."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportSubnetwork_un(*gp_fixargs((in_utility_network, domain_network, tier, subnetwork_name, export_acknowledged, out_json_file, condition_barriers, function_barriers, include_barriers, traversability_scope, propagators), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('Trace_un', None)
def Trace(in_utility_network=None, trace_type=None, starting_points=None, barriers=None, domain_network=None, tier=None, target_tier=None, subnetwork_name=None, shortest_path_network_attribute_name=None, include_containers=None, include_content=None, include_structures=None, include_barriers=None, validate_consistency=None, condition_barriers=None, function_barriers=None, traversability_scope=None, filter_barriers=None, filter_function_barriers=None, filter_scope=None, filter_bitset_network_attribute_name=None, filter_nearest=None, nearest_count=None, nearest_cost_network_attribute=None, nearest_categories=None, nearest_assets=None, functions=None, propagators=None, output_assettypes=None, output_conditions=None):
    """Trace_un(in_utility_network, trace_type, {starting_points}, {barriers}, {domain_network}, {tier}, {target_tier}, {subnetwork_name}, {shortest_path_network_attribute_name}, {include_containers}, {include_content}, {include_structures}, {include_barriers}, {validate_consistency}, {condition_barriers;condition_barriers...}, {function_barriers;function_barriers...}, {traversability_scope}, {filter_barriers;filter_barriers...}, {filter_function_barriers;filter_function_barriers...}, {filter_scope}, {filter_bitset_network_attribute_name}, {filter_nearest}, {nearest_count}, {nearest_cost_network_attribute}, {nearest_categories;nearest_categories...}, {nearest_assets;nearest_assets...}, {functions;functions...}, {propagators;propagators...}, {output_assettypes;output_assettypes...}, {output_conditions;output_conditions...})

        Returns selected features based on connectivity or traversability from
        the specified starting point(s). Utility network tracing capabilities
        allow you to analyze the paths
        within your network. This tool runs a trace that returns features
        based on connectivity or traversability from the specified starting
        points. Traversability refers to paths established by connected or
        associated features that also meet configuration requirements. Results
        from a trace operation are returned as a selection set of the
        appropriate network features. The resulting selection set of a trace
        can then be propagated to another map, a diagram view of the network,
        or be used as input to another tool or trace.About tracing utility
        networks

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network to run the trace against. The input utility
          network must be from a feature service environment. A utility network
          that comes from an enterprise geodatabase connection file is not
          supported.
      trace_type (String):
          The type of trace to execute.

          * CONNECTED-A connected trace begins at one or more starting points
          and spans outward along connected features. This is the default.

          * SUBNETWORK-A subnetwork trace begins at one or more starting points
          and spans outward to encompass the extent of the subnetwork.

          * SUBNETWORK_CONTROLLERS-A subnetwork controllers trace locates
          sources and sinks on subnetwork controllers associated with a
          subnetwork.

          * UPSTREAM-An upstream trace can discover features upstream from a
          location in the network.

          * DOWNSTREAM-A downstream trace can discover features downstream from
          a location in the network.

          * LOOPS-Loops are areas of the network where flow direction is
          ambiguous. A loops trace spans outwards from the starting point based
          on connectivity.

          * SHORTEST_PATH-A shortest path trace can identify the shortest path
          between two starting points.
      starting_points {Feature Layer}:
          A point feature class containing one or more features that represent
          the starting points of the trace. This feature class has to have a
          specific format, including fields that store the asset group, asset
          type, terminal id, and percent along edge of the starting point. This
          feature layer can be created by using the Set Starting Points tool on
          the Trace Locations pane.
      barriers {Feature Layer}:
          A feature class representing the barriers which prevents the trace
          from traversing beyond that point. This feature layer can be created
          by using the tool on the Barriers tab on the Trace Locations pane.
      domain_network {String}:
          The name of the domain network to run the trace on. This parameter is
          required when running the subnetwork, subnetwork controllers, upstream
          or downstream trace types.
      tier {String}:
          The name of the tier to start the trace. This parameter is required
          if running the subnetwork, subnetwork controllers, upstream or
          downstream trace types.
      target_tier {String}:
          The name of the target tier for which the input tier flows towards.
          If the parameter is missing for upstream and downstream traces, they
          will stop when they hit the boundary of the starting subnetwork. This
          parameter can be used to allow these traces to continue beyond, either
          farther up or farther down the hierarchy.
      subnetwork_name {String}:
          The name of the subnetwork to run the trace on. This parameter can be
          used when running a subnetwork trace type. If a subnetwork name is
          specified, the starting points parameter is not required.
      shortest_path_network_attribute_name {String}:
          The network attribute used to calculate the shortest path. When
          running a shortest path trace type, the shortest path is calculated
          using a numeric network attribute such as Shape length. Cost or
          distance based paths can both be achieved. This parameter is required
          when running a shortest path trace .
      include_containers {Boolean}:
          Define whether the container features are included in the trace
          results.

          * INCLUDE_CONTAINERS-Container features are included in the trace
          results.

          * EXCLUDE_CONTAINERS-Container features are not included in the trace
          results. This is the default.
      include_content {Boolean}:
          Define whether the trace returns content in containers in the
          results.

          * INCLUDE_CONTENT-Content in containers features are included in the
          trace results.

          * EXCLUDE_CONTENT-Content in containers features are not included in
          the trace results. This is the default.
      include_structures {Boolean}:
          Define whether the structure features are included in the trace
          results.

          * INCLUDE_STRUCTURES-Structure features are included in the trace
          results.

          * EXCLUDE_STRUCTURES-Structure features are not included in the trace
          results. This is the default.
      include_barriers {Boolean}:
          Define whether the traversability barrier features are included in the
          trace results. Traversability barriers are optional even if they have
          been preset in the subnetwork definition.

          * INCLUDE_BARRIERS-Traversability barrier features are included in the
          trace results. This is the default.

          * EXCLUDE_BARRIERS-Traversability barrier features are not included in
          the trace results.
      validate_consistency {Boolean}:
          If any dirty areas are encountered in the trace results, setting the
          trace to validate consistency will return a warning. This is the only
          way to guarantee a trace is passing through features with consistent
          status in the network. To remove dirty areas, the network topology
          should be validated.

          * VALIDATE_CONSISTENCY-A warning will be returned if any dirty areas
          are encountered in the trace results.

          * DO_NOT_VALIDATE_CONSISTENCY-No warning will be returned if dirty
          areas are encountered during in the trace results. This is the
          default.
      condition_barriers {Value Table}:
          Set a traversability barrier condition on features based on a
          comparison to a network attribute or check for a category string. A
          condition barrier uses a network attribute, an operator and type, and
          an attribute value. For example, stop a trace when a feature has the
          attribute Device Status equal to the specific value of Open. When a
          feature meets this condition, the trace stops. If using more than one
          attribute, you can use the Combine using parameter to define an And or
          an Or condition.Condition barrier components:

          * Name-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Type-Choose a specific value or network attribute from the value
          that is specified in the name parameter.

          * Value-Specific value of the input attribute type which would cause
          termination based on the operator value.

          * Combine Using-You can set this value if you have multiple attributes
          to add. You can choose to combine them using an Add or an Or
          condition.
          The condition barriers operator values are:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          Possible values for the Type options are:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
          The Combine Using values are:

          * AND-Combine the condition barriers.

          * OR-Use if either of condition barrier is met.
      function_barriers {Value Table}:
          Set a traversability barrier on features based on a function. Function
          barriers can be used to do such things as restrict how far the trace
          travels from the starting point, or set a maximum value to stop a
          trace at. For example, the length of each line traveled is added to
          the total distance traveled so far. When the total length traveled
          reaches the value specified, the trace stops.Function barrier
          components:

          * Function-Choose from a number of different calculation functions.

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Value-Specific value of the input attribute type that, if
          discovered, will cause the termination.

          * Use Local Values-Local values calculates values in each direction as
          opposed to an overall global value. For example, for a function
          barrier that is calculating the sum of Shape length where the trace
          terminates if the value is greater than or equal to 4. In the global
          case, after we have traversed two edges with a value of 2, we have
          already reached a shape length sum of 4, so the trace stops. If local
          values are used, the local values along each path changes, ro the
          trace goes further.
          Possible values for the function barrier function options are:

          * AVERAGE-The average of the input values.

          * COUNT-The number of features.

          * MAXIMUM-The maximum of the input values.

          * MINIMUM-The minimum of the input values.

          * ADD-Add the values.

          * SUBTRACT-Subtract the values.
          The function barrier operator value options are:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          The function barrier Use Local Values options are:

          * TRUE-Use local values.

          * FALSE-Use global values. This is the default.
      traversability_scope {String}:
          The type of traversability to enforce. Traversability scope dictates
          whether traversability is enforced at junctions, edges, or both. For
          example, if a condition barrier is defined to stop the trace if Device
          Status is equal to Open and traversability scope is set to edges only,
          then even if the trace encounters an open device the trace would not
          stop because the Device Status is only applicable for junctions. In
          other words, this parameter tells the trace whether or not to ignore
          junctions, edges, or both.

          * BOTH_JUNCTIONS_AND_EDGES-Apply traversability to both junctions and
          edges. This is the default.

          * JUNCTIONS_ONLY-Apply traversability to only junctions.

          * EDGES_ONLY-Apply traversability to only edges.
      filter_barriers {Value Table}:
          Filter barrier specifying when a trace should stop for a specific
          category or network attribute. For example, stop a trace at features
          that have a life cycle status attribute that is equal to a certain
          value. This parameter is used to set a terminator based on a value of
          a network attribute that is defined in the system. If using more than
          one attribute, you can use the Combine Using option to define an And
          or an Or condition.Filter barrier components:

          * Name-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Type-Choose a specific value or network attribute from the value
          that is specified in the name parameter.

          * Value-Specific value of the input attribute type which would cause
          termination based on the operator value.

          * Combine Using-You can set this value if you have multiple attributes
          to add. You can choose to combine them using an Add or an Or
          condition.
          The filter barriers operator values are:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          Possible values for the Type options are:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
          The Combine Using values are:

          * AND-Combine the condition barriers.

          * OR-Use if either of condition barrier is met.
      filter_function_barriers {Value Table}:
          The filter function barrier parameter allows you to filter the
          results of the trace for a specific category.Filter function barrier
          components:

          * Function-Choose from a number of different calculation functions.

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Value-Specific value of the input attribute type that, if
          discovered, will cause the termination.

          * Use Local Values-Local values calculates values in each direction as
          opposed to an overall global value. For example, for a function
          barrier that is calculating the sum of Shape length where the trace
          terminates if the value is greater than or equal to 4. In the global
          case, after we have traversed two edges with a value of 2, we have
          already reached a shape length sum of 4, so the trace stops. If local
          values are used, the local values along each path changes, or the
          trace goes further.
          Possible values for the function barrier function options are:

          * AVERAGE-The average of the input values.

          * COUNT-The number of features.

          * MAXIMUM-The maximum of the input values.

          * MINIMUM-The minimum of the input values.

          * ADD-Add the values.

          * SUBTRACT-Subtract the values.
          The function barrier operator value options are:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          The function barrier Use Local Values options are:

          * TRUE-Use local values.

          * FALSE-Use global values. This is the default.
      filter_scope {String}:
          Whether the filter for a specific category is enforced at junctions,
          edges, or both. For example, if a filter barrier is defined to stop
          the trace if Device Status is equal to Open and traversability scope
          is set to edges only, then even if the trace encounters an open device
          the trace will not stop because the Device Status is only applicable
          for junctions. In other words, this parameter tells the trace whether
          or not to ignore junctions, edges, or both.

          * BOTH_JUNCTIONS_AND_EDGES-Apply filter to both junctions and edges.
          This is the default.

          * JUNCTIONS_ONLY-Apply filter to only junctions.

          * EDGES_ONLY-Apply filter to only edges.
      filter_bitset_network_attribute_name {String}:
          The name of the network attribute that can be used to filter by
          bitset. This parameter is only applicable for upstream, downstream, or
          loops trace types. This parameter can be used to add special logic
          during a trace so the trace is more reflective of real world
          scenarios. For example, for a loops trace, the Phases current network
          attribute can determine if the loop is a true electrical loop (the
          same phase is energized all around the loop, ie. A) and return only
          real electrical loops for the trace results. An example for an
          upstream trace is; when tracing an electric distribution network, by
          specifying a Phases current network attribute, the trace results will
          only include valid paths that are the specified in the network
          attribute, not all paths.
      filter_nearest {Boolean}:
          Return a number of features of a certain type within a given distance
          by using k-nearest neighbors algorithm. When this parameter is used,
          you can specify a count, cost, and either a collection of categories
          or assets or both.

          * Checked-Use k-nearest neighbors to return a number of features as
          specified in the Count, Cost Network Attribute, Nearest Categories or
          Nearest Asset Groups/Types parameters.

          * Unchecked-Do not filter results by using k-nearest neighbors. This
          is the default.

          * TRUE-Use k-nearest neighbors to return a number of features as
          specified in the nearest_count, nearest_cost_network_attribute,
          nearest_categories, or nearest_assets parameters.

          * FALSE-Do not filter results by using k-nearest neighbors. This is
          the default.
      nearest_count {Long}:
          When filter_nearest is True, specify the number of features to be
          returned. For example, 4.
      nearest_cost_network_attribute {String}:
          When filter_nearest is True, specify the numeric network attribute
          that will be used to calculate nearness, cost, or distance. For
          example,  Shape length.
      nearest_categories {String}:
          When filter_nearest is True, specify the categories that will be
          returned. For example, Protective.
      nearest_assets {String}:
          When filter_nearest is True, specify the asset groups and asset types
          that will be returned. For example,
          ElectricDistributionDevice/Transformer/Step Down.
      functions {Value Table}:
          Apply a calculation function to the trace results.Functions
          components:

          * Function-Choose from a number of different calculation functions.

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Filter Name-Choose to filter the function results by attribute name.

          * Filter Operator-Choose from a number of different operators.

          * Filter Type-Choose from a number of different filter types.

          * Filter Value-Specific value of the input filter attribute.
          Possible values for the Function options are:

          * AVERAGE-The average of the input values.

          * COUNT-The number of features.

          * MAX-The maximum of the input values.

          * MI-The minimum of the input values.

          * ADD-Add the values.

          * SUBTRACT-Subtract the values.
          For example, there is a starting point feature with a value of 20. The
          next feature has a value of 30. If you are using the MIN function, the
          result is 20. MAX is 30, ADD is 50, AVERAGE is 25, COUNT is 2, and
          SUBTRACT is -10.The Filter Operator value options are:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          specific values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          Possible values for the summaries Filter Type options are:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
      propagators {Value Table}:
          Define which network attributes to propagate as well as how that
          propagation should happen during a trace. Propagated class attributes
          denote the key values on subnetwork controllers that are disseminated
          to the rest of the features in the subnetwork. For example, in an
          electric distribution model, you may propagate the phase
          value.Propagators components:

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Substitution Attribute-Use a substituted value instead of bitset
          network attribute values. Substitutions are encoded based on the
          number of bits in the network attribute being propagated.

          * Function-Choose from a number of different calculation functions.

          * Operator-Choose from a number of different operators.

          * Value-Specific value of the input attribute type that would cause
          termination based on the operator value.
          Possible values for the propagators function are:

          * PROPAGATED_BITWISE_AND-Compare the values from one feature to the
          next.

          * PROPAGATED_MIN-Get the minimum value.

          * PROPAGATED_MAX-Get the maximum value.
          The propagator operator values are:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          This parameter is only available via Python.
      output_assettypes {String}:
          Filter the output asset types to be included in the results. For
          example, only return overhead transformers.
      output_conditions {Value Table}:
          Use this parameter to control the types of features returned based on
          a network attribute or category. For example, a trace configured to
          filter out everything but Tap features, any traced features that do
          not have the Tap category assigned to it, is not included in the
          results. Any traced features that do are returned in the result
          selection set. If using more than one attribute, you can use the
          Combine Using option to define an And or an Or condition.Output
          conditions components:

          * Name-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Type-Choose a specific value or network attribute from the value
          that is specified in the name parameter.

          * Value-Specific value of the input attribute type which would cause
          termination based on the operator value.

          * Combine Using-You can set this value if you have multiple attributes
          to add. You can choose to combine them using an Add or an Or
          condition.
          The operator values are:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          Possible values for the Type options are:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
          The Combine Using values are:

          * AND-Combine the conditions.

          * OR-Use if either of conditions is met."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.Trace_un(*gp_fixargs((in_utility_network, trace_type, starting_points, barriers, domain_network, tier, target_tier, subnetwork_name, shortest_path_network_attribute_name, include_containers, include_content, include_structures, include_barriers, validate_consistency, condition_barriers, function_barriers, traversability_scope, filter_barriers, filter_function_barriers, filter_scope, filter_bitset_network_attribute_name, filter_nearest, nearest_count, nearest_cost_network_attribute, nearest_categories, nearest_assets, functions, propagators, output_assettypes, output_conditions), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('UpdateIsConnected_un', None)
def UpdateIsConnected(in_utility_network=None):
    """UpdateIsConnected_un(in_utility_network)

        Updates the IsConnected attribute on all the network features for the
        specified utility network. Utility network features have an attribute
        IsConnected that indicates
        if a feature is connected to a source or sink. If a feature is
        connected to a source or sink, it could potentially be part of an
        existing subnetwork.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network for which to update the IsConnected attribute."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpdateIsConnected_un(*gp_fixargs((in_utility_network,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('UpdateSubnetwork_un', None)
def UpdateSubnetwork(in_utility_network=None, domain_network=None, tier=None, all_subnetworks_in_tier=None, subnetwork_name=None, continue_on_failure=None, condition_barriers=None, function_barriers=None, include_barriers=None, traversability_scope=None, propagators=None):
    """UpdateSubnetwork_un(in_utility_network, domain_network, tier, all_subnetworks_in_tier, {subnetwork_name}, {continue_on_failure}, {condition_barriers;condition_barriers...}, {function_barriers;function_barriers...}, {include_barriers}, {traversability_scope}, {propagators;propagators...})

        Updates the SUBNETWORKNAME attribute on network features and creates
        and/or updates the SubnetLine feature class and subnetwork system
        diagram(s) for the specified subnetwork(s). A record for any new
        subnetworks will be generated, the record for any deleted subnetworks
        will be removed, and the shape and information for any modified
        subnetworks will be updated.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network the subnetwork belongs to.
      domain_network (String):
          The domain network that contains the subnetwork.
      tier (String):
          The tier the subnetwork belongs to.
      all_subnetworks_in_tier (Boolean):
          Choose to update all subnetworks in the tier. To update a subset of
          subnetworks in the tier, use the subnetwork_name parameter.

          * ALL_SUBNETWORKS_IN_TIER-Update all subnetworks in the tier. This is
          the default.

          * SPECIFIC_SUBNETWORK-Update only the subnetworks specified in the
          subnetwork_name parameter.
      subnetwork_name {String}:
          The name of the subnetworks to update. If you have chosen to update
          all subnetworks using the all_subnetworks_in_tier parameter, this
          parameter is ignored.
      continue_on_failure {Boolean}:
          When updating multiple subnetworks, this option determines whether or
          not to stop the process when a subnetwork fails to update.

          * CONTINUE_ON_FAILURE-Continue to update subnetworks upon failure.

          * STOP_ON_FAILURE-Stop the process of updating subnetworks if a
          failure occurs. This is the default.
      condition_barriers {Value Table}:
          Set a traversability barrier condition on features based on a
          comparison to a network attribute or check for a category string. A
          condition barrier uses a network attribute, an operator and type, and
          an attribute value. For example, stop a trace when a feature has the
          attribute Device Status equal to the specific value of Open. When a
          feature meets this condition, the trace stops. If using more than one
          attribute, you can use the Combine using parameter to define an And or
          an Or condition.Condition barrier components:

          * Name-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Type-Choose a specific value or network attribute from the value
          that is specified in the name parameter.

          * Value-Specific value of the input attribute type that would cause
          termination based on the operator value.

          * Combine Using-You can set this value if you have multiple attributes
          to add. You can choose to combine them using an Add or an Or
          condition.
          The condition barrier operator values are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          The condition barrier type options are as follows:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
          The Combine Using values are as follows:

          * AND-Combine the condition barriers.

          * OR-Use if either condition barrier is met.
          This parameter is only available via Python.
      function_barriers {Value Table}:
          Set a traversability barrier on features based on a function. Function
          barriers can be used to do such things as restrict how far the trace
          travels from the starting point, or set a maximum value to stop a
          trace at. For example, the length of each line traveled is added to
          the total distance traveled so far. When the total length traveled
          reaches the value specified, the trace stops.Function barrier
          components:

          * Function-Choose from a number of different calculation functions.

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Value-Specific value of the input attribute type that, if
          discovered, will cause the termination.

          * Use Local Values-Calculates values in each direction as opposed to
          an overall global value, for example, for a function barrier that is
          calculating the sum of Shape length where the trace terminates if the
          value is greater than or equal to 4. In the global case, after you
          have traversed two edges with a value of 2, you have already reached a
          shape length sum of 4, so the trace stops. If local values are used,
          the local values along each path change, so the trace goes farther.

          * TRUE-Use local values.

          * FALSE-Use global values. This is the default.
          Possible values for the function barrier function options are as
          follows:

          * AVERAGE-The average of the input values.

          * COUNT-The number of features.

          * MAX-The maximum of the input values.

          * MIN-The minimum of the input values.

          * ADD-Add the values.

          * SUBTRACT-Subtract the values.
          For example, there is a starting point feature with a value of 20. The
          next feature has a value of 30. If you are using the MIN function, the
          result is 20. MAX is 30, ADD is 50, AVERAGE is 25, COUNT is 2, and
          SUBTRACT is -10.The function barrier operator value options are as
          follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          This parameter is only available via Python.
      include_barriers {Boolean}:
          Define whether the traversability barrier features are included in the
          trace results. Traversability barriers are optional even if they have
          been preset in the subnetwork definition.

          * INCLUDE_BARRIERS-Traversability barriers are included in the trace
          results. This is the default.

          * EXCLUDE_BARRIERS-Traversability barriers are ignored in the trace
          results.
          This parameter is only available via Python.
      traversability_scope {String}:
          The type of traversability to enforce. Traversability scope dictates
          whether traversability is enforced at junctions, edges, or both. For
          example, if a condition barrier is defined to stop the trace if
          DEVICESTATUS is equal to Open and traversability scope is set to edges
          only, then even if the trace encounters an open device the trace would
          not stop, because the DEVICESTATUS is only applicable for junctions.
          In other words, this parameter tells the trace whether or not to
          ignore junctions, edges, or both.

          * BOTH_JUNCTIONS_AND_EDGES-Apply traversability to both junctions and
          edges. This is the default.

          * JUNCTIONS_ONLY-Apply traversability to only junctions.

          * EDGES_ONLY-Apply traversability to only edges.
          This parameter is only available via Python.
      propagators {Value Table}:
          Define which network attributes to propagate as well as how that
          propagation should happen during a trace. Propagated class attributes
          denote the key values on subnetwork controllers that are disseminated
          to the rest of the features in the subnetwork. For example, in an
          electric distribution model, you may propagate the phase
          value.Propagators components:

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Substitution Attribute-Use a substituted value instead of bitset
          network attribute values. Substitutions are encoded based on the
          number of bits in the network attribute being propagated.

          * Function-Choose from a number of different calculation functions.

          * Operator-Choose from a number of different operators.

          * Value-Specific value of the input attribute type that would cause
          termination based on the operator value.
          Possible values for the propagators function are as follows:

          * PROPAGATED_BITWISE_AND-Compare the values from one feature to the
          next.

          * PROPAGATED_MIN-Get the minimum value.

          * PROPAGATED_MAX-Get the maximum value.
          The propagator operator values are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          This parameter is only available via Python."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpdateSubnetwork_un(*gp_fixargs((in_utility_network, domain_network, tier, all_subnetworks_in_tier, subnetwork_name, continue_on_failure, condition_barriers, function_barriers, include_barriers, traversability_scope, propagators), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ValidateNetworkTopology_un', None)
def ValidateNetworkTopology(in_utility_network=None, extent=None):
    """ValidateNetworkTopology_un(in_utility_network, {extent})

        Validates the network topology of a utility network after there have
        been spatial edits to features in the network.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network for which the network topology will be validated.
      extent {Extent}:
          The geographical area for which to validate the network topology. This
          parameter is similar to the extent geoprocessing environment.

          * Extent object-An Extent object can be used to define the extent.

          * MINOF-The extent where all input features or rasters overlap
          (intersect one another). Note that it is possible that none of the
          features overlap and that a null extent (zero width and height) may
          result. In such cases, no features or cells will be processed.

          * MAXOF-The combined extent of all input data. All features or cells
          will be processed.

          * Xmin, Ymin, XMax, YMax-Space-delimited coordinates that define the
          extent in the coordinate system in which the input data is stored. For
          example, "-107.0 38.0 -104.0 40.0"

          * pathname-Path to a dataset. The extent of the dataset will be used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ValidateNetworkTopology_un(*gp_fixargs((in_utility_network, extent), True)))
        return retval
    except Exception as e:
        raise e


# Administration toolset
@gptooldoc('AddDomainNetwork_un', None)
def AddDomainNetwork(in_utility_network=None, domain_network_name=None, tier_definition=None, subnetwork_controller_type=None, domain_network_alias_name=None):
    """AddDomainNetwork_un(in_utility_network, domain_network_name, tier_definition, subnetwork_controller_type, {domain_network_alias_name})

        Adds a domain network to a utility network.To learn more about adding
        a domain network, see Add a domain network.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network to which the domain network will be added.
      domain_network_name (String):
          The name for the new domain network. The domain network name will
          prefix the feature class names that are created. For example, a domain
          named ElectricDistribution would include a feature class named
          ElectricDistributionJunction.
      tier_definition (String):
          The tier definition that will be used for the new domain network.

          * HIERARCHICAL-A hierarchical tier definition. In hierarchical domain
          networks, tiers are nested within one another, so features existing in
          subnetworks for a lower tier naturally participate in all higher
          tiers. For example, in a gas network, a valve isolation zone is within
          a pressure zone, which in turn exists within a system zone. A feature
          in the isolation zone also exists in the pressure zone and in the
          system zone.

          * PARTITIONED-A partitioned tier definition. Features in partitioned
          domain networks only exist in one tier. The relationship between tiers
          is ordered and linear. Features can exist in one or multiple
          subnetworks with one tier.
      subnetwork_controller_type (String):
          The subnetwork controller type for the new domain network.

          * SOURCE-The subnetwork controller type is a set of sources. A source
          is an origin of the resource delivered. For example, for an electric
          system, sources of electricity are power generating stations and
          substations.

          * SINK-The subnetwork controller type is a set of sinks. A sink is the
          destination of the gathered resource.
      domain_network_alias_name {String}:
          You can optionally choose to give your domain network an alias name.
          This name is used to give a more descriptive name to the domain
          network."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddDomainNetwork_un(*gp_fixargs((in_utility_network, domain_network_name, tier_definition, subnetwork_controller_type, domain_network_alias_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddNetworkAttribute_un', None)
def AddNetworkAttribute(in_utility_network=None, attribute_name=None, attribute_type=None, is_inline=None, is_apportionable=None, domain=None, is_overridable=None, is_nullable=None, is_substitution=None, network_attribute_to_substitute=None):
    """AddNetworkAttribute_un(in_utility_network, attribute_name, attribute_type, {is_inline}, {is_apportionable}, {domain}, {is_overridable}, {is_nullable}, {is_substitution}, {network_attribute_to_substitute})

        Adds a network attribute to a utility network.  A network attribute is
        a value stored in the network topology
        derived from attributes on corresponding features in the network.
        While a network attribute can be associated with only one attribute on
        a feature class, there is no limit to the number of network attributes
        a single utility network can have. Network attributes are used as
        weights to control traversability and to model the cost of paths in
        the network.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The input utility network to add the network attribute to.
      attribute_name (String):
          The name of the network attribute to add to the utility network.
      attribute_type (String):
          The data type of the new attribute.

          * SHORT-Short integer type

          * LONG-Long integer type

          * DOUBLE-Double precision type

          * DATE-Date type
      is_inline {Boolean}:
          Specifies whether the attribute being added is embedded in the
          network topology in-line weights. In-line attribute storage is limited
          to 64 bits, most of which is reserved for system in-line weights. The
          size of the bits is determined by the domain parameter. In-line
          attributes are only supported for integer network attributes.

          * INLINE-The attribute will be added internally to the topology,
          making retrieval much more efficient.

          * NOT_INLINE-The attribute will be stored in an external table, and
          retrieval will require a call to the external weights table. This is
          the default.
      is_apportionable {Boolean}:
          Specifies whether the network attribute will be apportioned across
          multiple edges belonging to the same feature. For example, with the
          shape_length network attribute, if one line feature consisted of five
          edge elements, and if the total length of that line feature is 100
          feet, that attribute will be apportioned across all edges, giving 20
          feet for each. The distribution of the value depends on the percentage
          along each edge element with respect to the from point of the original
          feature. Apportionable network attributes can only be assigned to
          fields on line feature classes.

          * APPORTIONABLE-The network attribute is apportionable.

          * NOT_APPORTIONABLE-The network attribute is not apportionable. This
          is the default.
      domain {String}:
          The domain with which the new network attribute is to be associated.
          This parameter is required when is_inline is True. This domain is used
          to determine how many bits to allocate for the inline attribute and
          must be a coded value type. For example, the LifeCycleStatusDomain (0,
          Unknown | 1, In-Service | 2, Proposed | 3, Abandoned) domain has four
          entries, which means 2 bits are required to store the inline
          attribute. The coded value domain must have sequential codes starting
          from 0.
      is_overridable {Boolean}:
          This parameter is not used and any value you enter will be ignored for
          the current release. The functionality of this parameter is still
          under development and will be applicable in a future release.Whether a
          network attribute has an external override table that the network
          topology reads from and overrides (or overwrites) the current value
          stored in the topology. This could be used to input live data from
          external systems, such as present position in the case of electric or
          pressure value in the case of gas. An example could be a SCADA system
          pushing the updated switching positions of Device A to the override
          table of the DeviceStatus network attribute, which the topology engine
          then uses to override its current value of device status for Device A
          with the override value.

          * OVERRIDE-Override the current value stored in the topology.

          * NOT_OVERRIDABLE-Do not override the current value stored in the
          topology. This is the default.
      is_nullable {Boolean}:
          Specify if this network attribute supports null values.

          * NULLABLE-The network attribute supports null values.

          * NOT_NULLABLE-The network attribute does not support null values.
          This is the default.
      is_substitution {Boolean}:
          Specify if this network attribute is to be used as a substitution.
          Substitution network attributes allow you to use a substituted value
          instead of bitset network attribute values during a propagation in
          trace operation. If the network attribute is in-line, it cannot also
          be a substitution.

          * SUBSTITUTION-The network attribute is a substitution.

          * NOT_SUBSTITUTION-The network attribute is not a substitution. This
          is the default.
      network_attribute_to_substitute {String}:
          The network attribute to use for substitution. Substitutions are
          encoded based on the number of bits in the network attribute being
          propagated. The network attribute must be in-line and an integer field
          type less than or equal to 8 bits."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddNetworkAttribute_un(*gp_fixargs((in_utility_network, attribute_name, attribute_type, is_inline, is_apportionable, domain, is_overridable, is_nullable, is_substitution, network_attribute_to_substitute), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddNetworkCategory_un', None)
def AddNetworkCategory(in_utility_network=None, category_name=None):
    """AddNetworkCategory_un(in_utility_network, category_name)

        Adds a network category to an existing utility network. Categories are
        used to control analysis at the asset group and asset
        type levels; for example, you can define whether a particular asset
        group or asset type is a protective device. You can also define a
        category type to control how trace analysis is executed; for example,
        you can specify that a network trace ends at a user-defined category
        type of ProtectiveDevice. This tool allows you to add a new network
        category to a utility
        network that can be later assigned to a feature class at the asset
        group/asset type level using the Set Network Category tool.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The input utility network to add a network category to.
      category_name (String):
          The name of the category to be created."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddNetworkCategory_un(*gp_fixargs((in_utility_network, category_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddRule_un', None)
def AddRule(in_utility_network=None, rule_type=None, from_class=None, from_assetgroup=None, from_assettype=None, to_class=None, to_assetgroup=None, to_assettype=None, from_terminal=None, to_terminal=None, via_class=None, via_assetgroup=None, via_assettype=None, via_terminal=None):
    """AddRule_un(in_utility_network, rule_type, from_class, from_assetgroup, from_assettype, to_class, to_assetgroup, to_assettype, {from_terminal}, {to_terminal}, {via_class}, {via_assetgroup}, {via_assettype}, {via_terminal})

        Adds a rule to a utility network. All rules created within a utility
        network are based on the feature
        class at the asset group and asset type level and can be used to
        control some behaviors in the utility network.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network for which the rule will be added.
      rule_type (String):
          The type of rule to be created.

          * JUNCTION_JUNCTION_CONNECTIVITY-Creates a junction-junction
          connectivity association rule allowing two points to connect via a
          connectivity association (features are offset geometrically).

          * CONTAINMENT-Creates a containment association rule where the from
          parameters are the container and the to parameters are the contents.

          * STRUCTURAL_ATTACHMENT-Creates a structural attachment association
          rule where the from parameters are the structure and the to parameters
          are the structural attachments.

          * JUNCTION_EDGE_CONNECTIVITY-Creates an edge-junction connectivity
          rule allowing a line and a junction to connect via geometric
          coincidence (features are at the same x, y, z location).

          * EDGE_JUNCTION_EDGE_CONNECTIVITY-Creates an edge-junction-edge
          connectivity rule allowing a certain type of line to connect to either
          side of a junction feature.
      from_class (String):
          The from utility network feature class that will be included in the
          rule.Structural attachment and containment association rules require
          the
          container or structure feature be in this parameter.Ordering is
          irrelevant for the junction-junction, junction-edge, and
          edge-junction-edge connectivity rules.
      from_assetgroup (String):
          An asset group for the from_class to which the rule will apply.
      from_assettype (String):
          An asset type for the from_class to which the rule will apply.
      to_class (String):
          The to utility network feature class that will be included in the
          rule.Structural attachment and containment associations rules require
          the
          content or attachment feature be in this parameter.Ordering is
          irrelevant for the junction-junction, junction-edge, and
          edge-junction-edge connectivity rules.
      to_assetgroup (String):
          An asset group for the to_class to which the rule will apply.
      to_assettype (String):
          An asset type for the to_class to which the rule will apply.
      from_terminal {String}:
          The from terminal to which the rule will apply. This will be a
          terminal in the from_class. When creating a connectivity rule for a
          line or point to connect to a feature with terminals, the terminal
          side to connect to must be specified. For example, the high side
          terminal on a transformer.This parameter will be ignored for
          structural attachment or
          containment attachment rule types.
      to_terminal {String}:
          The to terminal to which the rule will apply. This will be a terminal
          of the to_class. When creating either type of connectivity rule for a
          line or point to connect to a feature with terminals, the terminal
          side to connect to must be specified. For example, the high side
          terminal on a transformer.This parameter will be ignored for
          structural attachment or
          containment attachment rule types.
      via_class {String}:
          The junction utility network feature class to which the rule will
          apply. This parameter can be specified only for the
          EDGE_JUNCTION_EDGE_CONNECTIVITY rule_type since three feature classes
          are required to participate in edge-junction-edge connectivity.
      via_assetgroup {String}:
          An  asset group of the via_class to which the rule will apply. This
          parameter can only be specified for the
          EDGE_JUNCTION_EDGE_CONNECTIVITY rule_type parameter value.
      via_assettype {String}:
          An asset type of the via_class to which the rule will apply. This
          parameter can only be specified for the
          EDGE_JUNCTION_EDGE_CONNECTIVITY rule_type parameter value.
      via_terminal {String}:
          The terminal from the via_class to which the rule will apply. This
          parameter can only be specified for the
          EDGE_JUNCTION_EDGE_CONNECTIVITY rule_type parameter value."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddRule_un(*gp_fixargs((in_utility_network, rule_type, from_class, from_assetgroup, from_assettype, to_class, to_assetgroup, to_assettype, from_terminal, to_terminal, via_class, via_assetgroup, via_assettype, via_terminal), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddTerminalConfiguration_un', None)
def AddTerminalConfiguration(in_utility_network=None, terminal_configuration_name=None, traversability_model=None, terminals_directional=None, terminals_bidirectional=None, valid_paths=None, default_path=None):
    """AddTerminalConfiguration_un(in_utility_network, terminal_configuration_name, traversability_model, {terminals_directional;terminals_directional...}, {terminals_bidirectional;terminals_bidirectional...}, {valid_paths;valid_paths...}, {default_path})

        Adds a terminal configuration to an existing utility network. Specific
        devices with terminals require constraints that define the
        valid configuration of the internal connectivity of the device. This
        tool allows you to add a new terminal configuration to a utility
        network that can be later assigned to a feature class at the asset
        group/asset type level using the Set Terminal Configuration tool.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The input utility network to add the terminal configuration to.
      terminal_configuration_name (String):
          The name for the terminal configuration.
      traversability_model (String):
          Choose the directionality of the terminal configuration. A
          directional traversability model means that the flow for the terminal
          will only go in one direction. A bidirectional traversability model
          means that the terminal allows flow in both directions.

          * DIRECTIONAL-Only one flow direction is permissible.

          * BIDIRECTIONAL-Both flow directions are permissible.
      terminals_directional {Value Table}:
          If the traversability model is directional, provide the name of each
          terminal and specify whether the terminal is upstream or not. The
          minimum number of terminals required is 2. This parameter is required
          if you choose a directional traversability model.

          * Name-The name of the terminal.

          * Upstream-Whether the terminal is upstream or downstream. Use the
          keyword True if the terminal is upstream, or False if the terminal is
          downstream.
      terminals_bidirectional {Value Table}:
          If the traversability model is bidirectional, provide the names of
          each bidirectional terminal. A minimum of two terminals is required.
      valid_paths {Value Table}:
          Specify the valid paths for the terminal configuration. For
          bidirectional traversability, this parameter is required if you have
          three or more terminals. If you are using directional traversability,
          one of the terminals must be upstream in order to have any valid
          configurations. Valid paths must be set in order to indicate which of
          the paths within a device are valid for a resource to travel through.
          Provide a name for each valid path and specify a value.

          * Name-The name of the valid path.

          * Value-The value of the path.

          * All-Indicates all paths are valid.

          * None-Indicates no paths are valid.

          * Terminal pair-Indicates a single path from one terminal to another,
          for example, A-B.

          * Collection of terminal pairs-Indicates a collection of single paths
          from one terminal to another, for example, A-B,A-C.
      default_path {String}:
          Of the valid configurations specified, you may set the default path.
          This will be assigned to new features that have this terminal
          configuration assigned to their asset type. If you have not specified
          one of the valid configurations, the default configuration will be
          All.

          * All-Indicates all paths are valid. This is the default.

          * None-Indicates no paths are valid.

          * Valid path-Specify a valid path defined in the Valid Path(s)
          parameter.

          * ALL-Indicates all paths are valid. This is the default.

          * NONE-Indicates no paths are valid."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddTerminalConfiguration_un(*gp_fixargs((in_utility_network, terminal_configuration_name, traversability_model, terminals_directional, terminals_bidirectional, valid_paths, default_path), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddTier_un', None)
def AddTier(in_utility_network=None, domain_network=None, name=None, rank=None, topology_type=None, tier_group_name=None, subnetwork_field_name=None):
    """AddTier_un(in_utility_network, domain_network, name, rank, {topology_type}, {tier_group_name}, {subnetwork_field_name})

        Creates a new tier for a specific domain network in a utility
        network. Tiers are collections of subnetworks that share the same
        level, name
        restrictions, and topology type. Tiers are required for subnetwork
        management. For hierarchical tier types, this tool can be used to add
        a new tier within a tier group. Tier groups can be created by using
        the Add Tier Group tool.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network that contains the domain network to add a tier to.
      domain_network (String):
          The domain network to create the tier in.
      name (String):
          A name for the new tier. The name must be unique in the entire
          utility network.
      rank (Long):
          The rank of the tier being added. The highest rank is the number 1.
      topology_type {String}:
          The topology type for the new tier: radial or mesh. Radial means the
          subnetworks in the tier are provided by one source. Mesh means the
          subnetworks in the tier are provided by multiple sources. If the input
          domain network was created with a hierarchical tier definition, the
          default topology type is MESH. If the input domain network was created
          with a partitioned tier definition, the topology type parameter is
          required.

          * RADIAL-The subnetworks are fed by one source, a nonlooped path with
          only one subnetwork controller.

          * MESH-The subnetworks are fed by multiple sources, a closed path
          (loop) with one or more subnetwork controllers. This is the default
          topology type for a tier created with a hierarchical tier definition.
      tier_group_name {String}:
          The existing tier group for which the new tier will be added. This
          parameter is required for hierarchical tier types.
      subnetwork_field_name {String}:
          The name of field that the subnetwork names for this tier will be
          stored in. This parameter is required for hierarchical tier types."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddTier_un(*gp_fixargs((in_utility_network, domain_network, name, rank, topology_type, tier_group_name, subnetwork_field_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddTierGroup_un', None)
def AddTierGroup(in_utility_network=None, domain_network=None, name=None):
    """AddTierGroup_un(in_utility_network, domain_network, name)

        Add a tier group to a domain network within a utility network.This
        tool is used to add a new tier group to an existing domain
        network within a utility network. When a tier group exists, the Add
        Tier tool can be used to add tiers to the tier group.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network that contains the domain network to create the
          tier group in.
      domain_network (String):
          The name of the domain network to add the tier group to. Tier groups
          can only be added to domain networks that have a hierarchical tier
          definition.
      name (String):
          A unique name for the new tier group up to 64 characters in length."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddTierGroup_un(*gp_fixargs((in_utility_network, domain_network, name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateUtilityNetwork_un', None)
def CreateUtilityNetwork(in_feature_dataset=None, in_utility_network_name=None, service_territory_feature_class=None):
    """CreateUtilityNetwork_un(in_feature_dataset, in_utility_network_name, service_territory_feature_class)

        Creates a utility network in an enterprise geodatabase feature
        dataset. A utility network is created and a structure network is added
        with
        its collection of feature classes within the target feature dataset.
        The structure feature classes will be shared across all domain
        networks as they are created and configured for the utility
        network.For more details about system requirements and supported
        databases,
        see Create a utility network..

     INPUTS:
      in_feature_dataset (Feature Dataset):
          The enterprise geodatabase feature dataset in which the utility
          network and schema will be created.
      in_utility_network_name (String):
          The name for the utility network that will be created.
      service_territory_feature_class (Polygon):
          The existing polygon feature class that will be used to create the
          utility network's geographical extent. Utility network features cannot
          be created outside of this extent.The feature class must be z- and
          m-enabled."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateUtilityNetwork_un(*gp_fixargs((in_feature_dataset, in_utility_network_name, service_territory_feature_class), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DeleteNetworkCategory_un', None)
def DeleteNetworkCategory(in_utility_network=None, category_name=None):
    """DeleteNetworkCategory_un(in_utility_network, category_name)

        Deletes a network category in a utility network.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network that contains the network category to be deleted.
      category_name (String):
          The name of the network category to delete."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DeleteNetworkCategory_un(*gp_fixargs((in_utility_network, category_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DeleteRule_un', None)
def DeleteRule(in_utility_network=None, rule_type=None, rule_desc=None):
    """DeleteRule_un(in_utility_network, rule_type, {rule_desc})

        Permanently deletes a rule from a utility network.To delete an
        association rule, there cannot be any features that
        participate in the association rule. Any associations must be deleted
        first before deleting the rule. Association rules include junction-
        junction connectivity, containment, and structural attachment.When a
        junction-edge connectivity rule is deleted, any features
        participating in the rule will be marked with error features when the
        network topology is validated.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network for which the rule will be removed.
      rule_type (String):
          The type of rule being deleted.

          * ALL-Delete all rules.

          * JUNCTION_JUNCTION_CONNECTIVITY-Delete a junction-junction
          connectivity association rule.

          * CONTAINMENT-Delete a containment association rule.

          * STRUCTURAL_ATTACHMENT-Delete a structural attachment association
          rule.

          * JUNCTION_EDGE_CONNECTIVITY-Delete a junction-edge connectivity rule.

          * EDGE_JUNCTION_EDGE_CONNECTIVITY-Delete an edge-junction-edge
          connectivity rule.
      rule_desc {String}:
          Specify which rule to remove. This includes the rule ID and the
          description of the rule. You can find the rule ID by browsing the
          Rules section of the Network
          Properties, which is available on the Layer Properties dialog box."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DeleteRule_un(*gp_fixargs((in_utility_network, rule_type, rule_desc), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DeleteTerminalConfiguration_un', None)
def DeleteTerminalConfiguration(in_utility_network=None, terminal_configuration_name=None):
    """DeleteTerminalConfiguration_un(in_utility_network, terminal_configuration_name)

        Deletes a terminal configuration in a utility network.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network that contains the terminal configuration to be
          deleted.
      terminal_configuration_name (String):
          The name of the terminal configuration to delete."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DeleteTerminalConfiguration_un(*gp_fixargs((in_utility_network, terminal_configuration_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DisableNetworkTopology_un', None)
def DisableNetworkTopology(in_utility_network=None):
    """DisableNetworkTopology_un(in_utility_network)

        Disables the network topology for an existing utility network.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network for which the network topology will be disabled."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DisableNetworkTopology_un(*gp_fixargs((in_utility_network,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('EnableNetworkTopology_un', None)
def EnableNetworkTopology(in_utility_network=None, max_number_of_errors=None, only_generate_errors=None):
    """EnableNetworkTopology_un(in_utility_network, {max_number_of_errors}, {only_generate_errors})

        Enables the network topology for a utility network.The network
        topology is needed for analytic and diagram operations.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network for which the network topology will be enabled.
      max_number_of_errors {Long}:
          The maximum number of errors before the process of enabling the
          network topology will stop and errors will be recorded to the errors
          table. The default value is 10000. Setting a value of 0 will ignore
          the restriction for max errors.
      only_generate_errors {Boolean}:
          Whether or not to generate network errors only.

          * ONLY_ERRORS-The utility network will only be evaluated for network
          errors. The topology will not be enabled and the data will not be
          required to be registered as versioned. This allows you to inspect and
          fix errors in the network until you are ready to register the data as
          versioned and enable the topology.

          * ENABLE_TOPO-Enable the topology. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.EnableNetworkTopology_un(*gp_fixargs((in_utility_network, max_number_of_errors, only_generate_errors), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExportAssociations_un', None)
def ExportAssociations(in_utility_network=None, association_type=None, out_csv_file=None):
    """ExportAssociations_un(in_utility_network, association_type, out_csv_file)

        Exports connectivity, containment, and structural attachment
        associations from a utility network into a comma separated values
        file. All types of associations can be exported including junction-
        junction
        connectivity, structural attachment, and containment.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network to export the associations from.
      association_type (String):
          The type of association to export.

          * ALL-All associations in the utility network are exported to a .csv.

          * JUNCTION_JUNCTION_CONNECTIVITY-Connectivity associations allowing
          two junction subtypes to connect via a connectivity association
          (features are offset geometrically) are exported to a .csv.

          * CONTAINMENT-Containment associations are exported to a .csv.

          * STRUCTURAL_ATTACHMENT-Structural attachment associations are
          exported to a .csv.

     OUTPUTS:
      out_csv_file (File):
          A name and location for the .csv file that will be generated."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportAssociations_un(*gp_fixargs((in_utility_network, association_type, out_csv_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExportRules_un', None)
def ExportRules(in_utility_network=None, rule_type=None, out_csv_file=None):
    """ExportRules_un(in_utility_network, rule_type, out_csv_file)

        Exports connectivity, structural attachment, and containment rules
        from a utility network into a comma-separated values file.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network to export the rules from.
      rule_type (String):
          The type of rule to export.

          * ALL-All the rules in the utility network will be exported.

          * JUNCTION_JUNCTION_CONNECTIVITY-Junction-junction connectivity
          association rules will be exported.

          * JUNCTION_EDGE_CONNECTIVITY-Junction-edge connectivity rules will be
          exported.

          * CONTAINMENT-Containment association rules are will be exported.

          * STRUCTURAL_ATTACHMENT-Structural attachment association rules will
          be exported.

          * EDGE_JUNCTION_EDGE_CONNECTIVITY-Edge-junction-edge connectivity
          association rules will be exported.

     OUTPUTS:
      out_csv_file (File):
          The folder location and name of the .csv file to be created."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportRules_un(*gp_fixargs((in_utility_network, rule_type, out_csv_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExportSubnetworkControllers_un', None)
def ExportSubnetworkControllers(in_utility_network=None, out_csv_file=None):
    """ExportSubnetworkControllers_un(in_utility_network, out_csv_file)

        Exports subnetwork controllers from a utility network into a .csv
        file. Subnetwork controllers are features that have been set as
        subnetwork
        controllers using the Modify Subnetwork Controller pane. The exported
        .csv file will contain information about the device features that are
        currently set as subnetwork controllers.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network from which subnetwork controllers will be
          exported.

     OUTPUTS:
      out_csv_file (File):
          The location and name for the .csv file to be generated."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportSubnetworkControllers_un(*gp_fixargs((in_utility_network, out_csv_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportAssociations_un', None)
def ImportAssociations(in_utility_network=None, association_type=None, csv_file=None):
    """ImportAssociations_un(in_utility_network, association_type, csv_file)

        Import connectivity, containment, and structural attachment
        associations from a comma-separated values file into an existing
        utility network.Associations must be imported from a single .csv file.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network receiving the associations.
      association_type (String):
          The type of associations to import.

          * ALL-One or more types of associations

          * JUNCTION_JUNCTION_CONNECTIVITY-Junction-junction connectivity
          associations type

          * CONTAINMENT-Containment associations type

          * STRUCTURAL_ATTACHMENT-Structural attachment associations type
      csv_file (File):
          The .csv file containing the associations to import."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportAssociations_un(*gp_fixargs((in_utility_network, association_type, csv_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportRules_un', None)
def ImportRules(in_utility_network=None, rule_type=None, csv_file=None):
    """ImportRules_un(in_utility_network, rule_type, csv_file)

        Import connectivity, structural attachment, and containment rules
        from a comma-separated values file into an existing utility network.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network to import the rules to.
      rule_type (String):
          The type of rules to import.

          * ALL-One or more types of rules

          * JUNCTION_JUNCTION_CONNECTIVITY-Junction-junction connectivity
          association rules

          * JUNCTION_EDGE_CONNECTIVITY-Junction-edge connectivity rules

          * CONTAINMENT-Containment association rules

          * STRUCTURAL_ATTACHMENT-Structural attachment association rules

          * EDGE_JUNCTION_EDGE_CONNECTIVITY-Edge-junction-edge association
          rules
      csv_file (File):
          The .csv file containing the rules to import."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportRules_un(*gp_fixargs((in_utility_network, rule_type, csv_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportSubnetworkControllers_un', None)
def ImportSubnetworkControllers(in_utility_network=None, csv_file=None):
    """ImportSubnetworkControllers_un(in_utility_network, csv_file)

        Imports subnetwork controllers from a .csv file into a utility
        network.The imported .csv file will modify properties on existing
        features in
        the utility network to set these features as subnetwork controllers.
        Subnetwork controllers are needed to work with utility network trace
        analytics.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network for which the subnetwork controllers will be
          imported.
      csv_file (File):
          The .csv file containing the subnetwork controllers to import."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportSubnetworkControllers_un(*gp_fixargs((in_utility_network, csv_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SetAssociationRole_un', None)
def SetAssociationRole(in_utility_network=None, domain_network=None, featureclass=None, assetgroup=None, assettype=None, association_role_type=None, association_deletion_semantics=None, view_scale=None):
    """SetAssociationRole_un(in_utility_network, domain_network, featureclass, assetgroup, assettype, association_role_type, association_deletion_semantics, {view_scale})

        Alters the role assigned to a class at the asset type level.Roles
        define how an asset type participates in a utility network. To
        learn more about association roles, see the set an association role
        topic.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network which contains the asset type to set an
          association role.
      domain_network (String):
          The domain network which contains the asset type to set an
          association role.
      featureclass (String):
          The utility network assembly or structural feature class which
          contains the asset type to set an association role.
      assetgroup (String):
          The asset group which contains the asset type.
      assettype (String):
          The asset type to set the association role.
      association_role_type (String):
          The type of association role to assign to the asset type.

          * CONTAINER-Features of this asset type can contain other features as
          contents.

          * STRUCTURE-Features of this asset type can have other features
          attached to them.

          * NONE-No role type. These are features that are neither a container
          or a structure, but does connect to other structures.
      association_deletion_semantics (String):
          The deletion semantics for the features.

          * CASCADE-All content is deleted when the parent container is deleted.
          Content features are permanently deleted.

          * SET_TO_NONE-All containment associations are removed. Content
          features are now regular features in the map.

          * RESTRICTED-Upon deletion, if content exists in the container, an
          error is returned. You must then either delete the content features or
          remove them from the container by deleting the association (placing
          them outside of the container).
      view_scale {Double}:
          The scale at which to enter containment mode to edit features
          participating in the container. For example, setting the view scale to
          5 means that when you enter containment mode of the container feature,
          the scale will be 1:5. Units are based on the utility network units
          which can be found on the Source tab of the utility network layer
          properties."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SetAssociationRole_un(*gp_fixargs((in_utility_network, domain_network, featureclass, assetgroup, assettype, association_role_type, association_deletion_semantics, view_scale), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SetEdgeConnectivity_un', None)
def SetEdgeConnectivity(in_utility_network=None, domain_network=None, line_featureclass=None, assetgroup=None, assettype=None, edge_connectivity=None):
    """SetEdgeConnectivity_un(in_utility_network, domain_network, line_featureclass, assetgroup, assettype, edge_connectivity)

        Defines how features will connect to a line of a given asset type.
        There are two locations where point features can connect to lines: an
        end point or a mid-span vertex. Each asset type in the domain network
        is set with a default edge connectivity setting.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network that contains the asset type to set the edge
          connectivity.
      domain_network (String):
          The domain network that contains the asset type to set the edge
          connectivity.
      line_featureclass (String):
          The name of the line feature class that contains the asset type to
          set the edge connectivity.
      assetgroup (String):
          The asset group that has the asset type to set the edge connectivity.
      assettype (String):
          The asset type for which to update the edge connectivity setting.
      edge_connectivity (String):
          The edge connectivity type to assign to the asset type.

          * ANY_VERTEX-Allows features to connect anywhere along the line where
          a vertex is present. This includes end vertices.

          * END_VERTEX-Allows features to only connect to the end vertex of the
          line."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SetEdgeConnectivity_un(*gp_fixargs((in_utility_network, domain_network, line_featureclass, assetgroup, assettype, edge_connectivity), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SetNetworkAttribute_un', None)
def SetNetworkAttribute(in_utility_network=None, network_attribute=None, domain_network=None, featureclass=None, field=None):
    """SetNetworkAttribute_un(in_utility_network, network_attribute, domain_network, featureclass, field)

        Assigns a network attribute to a feature class at the asset type level
        to be used during tracing operations. A utility network can have a set
        of network attributes associated
        with it. A network attribute is a value stored in the network topology
        derived from attributes on corresponding features in the network.
        While a network attribute can be associated with only one attribute on
        a feature class, there is no limit to the number of network attributes
        a single utility network can have. Network attributes are used as
        weights to control traversability and to model the cost of paths in
        the network.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network that contains the network attribute to set.
      network_attribute (String):
          The network attribute to be assigned to the feature class field.
      domain_network (String):
          The domain network that contains the feature class which is going to
          have a network attribute set on it.
      featureclass (String):
          The input feature class which contains the field that will be used to
          set the network attribute.
      field (String):
          An existing field that will be assigned the network attribute. The
          field data type must match the data type of the network attribute. For
          example, if the network attribute is a short integer type, the field
          must also be a short integer type."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SetNetworkAttribute_un(*gp_fixargs((in_utility_network, network_attribute, domain_network, featureclass, field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SetNetworkCategory_un', None)
def SetNetworkCategory(in_utility_network=None, domain_network=None, featureclass=None, assetgroup=None, assettype=None, category=None):
    """SetNetworkCategory_un(in_utility_network, domain_network, featureclass, assetgroup, assettype, {category;category...})

        Assigns a network category to a feature class at the asset type level
        to be used during tracing operations. Categories are defined on asset
        types to constrain the beginning and
        end of several analytical traces.Learn more about network categories

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network that contains the network category.
      domain_network (String):
          The domain network within the utility network that contains the
          network category.
      featureclass (String):
          The utility network feature class the asset type belongs to.
      assetgroup (String):
          The asset group that the asset type belongs to.
      assettype (String):
          The asset type to alter the category configuration.
      category {String}:
          The categories to be assigned to the asset type. The categories that
          are specified for this parameter will replace the current categories
          that are assigned to the asset type. To unassign a network category
          from an asset type, do not specify a category for this
          parameter.Subnetwork controllers in a domain network with a
          partitioned tier
          definition, must first have a directional terminal configuration
          assigned before the network category can be set."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SetNetworkCategory_un(*gp_fixargs((in_utility_network, domain_network, featureclass, assetgroup, assettype, category), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SetSubnetworkDefinition_un', None)
def SetSubnetworkDefinition(in_utility_network=None, domain_network=None, tier_name=None, support_disjoint_subnetwork=None, valid_devices=None, valid_subnetwork_controller=None, valid_lines=None, aggregated_line=None, diagram_template=None, summaries=None, condition_barriers=None, function_barriers=None, include_barriers=None, traversability_scope=None, propagators=None):
    """SetSubnetworkDefinition_un(in_utility_network, domain_network, tier_name, support_disjoint_subnetwork, valid_devices;valid_devices..., valid_subnetwork_controller;valid_subnetwork_controller..., valid_lines;valid_lines..., aggregated_line;aggregated_line..., {diagram_template;diagram_template...}, {summaries;summaries...}, {condition_barriers;condition_barriers...}, {function_barriers;function_barriers...}, {include_barriers}, {traversability_scope}, {propagators;propagators...})

        Sets the properties for a subnetwork in a utility network. The types
        of features that participate in a tier can be restricted by
        defining valid asset types from the device and line feature classes.
        Defining valid asset types helps enforce data correctness by limiting
        the types of features that can participate in a subnetwork for a
        specific tier.Configuration parameters can be used to set properties
        for when a
        trace is executed on the subnetwork.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The input utility network that contains the subnetwork.
      domain_network (String):
          The domain network that contains the subnetwork.
      tier_name (String):
          The name of the tier that contains the subnetwork.
      support_disjoint_subnetwork (Boolean):
          Whether or not the tier supports disjointed subnetworks. Disjointed
          subnetworks are two or more subnetworks that belong to the same tier
          and have the same subnetwork name but are not traversable.  Tiers in a
          domain with a hierarchical definition do not support disjointed
          networks.

          * SUPPORT_DISJOINT-The input tier does support disjointed
          subnetworks.

          * NO_DISJOINT-The input tier does not support disjointed subnetworks.
          This is the default.
      valid_devices (String):
          The list of asset group/asset type pairs that will be considered as
          valid devices for the subnetwork.
      valid_subnetwork_controller (String):
          The list of asset group/asset type pairs that can become subnetwork
          controllers in the subnetwork.
      valid_lines (String):
          The list of asset group/asset type pairs that will be considered as
          valid lines for the subnetwork.
      aggregated_line (String):
          The valid lines whose geometry will be aggregated to generate the
          SubnetLine features. This list is a subset of the values specified in
          the valid_lines parameter.
      diagram_template {String}:
          The templates that will be used to generate subnetwork system diagrams
          for each subnetwork.
      summaries {Value Table}:
          Set the summary field to store function results when inserting or
          updating SubnetLine features.Summaries components:

          * Function-Choose from a number of different calculation functions.

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Filter Name-Choose to filter the function results by attribute name.

          * Filter Operator-Choose from a number of different operators.

          * Filter Type-Choose from a number of different filter types.

          * Filter Value-Specific value of the input filter attribute.

          * Summary Attribute-The field in the SubnetLine feature class that
          will persist the function result. Depending on the selected function
          and network attribute type, only the applicable type of user-added
          subnetwork attributes will be valid for this parameter. In the case of
          hierarchical domain networks, only the attributes added to both
          SubnetLine and SubnetZone will be valid for the Summary Attribute
          parameter. See the following matrix of valid field types for the
          various functions:
          Possible values for the summaries Function options are as follows:

          * AVERAGE-The average of the input values.

          * COUNT-The number of features.

          * MAX-The maximum of the input values.

          * MIN-The minimum of the input values.

          * ADD-Add the values.

          * SUBTRACT-Subtract the values.
          Possible values for the summaries Filter Type options are as follows:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
          The Filter Operator value options are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          specific values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
      condition_barriers {Value Table}:
          Set a traversability barrier condition on features based on a
          comparison to a network attribute or check for a category string. A
          condition barrier uses a network attribute, an operator and type, and
          an attribute value. For example, stop a trace when a feature has the
          attribute Device Status equal to the specific value of Open. When a
          feature meets this condition, the trace stops. If using more than one
          attribute, you can use the Combine using parameter to define an And or
          an Or condition.Condition barrier components:

          * Name-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Type-Choose a specific value or network attribute from the value
          that is specified in the name parameter.

          * Value-Specific value of the input attribute type that would cause
          termination based on the operator value.

          * Combine Using-You can set this value if you have multiple attributes
          to add. You can choose to combine them using an Add or an Or
          condition.
          The condition barriers operator values are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          Possible values for the Type options are as follows:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
          The Combine Using values are as follows:

          * AND-Combine the condition barriers.

          * OR-Use if either condition barrier is met.
      function_barriers {Value Table}:
          Set a traversability barrier on features based on a function. Function
          barriers can be used to do such things as restrict how far the trace
          travels from the starting point, or set a maximum value to stop a
          trace at. For example, the length of each line traveled is added to
          the total distance traveled so far. When the total length traveled
          reaches the value specified, the trace stops.Function barrier
          components:

          * Function-Choose from a number of different calculation functions.

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Value-Specific value of the input attribute type that, if
          discovered, will cause the termination.

          * Use Local Values-Calculates values in each direction as opposed to
          an overall global value, for example, for a function barrier that is
          calculating the sum of Shape length where the trace terminates if the
          value is greater than or equal to 4. In the global case, after you
          have traversed two edges with a value of 2, you have already reached a
          shape length sum of 4, so the trace stops. If local values are used,
          the local values along each path change, so the trace goes farther.
          Possible values for the function barrier function options are as
          follows:

          * AVERAGE-The average of the input values.

          * COUNT-The number of features.

          * MAXIMUM-The maximum of the input values.

          * MINIMUM-The minimum of the input values.

          * ADD-Add the values.

          * SUBTRACT-Subtract the values.
          The function barrier operator value options are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          The function barrier Use Local Values options are as follows:

          * TRUE-Use local values.

          * FALSE-Use global values. This is the default.
      include_barriers {Boolean}:
          Define whether the traversability barrier features are included in the
          trace results. Traversability barriers are optional even if they have
          been preset in the subnetwork definition.

          * INCLUDE_BARRIERS-Traversability barriers are included in the trace
          results. This is the default.

          * EXCLUDE_BARRIERS-Traversability barriers are ignored in the trace
          results.
      traversability_scope {String}:
          The type of traversability to enforce. Traversability scope dictates
          whether traversability is enforced at junctions, edges, or both. For
          example, if a condition barrier is defined to stop the trace if Device
          Status is equal to Open and traversability scope is set to edges only,
          then even if the trace encounters an open device the trace would not
          stop, because the Device Status is only applicable for junctions. In
          other words, this parameter tells the trace whether or not to ignore
          junctions, edges, or both.

          * BOTH_JUNCTIONS_AND_EDGES-Apply traversability to both junctions and
          edges.

          * JUNCTIONS_ONLY-Apply traversability to only junctions.

          * EDGES_ONLY-Apply traversability to only edges.
      propagators {Value Table}:
          Define which network attributes to propagate as well as how that
          propagation should happen during a trace. Propagated class attributes
          denote the key values on subnetwork controllers that are disseminated
          to the rest of the features in the subnetwork. For example, in an
          electric distribution model, you may propagate the phase
          value.Propagators components:

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Substitution Attribute-Use a substituted value instead of bitset
          network attribute values. Substitutions are encoded based on the
          number of bits in the network attribute being propagated.

          * Function-Choose from a number of different calculation functions.

          * Operator-Choose from a number of different operators.

          * Value-Specific value of the input attribute type that would cause
          termination based on the operator value.
          Possible values for the propagators function are as follows:

          * PROPAGATED_BITWISE_AND-Compare the values from one feature to the
          next.

          * PROPAGATED_MIN-Get the minimum value.

          * PROPAGATED_MAX-Get the maximum value.
          The propagator operator values are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          This parameter is only available via Python."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SetSubnetworkDefinition_un(*gp_fixargs((in_utility_network, domain_network, tier_name, support_disjoint_subnetwork, valid_devices, valid_subnetwork_controller, valid_lines, aggregated_line, diagram_template, summaries, condition_barriers, function_barriers, include_barriers, traversability_scope, propagators), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SetTerminalConfiguration_un', None)
def SetTerminalConfiguration(in_utility_network=None, domain_network=None, device_featureclass=None, assetgroup=None, assettype=None, terminal_configuration=None):
    """SetTerminalConfiguration_un(in_utility_network, domain_network, device_featureclass, assetgroup, assettype, terminal_configuration)

        Assigns a terminal configuration to an asset type in a utility
        network.Once a terminal configuration has been established, it can be
        assigned
        to an asset type in the device feature class. This tool allows you to
        set the terminal configuration for a utility network asset type in the
        device class. When a terminal configuration is assigned to an asset
        type, a feature created with that asset type will have terminals. More
        specifically, the feature will have the terminals specified for the
        terminal configuration.To understand what the underlaying terminals
        are for each asset type,
        refer to the Terminal Configuration section on the Network Properties
        page of the utility network layer properties.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network that contains the terminal configuration that
          will be set on a specific asset type.
      domain_network (String):
          The domain network to which the asset type belongs.
      device_featureclass (String):
          The utility network device feature class to which the asset type
          belongs.
      assetgroup (String):
          The asset group to which the asset type belongs.
      assettype (String):
          The asset type receiving the terminal configuration.
      terminal_configuration (String):
          The terminal configuration to be assigned to the asset type."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SetTerminalConfiguration_un(*gp_fixargs((in_utility_network, domain_network, device_featureclass, assetgroup, assettype, terminal_configuration), True)))
        return retval
    except Exception as e:
        raise e


# Network Diagrams toolset
@gptooldoc('AlterDiagramProperties_un', None)
def AlterDiagramProperties(in_network_diagram_layer=None, out_name=None, access_right_type=None, tags=None):
    """AlterDiagramProperties_un(in_network_diagram_layer, {out_name}, {access_right_type}, {tags})

        Alters properties for any stored network diagram.The diagram owner and
        the utility network owner are the only users who
        can run the Set Diagram Properties tool.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The stored network diagram to alter.
      out_name {String}:
          The new name for the input network diagram.
      access_right_type {String}:
          The access right level of the input diagram.

          * PUBLIC-All users will have full access to the diagram; everyone can
          see, edit, update, and overwrite the diagram. However, no one except
          the diagram owner and the utility network owner will have rights to
          delete the diagram or change its properties using the Set Diagram
          Properties tool. This is the default.

          * PROTECTED-Other users will have read-only access to the diagram.
          They cannot edit, update, or overwrite the diagram.

          * PRIVATE-Other users will not have access to the diagram. The
          corresponding diagram item will be hidden from any other users in the
          Find Diagrams pane.
      tags {String}:
          One or several tags that would help find the stored diagram. These
          tags are searched through in the Find Diagrams pane afterwards.To add
          several tags use the # character to separate each tag. This
          also allows for more thorough and efficient diagram searching."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AlterDiagramProperties_un(*gp_fixargs((in_network_diagram_layer, out_name, access_right_type, tags), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AppendToDiagram_un', None)
def AppendToDiagram(in_network_diagram_layer=None, map=None):
    """AppendToDiagram_un(in_network_diagram_layer, map)

        Appends selected utility network features to a network diagram.If you
        have an open edit session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram layer to which selected utility network features
          will be appended.
      map (Map):
          The map with selected utility network features to append to the
          network diagram."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AppendToDiagram_un(*gp_fixargs((in_network_diagram_layer, map), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateDiagram_un', None)
def CreateDiagram(in_utility_network=None, template_name=None, features=None):
    """CreateDiagram_un(in_utility_network, template_name, {features;features...})

        Creates a network diagram from utility network features currently
        selected in one or more layers in the active map or from feature
        layers created from a Python script.Edits must be saved so that the
        output diagram is in sync with the
        last save moment of the network topology in the database. Otherwise,
        the unsaved edits will not be reflected in the new diagram.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network from which the diagram will be created.
      template_name (String):
          The name of the template used to create the diagram.
      features {Feature Layer}:
          One or more feature layers or feature classes to use as input for
          diagram generation."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateDiagram_un(*gp_fixargs((in_utility_network, template_name, features), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DeleteDiagram_un', None)
def DeleteDiagram(in_diagrams=None, template_names=None, diagram_names=None):
    """DeleteDiagram_un(in_diagrams, {template_names;template_names...}, {diagram_names;diagram_names...})

        Deletes one or more network diagrams, which are optionally filtered by
        their diagram template names, related to a given utility network.You
        can specify a single diagram, a set of diagrams, or a diagram
        template name. When you delete a diagram template, all associated
        diagrams are deleted as well. You must save any edits prior to
        deleting a diagram.

     INPUTS:
      in_diagrams (Utility Network Layer / Utility Network / Diagram Layer):
          The utility network data element or layer with one or more diagrams
          to be deleted.
      template_names {String}:
          The names of the templates for which you want the related diagrams to
          be processed.
      diagram_names {String}:
          The names of the diagrams to be processed."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DeleteDiagram_un(*gp_fixargs((in_diagrams, template_names, diagram_names), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExtendDiagram_un', None)
def ExtendDiagram(in_network_diagram_layer=None, ignore_traversability=None):
    """ExtendDiagram_un(in_network_diagram_layer, {ignore_traversability})

        Extends a network diagram by one feature level based on network
        connectivity or traversability.For example, a diagram with a portion
        of a pipe network in it, may
        have many open ended pipes with connected features. When the Extend
        Diagram tool is run on this diagram, any connected features are
        appended to the diagram.Alternatively, features may be obtained based
        on traversability;
        features are appended to the diagram if they allow the network
        commodity to continue through to the next feature. For example, a
        diagram with a portion of a pipe network in it may have a closed valve
        at the end of a pipe end. Since a resource travelling this network can
        not travel beyond the closed valve, the valve is not returned in the
        diagram. If this example was based on connectivity instead of
        traversability, the valve would be returned as it is connected to the
        pipe.If a feature is not returned in the diagram and is expected to
        be,
        then either the feature is not connected (connectivity and
        traversability based operations), or the feature is not traversable.If
        you have an open edit session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to extend.
      ignore_traversability {Boolean}:
          This option determines whether or not the extend diagram operation
          processes based on connectivity or traversability.

          *  IGNORE_TRAVERSABILITY-The traversability of the network is not
          taken into account. This is the default.

          * HONOR_TRAVERSABILITY-The traversability of the network is taken
          into account."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExtendDiagram_un(*gp_fixargs((in_network_diagram_layer, ignore_traversability), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('MakeDiagramLayer_un', None)
def MakeDiagramLayer(in_utility_network=None, network_diagram_name=None, out_layer=None):
    """MakeDiagramLayer_un(in_utility_network, network_diagram_name, out_layer)

        Creates a network diagram layer from a network diagram.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network the diagram is related to.
      network_diagram_name (String):
          The network diagram name.

     OUTPUTS:
      out_layer (Diagram Layer):
          The name of the diagram layer to be created.The output diagram layer
          can be used as input to any geoprocessing
          tool that accepts a diagram layer as input, including the Store
          Diagram, Update Diagram, and Apply Smart Tree Layout tools."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MakeDiagramLayer_un(*gp_fixargs((in_utility_network, network_diagram_name, out_layer), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('OverwriteDiagram_un', None)
def OverwriteDiagram(in_network_diagram_layer=None, map=None):
    """OverwriteDiagram_un(in_network_diagram_layer, map)

        Overwrites the contents of a network diagram with the network features
        currently selected in the specified map. These network features become
        the new initial content of the diagram.If you have an open edit
        session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to overwrite.
      map (Map):
          The map referencing the set of selected utility network features to
          use to overwrite the input network diagram."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.OverwriteDiagram_un(*gp_fixargs((in_network_diagram_layer, map), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('PurgeTemporaryDiagrams_un', None)
def PurgeTemporaryDiagrams(in_utility_network=None, created_before=None):
    """PurgeTemporaryDiagrams_un(in_utility_network, {created_before})

        Purges temporary network diagrams related to a given utility
        network.This tool needs to be run by the database owner of the utility
        network
        through a direct connection to the default version.In addition to
        those requirements, the connected portal account must
        be the owner of the utility network to perform this operation. This
        essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network data element with the temporary diagrams to be
          purged.
      created_before {Date}:
          All temporary network diagrams created before this date will be
          purged.If no date is specified, all temporary diagrams in the database
          will
          be purged."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.PurgeTemporaryDiagrams_un(*gp_fixargs((in_utility_network, created_before), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('StoreDiagram_un', None)
def StoreDiagram(in_network_diagram_layer=None, out_name=None, access_right_type=None, tags=None):
    """StoreDiagram_un(in_network_diagram_layer, out_name, {access_right_type}, {tags})

        Stores a temporary network diagram in the database. Access rights and
        tags can be assigned to control security and searchability of the
        diagram.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The temporary network diagram layer to be stored.
      access_right_type {String}:
          The access right level the owner wants to set for the input diagram.

          * PUBLIC-All users will have full access to the diagram; everyone can
          see, edit, update, and overwrite the diagram. However, no one except
          the diagram owner and the utility network owner will have rights to
          delete the diagram or change its properties using the Set Diagram
          Properties tool. This is the default.

          * PROTECTED-Other users will have read-only access to the diagram.
          They cannot edit, update, or overwrite the diagram.

          * PRIVATE-Other users will not have access to the diagram. The
          corresponding diagram item will be hidden from any other users in the
          Find Diagrams pane.
      tags {String}:
          One or several tags that could help querying the stored diagram in an
          easier way through the Find Diagrams pane afterwards.Use the #
          character to separate each tag and aid efficient diagram
          searches.

     OUTPUTS:
      out_name (Diagram Layer):
          The name of the output network diagram."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.StoreDiagram_un(*gp_fixargs((in_network_diagram_layer, out_name, access_right_type, tags), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('UpdateDiagram_un', None)
def UpdateDiagram(in_diagrams=None, template_names=None, diagram_names=None, update_option=None, autolayout_option=None):
    """UpdateDiagram_un(in_diagrams, {template_names;template_names...}, {diagram_names;diagram_names...}, {update_option}, {autolayout_option})

        Updates one or more network diagrams that are related to a given
        Utility Network.Diagrams may need to be updated when they are both
        inconsistent and
        consistent. When a diagram is inconsistent, it means the corresponding
        features in the map have been altered, and the diagram is out of date.
        A consistent diagram may need to be updated if the diagram template
        associated with it has been modified.If you have an open edit session,
        you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.

     INPUTS:
      in_diagrams (Utility Network Layer / Utility Network / Diagram Layer):
          The input network diagram layer to update, or the utility network
          data element or layer the set of specified input diagram names are
          based on and must be updated.
      template_names {String}:
          The names of the templates for which you want the related diagrams to
          be processed.
      diagram_names {String}:
          The names of the diagrams to be processed.
      update_option {Boolean}:
          This option specifies whether you want to update diagrams that are
          inconsistent only (default) or update all diagrams no matter what
          their consistency state is.

          * INCONSISTENT_DIAGRAMS_ONLY-Only diagrams which are inconsistent will
          be updated. This is the default.

          * ALL_SELECTED_DIAGRAMS-Both the consistent and inconsistent diagrams
          will be updated.
      autolayout_option {Boolean}:
          This option allows you to force the re-execution of any automatic
          layouts that may be configured on the template the diagrams are based
          on during the update process. By default, when automatic layouts are
          specified on a template, they are never re-applied during update
          operations.

          * REAPPLY_AUTOLAYOUT-The automatic layouts that are configured on the
          template will be re-applied on diagrams at the end of the update
          process.

          * DO_NOT_REAPPLY_AUTOLAYOUT-None of the automatic layouts configured
          on the template will be re-applied on diagrams during their update.
          This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpdateDiagram_un(*gp_fixargs((in_diagrams, template_names, diagram_names, update_option, autolayout_option), True)))
        return retval
    except Exception as e:
        raise e


# Network Diagrams\Configuration toolset
@gptooldoc('AddAngleDirectedLayout_un', None)
def AddAngleDirectedLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, iterations_number=None, number_of_directions=None):
    """AddAngleDirectedLayout_un(in_utility_network, template_name, is_active, {are_containers_preserved}, {iterations_number}, {number_of_directions})

        Adds the Angle Directed Layout algorithm to the list of the layouts to
        be automatically chained at the end of the generation of diagrams
        based on a given template. This tool also presets the Angle Directed
        Layout algorithm parameters for any diagram based on that
        template.This layout algorithm progressively moves the diagram's edges
        in
        specified alignment directions. For each diagram edge, this layout
        considers its current direction, searches for the nearest desired
        direction among those specified, and moves the edge in that
        direction.This tool is a configuration and administration tool that
        must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Whether the layout algorithm must be automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagrams based on the input template. This is the
          default.The parameter values specified for the layout algorithm are
          those used to run the layout during the diagram generation. They also
          become those loaded by default when the algorithm is going to be run
          on any diagrams based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be those loaded by default when the algorithm is
          going to be run on any diagrams based on the input template.
      are_containers_preserved {Boolean}:
          How containers will be processed by the algorithm:

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          non-content features in the diagram. This is the default.
      iterations_number {Long}:
          The number of iterations to process. The default is 1.
      number_of_directions {String}:
          The number of directions that must be used to align the diagram edges
          and their connected junctions.

          * TWELVE_DIRECTIONS-The edges will move so they progressively approach
          one of the 12 axes, starting with the edge's origin junction and
          inclined at 30, 60, 90, 120, 150, 180, 210, 240, 270, 300, 330, or 360
          degrees.

          * EIGHT_DIRECTIONS-The edges will move so they progressively approach
          one of the 8 axes, starting with the edge's origin junction and
          inclined at 45, 90, 135, 180, 225, 270, 315, or 360 degrees. This is
          the default.

          * FOUR_DIRECTIONS-The edges will move so they progressively approach
          one of the 4 axes, starting with the edge's origin junction and
          inclined at 90, 180, 270, or 360 degrees."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddAngleDirectedLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, iterations_number, number_of_directions), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddCollapseContainerByAttributeRule_un', None)
def AddCollapseContainerByAttributeRule(in_utility_network=None, template_name=None, is_active=None, container_source=None, where_clause=None, description=None):
    """AddCollapseContainerByAttributeRule_un(in_utility_network, template_name, is_active, container_source, {where_clause}, {description})

        Adds a diagram rule to automatically collapses contents related to
        containers during the building of diagrams based on an existing
        template. The containers to collapse being queried from a given
        utility network source class by attributes.This tool is a
        configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes active during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not active during the generation or
          update of any diagrams based on the input template.
      container_source (Feature Class):
          The network container source class that references the containers for
          which you want the contents to be collapsed during the Collapse
          Container rule process.
      where_clause {SQL Expression}:
          An SQL expression used to select the subset of containers in this
          source class for which the contents will be collapsed in the generated
          diagrams. For more information on SQL syntax, see the help topic SQL
          reference for query expressions used in ArcGIS
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddCollapseContainerByAttributeRule_un(*gp_fixargs((in_utility_network, template_name, is_active, container_source, where_clause, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddCollapseContainerRule_un', None)
def AddCollapseContainerRule(in_utility_network=None, template_name=None, is_active=None, container_type=None, inverse_source_selection=None, container_sources=None, description=None):
    """AddCollapseContainerRule_un(in_utility_network, template_name, is_active, container_type, inverse_source_selection, {container_sources;container_sources...}, {description})

        Adds a diagram rule to automatically collapse contents related to
        containers during the building of diagrams based on an existing
        template. This rule collapses the entire content of containers in the
        diagrams.This tool is a configuration and administration tool that
        must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes active during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not active during the generation or
          update of any diagrams based on the input template.
      container_type (String):
          The geometry type of the source class container the rule must process.

          * JUNCTIONS-The Collapse Container rule process will focus on the
          junction container source classes only; that is, the utility network
          polygon or point container source classes..

          * EDGES-The Collapse Container rule process will focus on the edge
          container source classes only; that is, the utility network linear
          container source classes.

          * BOTH-The Collapse Container rule process will operate on any
          container source classes whatever their type-both junction and edge
          type will be processed. This is the default.
      inverse_source_selection (String):
          The way the rule must process the specified container source classes.

          * EXCLUDE_SOURCE_CLASSES-Any containers based on the specified source
          classes will not be collapsed, while the other containers will be all
          collapsed. This is the default option.

          * INCLUDE_SOURCE_CLASSES-Any containers based on the only specified
          source classes will be collapsed.
      container_sources {Feature Class}:
          The network container source class or classes that must be excluded
          or included during the Collapse Container rule execution depending on
          the chosen rule process.With the Exclude source classes rule process ,
          the rule can be
          configured without specifying any particular network source class; in
          that case, it will collapse contents related to any container source
          classes in the generated diagrams. However, with the Include source
          classes rule process , the rule needs to know which particular
          container source class or classes it needs to collapse the related
          contents.When running with the Exclude source classes rule process ,
          the
          contents related to any network container features belonging to those
          classes will never be collapsed in the generated diagrams, while
          contents related to network container features that don't belong to
          those classes will not be collapsed. Conversely, when running with the
          Include source classes rule process , the contents related to any
          network container features belonging to those classes will always be
          collapsed in the generated diagrams, while contents related to network
          container features that don't belong to those classes will not be
          collapsed.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddCollapseContainerRule_un(*gp_fixargs((in_utility_network, template_name, is_active, container_type, inverse_source_selection, container_sources, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddCompressionLayout_un', None)
def AddCompressionLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, grouping_distance_absolute=None, vertices_removal_rule=None):
    """AddCompressionLayout_un(in_utility_network, template_name, is_active, {are_containers_preserved}, {grouping_distance_absolute}, {vertices_removal_rule})

        Adds the Compression Layout algorithm to the list of the layouts to be
        automatically chained at the end of the building of diagrams based on
        a given template. This tool also presets the Compression Layout
        algorithm parameters for any diagram based on that template.This
        layout algorithm compresses the diagram features toward the
        middle of the diagram while trying to maintain relative positioning.
        It works from a distance that allows it to build junctions' groups
        that are moved as super nodes during the algorithm execution.This tool
        is a configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Whether the layout algorithm must be automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagrams based on the input template. This is the
          default.The parameter values specified for the layout algorithm are
          those used to run the layout during the diagram generation. They also
          become those loaded by default when the algorithm is going to be run
          on any diagrams based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be those loaded by default when the algorithm is
          going to be run on any diagrams based on the input template.
      are_containers_preserved {Boolean}:
          How containers will be processed by the Compression algorithm:

          * PRESERVE_CONTAINERS-The Compression layout algorithm executes on
          the top graph of the diagram and preserves the containers. This is the
          default.

          * IGNORE_CONTAINERS-The Compression layout algorithm executes on the
          both content and non-content features in the diagram.
      grouping_distance_absolute {Linear Unit}:
          The grouping distance is used to determine whether two connected
          junctions are close enough to be considered part of the same junctions
          group. A junctions group represents many junctions that are moved as a
          group during execution. The group may contain both junctions and
          containers. To group two junctions together, they must also be
          connected in the diagram by an edge. The default is 20 units in the
          diagram's coordinate system.
      vertices_removal_rule {String}:
          How vertices along edges in the diagram will be processed.

          * ALL-All vertices on all edges will be removed from the diagram.

          * OUTER-Any edge vertices that are within the detected junctions'
          groups will be maintained, while edge vertices that are outside will
          be removed.When there are containers in the diagram that have edges
          that intersect the container polygons, a vertex is added at the
          intersection of the edge and container polygon. This is the default.

          * OUTER_EXCEPT_FIRST-Any edge vertices that are within the detected
          junctions' groups will be maintained, while edge vertices that are
          outside will be removed.When there are containers in the diagram that
          have edges that intersect the container polygons, the first (or last)
          outside vertex is preserved on edges that insect a container polygon.
          A vertex is automatically inserted at the intersection of the edges
          and container polygons."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddCompressionLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, grouping_distance_absolute, vertices_removal_rule), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddConnectivityAssociationsRule_un', None)
def AddConnectivityAssociationsRule(in_utility_network=None, template_name=None, is_active=None, description=None):
    """AddConnectivityAssociationsRule_un(in_utility_network, template_name, is_active, {description})

        Adds a diagram rule to automatically represent connectivity
        associations during the building of diagrams based on an existing
        template. This rule processes connectivity associations for which both
        the from and to junctions are currently represented in the
        diagrams.This tool is a configuration and administration tool that
        must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes active during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not active during the generation or
          update of any diagrams based on the input template.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddConnectivityAssociationsRule_un(*gp_fixargs((in_utility_network, template_name, is_active, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddDiagramTemplate_un', None)
def AddDiagramTemplate(in_utility_network=None, template_name=None, ndbd_file=None, ndld_file=None):
    """AddDiagramTemplate_un(in_utility_network, template_name, {ndbd_file}, {ndld_file})

        Adds a new diagram template to a utility network. A network diagram
        rules and layouts definition file (.ndbd) and/or a layer definition
        file (.ndld) can be imported.This tool is a configuration and
        administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network to which the template will be added.
      template_name (String):
          The name of the output diagram template.
      ndbd_file {File}:
          The network diagram rules and layouts definition file (.ndbd) to
          import. This file can be created using the Export Diagram Template
          Definitions tool on an existing template.
      ndld_file {File}:
          The diagram layer definition file (.ndld) to import. This file can be
          created using the Export Diagram Template Definitions or Export
          Diagram Layer Definition tools on an existing template."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddDiagramTemplate_un(*gp_fixargs((in_utility_network, template_name, ndbd_file, ndld_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddExpandContainerByAttributeRule_un', None)
def AddExpandContainerByAttributeRule(in_utility_network=None, template_name=None, is_active=None, containers_visibility=None, container_source=None, where_clause=None, description=None):
    """AddExpandContainerByAttributeRule_un(in_utility_network, template_name, is_active, containers_visibility, container_source, {where_clause}, {description})

        Adds a diagram rule to automatically expand contents related to
        containers during the building of diagrams based on an existing
        template. The containers to expand being filtered out from a given
        utility network source class by attributes.This tool is a
        configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes active during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not active during the generation or
          update of any diagrams based on the input template.
      containers_visibility (Boolean):
          This option determines whether the containers stay visible or not
          after they are expanded.

          *  KEEP_VISIBLE-The containers will stay visible after they are
          expanded. This is the default.

          * HIDE-The containers are will be after they are expanded.
      container_source (Feature Class):
          The network container source class that references the containers you
          want to be expanded during the Expand Container rule process.
      where_clause {SQL Expression}:
          An SQL expression used to select the subset of containers in this
          class that will be expanded in the generated diagrams. For more
          information on SQL syntax see the help topic SQL reference for query
          expressions used in ArcGIS
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddExpandContainerByAttributeRule_un(*gp_fixargs((in_utility_network, template_name, is_active, containers_visibility, container_source, where_clause, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddExpandContainerRule_un', None)
def AddExpandContainerRule(in_utility_network=None, template_name=None, is_active=None, containers_visibility=None, container_type=None, inverse_source_selection=None, container_sources=None, description=None):
    """AddExpandContainerRule_un(in_utility_network, template_name, is_active, containers_visibility, container_type, inverse_source_selection, {container_sources;container_sources...}, {description})

        Adds a diagram rule to automatically expand contents related to
        containers during the building of diagrams based on an existing
        template. This rule expands the entire content of containers in the
        diagrams.This tool is a configuration and administration tool that
        must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes active during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not active during the generation or
          update of any diagrams based on the input template.
      containers_visibility (Boolean):
          This option determines whether the containers stay visible or not
          after they are expanded.

          *  KEEP_VISIBLE-The containers will stay visible after they are
          expanded. This is the default.

          * HIDE-The containers are will be after they are expanded.
      container_type (String):
          The geometry type of the source class container the rule must process.

          * JUNCTIONS-The Expand Container rule process will focus on the
          junction container source classes only; that is, the utility network
          polygon or point container source classes.

          * EDGES-The Expand Container rule process will focus on the edge
          container source classes only; that is, the utility network linear
          container source classes.

          * BOTH-The Expand Container rule process will operate on any container
          source classes whatever their type-both junction and edge type will be
          processed. This is the default.
      inverse_source_selection (String):
          How the rule must process the specified container source classes.

          * EXCLUDE_SOURCE_CLASSES-Any containers based on the specified source
          classes will not be expanded, while the other containers will be all
          expanded. This is the default.

          * INCLUDE_SOURCE_CLASSES-Any containers based on the only specified
          source classes will be expanded.
      container_sources {Feature Class}:
          The network container source class (or classes) that must be excluded
          or included during the Expand Container rule execution depending on
          the chosen rule process.With the Exclude source classes rule process,
          the rule can be
          configured without specifying any particular network source class; in
          that case, it will expand all containers in the generated diagrams
          whatever their source class. However, with the Include source classes
          rule process , the rule needs to know which particular container
          source class (or classes) to expand.When running with the Exclude
          source classes rule process
          (inverse_source_selection=EXCLUDE_SOURCE_CLASSES in Python), the
          containers belonging to those classes will never be expanded in the
          generated diagrams, while network container features that don't belong
          to those classes will be not expanded. Conversely, when running with
          the Include source classes rule process, the containers belonging to
          those classes will always be expanded in the generated diagrams, while
          network container features that don't belong to those classes will not
          be expanded .
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddExpandContainerRule_un(*gp_fixargs((in_utility_network, template_name, is_active, containers_visibility, container_type, inverse_source_selection, container_sources, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddForceDirectedLayout_un', None)
def AddForceDirectedLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, iterations_number=None, repel_factor=None, degree_freedom=None):
    """AddForceDirectedLayout_un(in_utility_network, template_name, is_active, {are_containers_preserved}, {iterations_number}, {repel_factor}, {degree_freedom})

        Adds the Force Directed Layout algorithm to the list of the layouts to
        be automatically chained at the end of the building of diagrams based
        on a given template. This tool also presets the Force Directed Layout
        algorithm parameters for any diagram based on that template.This
        layout algorithm uses a physical analogy to draw graphs by
        considering a graph a force system in which it tries to locally
        minimize the energy. It searches for an equilibrium state of the force
        system-a position for each diagram junction where the total force on
        each junction is zero.This tool is a configuration and administration
        tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Whether the layout algorithm must be automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagrams based on the input template. This is the
          default.The parameter values specified for the layout algorithm are
          those used to run the layout during the diagram generation. They also
          become those loaded by default when the algorithm is going to be run
          on any diagrams based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be those loaded by default when the algorithm is
          going to be run on any diagrams based on the input template.
      are_containers_preserved {Boolean}:
          How containers will be processed by the algorithm:

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          non-content features in the diagram. This is the default.
      iterations_number {Long}:
          The number of iterations to process. The default is 20.
      repel_factor {Double}:
          The repel factor is used to add distance between diagram junctions
          that are close together. The larger the repel factor, the greater the
          distance that will be added between nearly overlapping diagram
          junctions. The default is 1.
      degree_freedom {String}:
          Limits the area used to move the diagram junctions during each
          algorithm iteration.

          * LOW-The area used to move the diagram junctions will be very
          limited. This is the default.

          * HIGH-The area used to move the diagram junctions will be very large.

          * MEDIUM-The area use to move the diagram junctions will be moderate."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddForceDirectedLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, iterations_number, repel_factor, degree_freedom), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddGridLayout_un', None)
def AddGridLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, cell_width_absolute=None, cell_height_absolute=None):
    """AddGridLayout_un(in_utility_network, template_name, is_active, {are_containers_preserved}, {cell_width_absolute}, {cell_height_absolute})

        Adds the Grid Layout algorithm to the list of the layouts to be
        automatically chained at the end of the building of diagrams based on
        a given template. This tool also presets the Grid Layout algorithm
        parameters for any diagram based on that template.This algorithm
        positions diagram junctions relative to a magnetic grid
        that has cell sizes fixed by the Cell Width and Cell Height parameter
        values.This tool is a configuration and administration tool that must
        be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Whether the layout algorithm must be automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagrams based on the input template. This is the
          default.The parameter values specified for the layout algorithm are
          those used to run the layout during the diagram generation. They also
          become those loaded by default when the algorithm is going to be run
          on any diagrams based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be those loaded by default when the algorithm is
          going to be run on any diagrams based on the input template.
      are_containers_preserved {Boolean}:
          How containers will be processed by the algorithm:

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          non-content features in the diagram. This is the default.
      cell_width_absolute {Linear Unit}:
          The width of each grid cell. The default is 2 in the units of the
          diagram's coordinate system.
      cell_height_absolute {Linear Unit}:
          The height of each grid cell. The default is 2 in the units of the
          diagram's coordinate system."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddGridLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, cell_width_absolute, cell_height_absolute), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddLinearDispatchLayout_un', None)
def AddLinearDispatchLayout(in_utility_network=None, template_name=None, is_active=None, junction_placement_type=None, is_unit_absolute=None, maximum_shift_absolute=None, maximum_shift_proportional=None, minimum_shift_absolute=None, minimum_shift_proportional=None, iterations_number=None, is_path_preserved=None, are_leaves_moved=None, are_leaves_expanded=None, expand_shift_absolute=None, expand_shift_proportional=None):
    """AddLinearDispatchLayout_un(in_utility_network, template_name, is_active, {junction_placement_type}, {is_unit_absolute}, {maximum_shift_absolute}, {maximum_shift_proportional}, {minimum_shift_absolute}, {minimum_shift_proportional}, {iterations_number}, {is_path_preserved}, {are_leaves_moved}, {are_leaves_expanded}, {expand_shift_absolute}, {expand_shift_proportional})

        Adds the Linear Dispatch Layout algorithm to the list of the layouts
        to be automatically chained at the end of the building of diagrams
        based on a given template. This tool also presets the Linear Dispatch
        Layout algorithm parameters for any diagram based on that
        template.This layout algorithm spaces out diagram junctions that are
        visually
        too close, overlapping, or coincident. It moves junctions along their
        connected edges. The movement along the edges depends on the current
        and relative position of junctions and on the layout parameters.This
        tool is a configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Whether the layout algorithm must be automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagrams based on the input template. This is the
          default.The parameter values specified for the layout algorithm are
          those used to run the layout during the diagram generation. They also
          become those loaded by default when the algorithm is going to be run
          on any diagrams based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be those loaded by default when the algorithm is
          going to be run on any diagrams based on the input template.
      junction_placement_type {String}:
          How the junctions will move.

          * EQUAL_DISTANCE-All junctions with two connected edges will move so
          the distances between them and their two connected junctions are
          equal. This is the default.

          * USER_DEFINE_DISTANCE-All junctions with two connected edges will
          move so there is a minimum distance (Minimum Shift value) between them
          and the other end of the edges they connect to. This occurs at the end
          of the layout execution.

          * ITERATIVE_DISTANCE-All the junctions with two connected edges will
          move slightly  according to the Number of Iterations and Maximum Shift
          parameter values.
      is_unit_absolute {Boolean}:
          How parameters representing distances will be interpreted:

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the diagram when it is generated. This is the
          default.
      maximum_shift_absolute {Linear Unit}:
          The maximum distance the junctions with two connections can be spaced
          from the junctions to which they connect to. The default is 2 in the
          units of the diagram's coordinate system. At the time this distance is
          reached, junctions are no longer moved during following iterations.
          This parameter is required when using the Iterative distance  junction
          placement type and working with absolute units.
      maximum_shift_proportional {Double}:
          . It specifies the maximum distance the junctions with two
          connections can be spaced from the junctions to which they connect to.
          The default is 2. At the time this distance is reached, junctions are
          no longer moved during the following iterations. This parameter is
          required when using the Iterative distance  junction placement type
          and working with proportional units
      minimum_shift_absolute {Linear Unit}:
          It determines the minimum distance that will separate each junction
          with two connected edges from its two edge extremities after the
          layout execution. The default is 2 units in the units of the diagram's
          coordinate system. When the Minimum Shift parameter value is too
          large, the junctions with two connections are moved so the distances
          between each moved junction and its edge extremities are equal along
          the path defined by its two connected edges. This parameter is
          required when using the User define distance  junction placement type
          and working with absolute units.
      minimum_shift_proportional {Double}:
          It determines the minimum distance that will separate each junction
          with two connected edges from its two edge extremities after the
          layout execution. The default is 2. Note that when the Minimum shift
          parameter value is too large, the junctions with two connections are
          moved so the distances between each moved junction and its edge
          extremities are equal along the path defined by its two connected
          edges. This parameter is expected when using the User define distance
          junction placement type and working with proportional units.
      iterations_number {Long}:
          The number of iterations to process. The default is 5. This parameter
          is required when using the Iterative distance  junction placement type
      is_path_preserved {Boolean}:
          How vertices along edges will be processed:

          *  PRESERVE_PATH-All vertices along the connected edges will be kept,
          and new vertices will be added at the moved junctions' original
          location. This is the default.

          *  IGNORE_PATH-Vertices along edges will not be preserved.
      are_leaves_moved {Boolean}:
          This option determines whether the leaf junctions; that is, the
          junctions with one connection, can be moved or not during the
          algorithm execution:

          *  MOVE_LEAVES-Leaf junctions will be moved

          *  DO_NOT_MOVE_LEAVES-Leaf junctions will not be moved. This is the
          default, unless the specified input network diagram is based on a
          template for which the Linear Dispatch Layout algorithm has been
          configured with another parameter value.
      are_leaves_expanded {Boolean}:
          Whether the leaf junctions can be expanded or not:

          *  EXPAND_LEAVES-The leaves can be expanded. The Maximum Expand Shift
          value specifies the maximum distance those leaf junctions can be
          expanded away from the junctions they connect to.

          *  DO_NOT_EXPAND_LEAVES-The leaves cannot be expanded. This is the
          default, unless the specified input network diagram is based on a
          template for which the Linear Dispatch Layout algorithm has been
          configured with another parameter value.
      expand_shift_absolute {Linear Unit}:
          It specifies the maximum distance the leaf junctions must be expanded
          from the junctions to which they connect to. The default is 2 in the
          units of the diagram's coordinate system, unless the specified input
          network diagram is based on a template for which the Linear Dispatch
          Layout algorithm has been configured with another parameter value. At
          the time this distance is reached, leaf nodes are no longer moved
          during the following iterations. This parameter is required when
          enabling the Expand leaves mode and working with absolute units.
      expand_shift_proportional {Double}:
          It specifies the maximum distance the leaf junctions must be expanded
          from the junctions to which they connect to. The default is 2, unless
          the specified input network diagram is based on a template for which
          the Linear Dispatch Layout algorithm has been configured with another
          parameter value. At the time this distance is reached, leaf nodes are
          no longer moved during the next iterations. This parameter is required
          when enabling the Expand leaves mode and working with proportional
          units."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddLinearDispatchLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, junction_placement_type, is_unit_absolute, maximum_shift_absolute, maximum_shift_proportional, minimum_shift_absolute, minimum_shift_proportional, iterations_number, is_path_preserved, are_leaves_moved, are_leaves_expanded, expand_shift_absolute, expand_shift_proportional), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddMainlineTreeLayout_un', None)
def AddMainlineTreeLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, tree_direction=None, branches_placement=None, is_unit_absolute=None, perpendicular_absolute=None, perpendicular_proportional=None, along_absolute=None, along_proportional=None, disjoined_graph_absolute=None, disjoined_graph_proportional=None, are_edges_orthogonal=None, breakpoint_position=None):
    """AddMainlineTreeLayout_un(in_utility_network, template_name, is_active, {are_containers_preserved}, {tree_direction}, {branches_placement}, {is_unit_absolute}, {perpendicular_absolute}, {perpendicular_proportional}, {along_absolute}, {along_proportional}, {disjoined_graph_absolute}, {disjoined_graph_proportional}, {are_edges_orthogonal}, {breakpoint_position})

        Adds the Mainline Tree Layout algorithm to the list of the layouts to
        be automatically chained at the end of the building of diagrams based
        on a given template. This tool also presets the Mainline Tree Layout
        algorithm parameters for any diagram based on that template.This
        layout algorithm arranges the junctions and edges in the input
        network diagram hierarchically along a main line and places its
        related branches on either both sides, the left side, or the right
        side of the main line.This tool is a configuration and administration
        tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Whether the layout algorithm must be automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagrams based on the input template. This is the
          default.The parameter values specified for the layout algorithm are
          those used to run the layout during the diagram generation. They also
          become those loaded by default when the algorithm is going to be run
          on any diagrams based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be those loaded by default when the algorithm is
          going to be run on any diagrams based on the input template.
      are_containers_preserved {Boolean}:
          How containers will be processed by the algorithm:

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          non-content features in the diagram. This is the default.
      tree_direction {String}:
          The direction of the mainline.

          * FROM_LEFT_TO_RIGHT-The mainline will be drawn as a horizontal line
          starting from the left and ending on the right. This is the default.

          * FROM_RIGHT_TO_LEFT-The mainline will be drawn as a horizontal line
          starting from the right and ending on the left.

          * FROM_BOTTOM_TO_TOP-The mainline will be drawn as a vertical line
          starting from the bottom and ending at the top.

          * FROM_TOP_TO_BOTTOM-The mainline will be drawn as a vertical line
          starting from the top and ending at the bottom.
      branches_placement {String}:
          How branches from the mainline are relatively placed regarding to its
          direction.

          * BOTH_SIDES-Branches will be placed on both the left and right sides
          of the mainline. This is the default.

          * LEFT_SIDE-Branches will only be placed on the left side of the
          mainline.

          * RIGHT_SIDE-Branches will only be placed on the right side of the
          mainline.
      is_unit_absolute {Boolean}:
          How parameters representing distances will be interpreted:

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the diagram when it is generated. This is the
          default.
      perpendicular_absolute {Linear Unit}:
          The spacing between diagram junctions that are displayed along the
          axis perpendicular to the mainline. The default is 2 in the diagram's
          coordinate system. This parameter is required when using absolute
          units.
      perpendicular_proportional {Double}:
          The spacing between diagram junctions that are displayed along the
          axis perpendicular to the mainline. The default is 2.This parameter is
          required when using proportional units.
      along_absolute {Linear Unit}:
          The spacing between diagram junctions that are displayed along the
          mainline. It also dictates the spacing between diagram junctions that
          are displayed along the axis parallel to this mainline. This parameter
          is required when using absolute units. The default is 2 in the units
          of the diagram's coordinate system.
      along_proportional {Double}:
          The spacing between diagram junctions that are displayed along the
          mainline and diagram junctions that are displayed along the axis
          parallel to this mainline. This parameter is expected when using
          proportional units. The default is 2.
      disjoined_graph_absolute {Linear Unit}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using absolute units. The default is 4 in the units
          of the diagram's coordinate system.
      disjoined_graph_proportional {Double}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using proportional units. The default is 4.
      are_edges_orthogonal {Boolean}:
          How diagram edges are related to the tree branches display:

          *  ORTHOGONAL_EDGES-All diagram edges related to the tree branches
          will display with right angles.

          *  SLANTED_EDGES-All diagram edges related to the tree branches do not
          display with right angles. This is the default.
      breakpoint_position {Double}:
          The relative position of the break point on the diagram edges. It is
          a percentage between 0 and 100-50, by default.

          * With a Break Point Relative Position (%) value of 0, the break point
          is positioned at the x-coordinate of the edge's from"junction and at
          the y-coordinate of the edge's to junction for a horizontal tree. It
          is positioned at the y-coordinate of the edge's from junction and at
          the x-coordinate of the edge's to junction for a vertical tree

          * With a Break Point Relative Position (%) value of 100, there is no
          break point inserted on the diagram edges; each diagram edge directly
          connects its from and to junctions.

          * With a Break Point Relative Position (%) value of N between 0 and
          100, the break point is positioned at N% of the length of the [XY]
          segment, X being the x-coordinate of the edge's from junction and Y,
          the y-coordinate of the edge's to junction for an horizontal tree. It
          is positioned at N% of the length of the [YX] segment, Y being the
          y-coordinate of the edge's from junction and X, the x-coordinate of
          the edge's to junction for a vertical tree.
          The notion of the from and to junctions above is relative to the tree
          direction; it has nothing to do with the real topology of the network
          feature edge."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddMainlineTreeLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, tree_direction, branches_placement, is_unit_absolute, perpendicular_absolute, perpendicular_proportional, along_absolute, along_proportional, disjoined_graph_absolute, disjoined_graph_proportional, are_edges_orthogonal, breakpoint_position), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddPartialOverlappingEdgesLayout_un', None)
def AddPartialOverlappingEdgesLayout(in_utility_network=None, template_name=None, is_active=None, buffer_width_absolute=None, offset_absolute=None, optimize_edges=None):
    """AddPartialOverlappingEdgesLayout_un(in_utility_network, template_name, is_active, buffer_width_absolute, offset_absolute, {optimize_edges})

        Adds the Partial Overlapping Edges Layout algorithm to the list of the
        layouts to be automatically chained at the end of the building of
        diagrams based on a given template. This tool also presets the Partial
        Overlapping Edges Layout algorithm parameters for any diagram based on
        that template.This layout algorithm detects sets of collinear edges or
        collinear
        portions of edges (edge segments) that can be considered as being
        inside a buffer zone of a given size.This tool is a configuration and
        administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Whether the layout algorithm must be automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagrams based on the input template. This is the
          default.The parameter values specified for the layout algorithm are
          those used to run the layout during the diagram generation. They also
          become those loaded by default when the algorithm is going to be run
          on any diagrams based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be those loaded by default when the algorithm is
          going to be run on any diagrams based on the input template.
      buffer_width_absolute (Linear Unit):
          The width of the buffer zones in which to search for collinear edge
          segments.
      offset_absolute (Linear Unit):
          The distance that will separate the detected edge segments.
      optimize_edges {Boolean}:
          How segments are placed along edges:

          *  OPTIMIZE_EDGES-The placement of segments is optimized in each set
          of collinear segments. This is done by focusing on their connections
          instead of their positions. Segments that cross each other have a
          chance to be repositioned so they do not cross.

          *  DO_NOT_OPTIMIZE_EDGES-The initial position of each segment is
          maintained in the collinear segment set and crossings are kept. This
          is the default option."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddPartialOverlappingEdgesLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, buffer_width_absolute, offset_absolute, optimize_edges), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddRadialTreeLayout_un', None)
def AddRadialTreeLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, is_unit_absolute=None, initial_radius_absolute=None, initial_radius_proportional=None, disjoined_graph_absolute=None, disjoined_graph_proportional=None, radius_factor=None):
    """AddRadialTreeLayout_un(in_utility_network, template_name, is_active, {are_containers_preserved}, {is_unit_absolute}, {initial_radius_absolute}, {initial_radius_proportional}, {disjoined_graph_absolute}, {disjoined_graph_proportional}, {radius_factor})

        Adds the Radial Tree Layout algorithm to the list of the layouts to
        be automatically chained at the end of the building of diagrams based
        on a given template. This tool also presets the Radial Tree Layout
        algorithm parameters for any diagram based on that template.This
        layout algorithm arranges the diagram features hierarchically and
        places them in a radial tree according to the specified radius
        parameters. It works from a root junction that it uses as the circle
        center to arrange the subtrees starting from this root in concentric
        circles, each circle corresponding to one hierarchical level.This tool
        is a configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Whether the layout algorithm must be automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagrams based on the input template. This is the
          default.The parameter values specified for the layout algorithm are
          those used to run the layout during the diagram generation. They also
          become those loaded by default when the algorithm is going to be run
          on any diagrams based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be those loaded by default when the algorithm is
          going to be run on any diagrams based on the input template.
      are_containers_preserved {Boolean}:
          How containers will be processed by the algorithm:

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          non-content features in the diagram. This is the default.
      is_unit_absolute {Boolean}:
          How parameters representing distances will be interpreted:

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the diagram when it is generated. This is the
          default.
      initial_radius_absolute {Linear Unit}:
          The radius of the first concentric circle whose center is the radial
          tree root junction; that is, the radius of the circle around which the
          diagram junctions belonging to the first hierarchical level are
          placed. The default is 5 in the units of the diagram's coordinate
          system. This parameter is required when using absolute units.
      initial_radius_proportional {Double}:
          The radius of the first concentric circle whose center is the radial
          tree root junction; that is, the radius of the circle around which the
          diagram junctions belonging to the first hierarchical level are
          placed. The default is 5. This parameter is required when using
          proportional units.
      disjoined_graph_absolute {Linear Unit}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using absolute units. The default is 4 in the units
          of the diagram's coordinate system.
      disjoined_graph_proportional {Double}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using proportional units. The default is 4.
      radius_factor {Double}:
          Represents the multiplicative factor used to increase or decrease the
          radius of each concentric circle. It also represents the distance that
          separates each concentric circle related to a hierarchical level. When
          using a radius factor less than 1, the distance that separates the
          diagram junctions belonging to the (n) hierarchical level and the
          (n+1) hierarchical level progressively decreases. With a factor
          greater than 1, the distance between the hierarchical levels increases
          progressively. The default is 1."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddRadialTreeLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, is_unit_absolute, initial_radius_absolute, initial_radius_proportional, disjoined_graph_absolute, disjoined_graph_proportional, radius_factor), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddReduceEdgeByAttributeRule_un', None)
def AddReduceEdgeByAttributeRule(in_utility_network=None, template_name=None, is_active=None, network_source=None, where_clause=None, description=None):
    """AddReduceEdgeByAttributeRule_un(in_utility_network, template_name, is_active, network_source, {where_clause}, {description})

        Adds a diagram rule to automatically reduce diagram edges during the
        building of diagrams based on an existing template. This rule can be
        set up to reduce diagram edges by attributes.This tool is a
        configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes active during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not active during the generation or
          update of any diagrams based on the input template.
      network_source (Feature Class):
          The network edge source class to process during the reduction rule.
          All diagram edges related to network lines that belong to this source
          class are candidate to the reduction.
      where_clause {SQL Expression}:
          An SQL expression used to select the subset of network edges among
          the edges candidate to the reduction that will be reduced in the
          diagrams based on the input template. For more information on SQL
          syntax see the help topic SQL reference for query expressions used in
          ArcGIS.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddReduceEdgeByAttributeRule_un(*gp_fixargs((in_utility_network, template_name, is_active, network_source, where_clause, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddReduceJunctionByAttributeRule_un', None)
def AddReduceJunctionByAttributeRule(in_utility_network=None, template_name=None, is_active=None, junction_source=None, where_clause=None, connectivity_options=None, unconnected_junctions=None, one_connected_junction=None, two_connected_junctions=None, edges_attributes=None, description=None):
    """AddReduceJunctionByAttributeRule_un(in_utility_network, template_name, is_active, junction_source, {where_clause}, {connectivity_options}, {unconnected_junctions}, {one_connected_junction}, {two_connected_junctions}, {edges_attributes;edges_attributes...}, {description})

        Adds a diagram rule to automatically reduce diagram junctions during
        the building of diagrams based on an existing template. The junctions
        to reduce being queried from a given utility network junction source
        class by attributes according to the number of other junctions they
        are connected to.This tool is a configuration and administration tool
        that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes active during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not active during the generation or
          update of any diagrams based on the input template.
      junction_source (Feature Class):
          The network junction source class to process during the reduction
          rule. All diagram junctions related to network junctions that belong
          to this source class are candidate to the reduction.
      where_clause {SQL Expression}:
          An SQL expression used to select the subset of network junctions
          among the junctions candidate to the reduction that will be reduced in
          the diagrams based on the input template. For more information on SQL
          syntax see the help topic SQL reference for query expressions used in
          ArcGIS.
      connectivity_options {String}:
          This parameter allows to specify which kind of reduction the rule
          will process.

          * MAX_2_CONNECTED_JUNCTIONS-The rule will process junctions which have
          two connections or less. In that case, the rule executes a specific
          process according to the number of junctions the junction to reduce
          connects. This is the default.

          * MIN_3_CONNECTED_JUNCTIONS-The rule will process junctions which have
          three connections or more. In that case, the rule will execute
          upstream traces to determine wether the junctions candidate to the
          reduction can be reduced or not.
      unconnected_junctions {Boolean}:
          This option is available when the rule is configured to run with the
          Maximum two connected junctions connectivity option. It determines
          whether each network diagram unconnected junction which is candidate
          to the reduction is reduced or kept.

          *  REDUCE_UNCONNECTED_JCT-The rule will reduce the diagram junctions
          candidate to the reduction which are unconnected. Each of those
          junctions will be "removed".

          *  KEEP_UNCONNECTED_JCT-The rule will keep the unconnected diagram
          junctions. This is the default.
      one_connected_junction {Boolean}:
          This option is available when the rule is configured to run with the
          Maximum two connected junctions connectivity option. It determines
          whether each network diagram junction connected to a single other
          junction which is candidate to the reduction is reduced or kept.

          *  REDUCE_JCT_TO_1JCT-The rule will reduce the diagram junctions
          candidate to the reduction which connect to a single junction. Each of
          those junctions and its incident edge will be reduced onto its single
          connected junction.

          *  KEEP_JCT_TO_1JCT-The rule will keep the diagram junctions candidate
          to the reduction which connect to a single junction. This is the
          default.
      two_connected_junctions {Boolean}:
          This option is available when the rule is configured to run with the
          Maximum two connected junctions connectivity option. It determines
          whether each network diagram junction connected to two different other
          junctions which is candidate to the reduction is reduced or kept:

          *  REDUCE_JCT_TO_2JCTS-The rule will reduce the diagram junctions
          candidate to the reduction which connect two other junctions. Each of
          those junctions and its incident edges will be reduced onto a super
          span edge, the "reduction edge". This is the default.

          *  KEEP_JCT_TO_2JCTS-The rule will keep the diagram junctions
          candidate to the reduction which connect two other junctions.
      edges_attributes {String}:
          The alias of the attribute(s) brought by the edges adjacent to the
          junction candidate to the reduction.The junction will be reduced only
          when all its adjacent edges brought
          the same values for each of the specified attribute aliases.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddReduceJunctionByAttributeRule_un(*gp_fixargs((in_utility_network, template_name, is_active, junction_source, where_clause, connectivity_options, unconnected_junctions, one_connected_junction, two_connected_junctions, edges_attributes, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddReduceJunctionRule_un', None)
def AddReduceJunctionRule(in_utility_network=None, template_name=None, is_active=None, inverse_source_selection=None, junction_source=None, connectivity_options=None, unconnected_junctions=None, one_connected_junction=None, two_connected_junctions=None, edges_attributes=None, description=None):
    """AddReduceJunctionRule_un(in_utility_network, template_name, is_active, inverse_source_selection, {junction_source;junction_source...}, {connectivity_options}, {unconnected_junctions}, {one_connected_junction}, {two_connected_junctions}, {edges_attributes;edges_attributes...}, {description})

        Adds a diagram rule to automatically reduce diagram junctions during
        the building of diagrams based on an existing template. This rule
        reduces junctions based on several utility network junction source
        classes according to the number of other junctions they are connected
        to.This tool is a configuration and administration tool that must be
        run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes active during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not active during the generation or
          update of any diagrams based on the input template.
      inverse_source_selection (String):
          How the rule processes the specified junction source classes.

          * EXCLUDE_SOURCE_CLASSES-The junctions based on the specified source
          classes will not be processed by the Reduce Junction rule while all
          the other junctions will be.

          * INCLUDE_SOURCE_CLASSES-The junctions based on the only specified
          source classes will be processed by the Reduce Junction rule. This is
          the default.
      junction_source {Feature Class}:
          The junction source class (or classes) that must be excluded or
          included during the Reduce Junction rule execution depending on the
          chosen rule process. With the Include source classes rule process set
          by default , the
          Reduce Junction rule expects one or more network junction source
          classes to process during the rule execution. All diagram junctions
          related to network junctions that belong to those source classes are
          candidate to the reductions. The Reduce Junction rule will process the
          junction source classes in
          the order specified in this list from the junction class with the
          highest priority-the first class in the list-to the junction class
          with the lowest priority-the last class in the list.With the Exclude
          source classes rule process , the rule can be
          configured without specifying any particular junction source class; in
          that case, it will reduce all junctions in the generated diagrams
          whatever their source class.
      connectivity_options {String}:
          This parameter allows to specify which kind of reduction the rule
          will process.

          * MAX_2_CONNECTED_JUNCTIONS-The rule will process junctions which have
          two connections or less. In that case, the rule executes a specific
          process according to the number of junctions the junction to reduce
          connects. This is the default.

          * MIN_3_CONNECTED_JUNCTIONS-The rule will process junctions which have
          three connections or more. In that case, the rule will execute
          upstream traces to determine wether the junctions candidate to the
          reduction can be reduced or not.
      unconnected_junctions {Boolean}:
          This option is available when the rule is configured to run with the
          Maximum two connected junctions connectivity option. It determines
          whether each network diagram unconnected junction which is candidate
          to the reduction is reduced or kept.

          *  REDUCE_UNCONNECTED_JCT-The rule will reduce the diagram junctions
          candidate to the reduction which are unconnected. Each of those
          junctions will be "removed".

          *  KEEP_UNCONNECTED_JCT-The rule will keep the unconnected diagram
          junctions. This is the default.
      one_connected_junction {Boolean}:
          This option is available when the rule is configured to run with the
          Maximum two connected junctions connectivity option. It determines
          whether each network diagram junction connected to a single other
          junction which is candidate to the reduction is reduced or kept.

          *  REDUCE_JCT_TO_1JCT-The rule will reduce the diagram junctions
          candidate to the reduction which connect to a single junction. Each of
          those junctions and its incident edge will be reduced onto its single
          connected junction.

          *  KEEP_JCT_TO_1JCT-The rule will keep the diagram junctions candidate
          to the reduction which connect to a single junction. This is the
          default.
      two_connected_junctions {Boolean}:
          This option is available when the rule is configured to run with the
          Maximum two connected junctions connectivity option. It determines
          whether each network diagram junction connected to two different other
          junctions which is candidate to the reduction is reduced or kept:

          *  REDUCE_JCT_TO_2JCTS-The rule will reduce the diagram junctions
          candidate to the reduction which connect two other junctions. Each of
          those junctions and its incident edges will be reduced onto a super
          span edge, the "reduction edge". This is the default.

          *  KEEP_JCT_TO_2JCTS-The rule will keep the diagram junctions
          candidate to the reduction which connect two other junctions.
      edges_attributes {String}:
          The alias of the attribute(s) brought by the edges adjacent to the
          junction candidate to the reduction.The junction will be reduced only
          when all its adjacent edges brought
          the same values for each of the specified attribute aliases.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddReduceJunctionRule_un(*gp_fixargs((in_utility_network, template_name, is_active, inverse_source_selection, junction_source, connectivity_options, unconnected_junctions, one_connected_junction, two_connected_junctions, edges_attributes, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddRemoveFeatureByAttributeRule_un', None)
def AddRemoveFeatureByAttributeRule(in_utility_network=None, template_name=None, is_active=None, network_source=None, where_clause=None, description=None):
    """AddRemoveFeatureByAttributeRule_un(in_utility_network, template_name, is_active, network_source, {where_clause}, {description})

        Adds a diagram rule to automatically remove diagram features during
        the building of diagrams based on an existing template. The features
        to remove are queried from a given utility network source class.This
        tool is a configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes active during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not active during the generation or
          update of any diagrams based on the input template.
      network_source (Feature Class):
          The network source class to process during the Remove Feature rule.
          All diagram features related to network features that belong to this
          source class are candidates for removal.
      where_clause {SQL Expression}:
          An SQL expression used to select the subset of features among the
          features candidate to the removal that will be removed in the diagrams
          based on the input template. For more information on SQL syntax see
          the help topic SQL reference for query expressions used in ArcGIS
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddRemoveFeatureByAttributeRule_un(*gp_fixargs((in_utility_network, template_name, is_active, network_source, where_clause, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddRemoveFeatureRule_un', None)
def AddRemoveFeatureRule(in_utility_network=None, template_name=None, is_active=None, source_type=None, inverse_source_selection=None, network_source=None, description=None):
    """AddRemoveFeatureRule_un(in_utility_network, template_name, is_active, source_type, inverse_source_selection, network_source;network_source..., {description})

        Adds a diagram rule to automatically remove diagram features during
        the building of diagrams based on an existing template. This rule
        removes features based on different utility network source
        classes.This tool is a configuration and administration tool that must
        be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes active during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not active during the generation or
          update of any diagrams based on the input template.
      source_type (String):
          The geometry type of the source class feature the rule must process.

          * JUNCTIONS-Only junction source classes will be processed; that is,
          the utility network polygon or point source classes.

          * EDGES-Only edge source classes will be processed; that is, the
          utility network linear source classes.

          * BOTH-Both junction and edge types will be processed. This is the
          default.
      inverse_source_selection (String):
          The way the rule must process the specified network source classes.

          * EXCLUDE_SOURCE_CLASSES-The features based on the specified network
          source classes will not be processed by the Remove Feature rule while
          all the other features will be.

          * INCLUDE_SOURCE_CLASSES-The features based on the only specified
          network source classes will be processed by the Remove Feature rule.
          This is the default.
      network_source (Feature Class):
          The network source class(or classes) that must be excluded or
          included during the Remove Feature rule execution depending on the
          chosen rule process.By default, with the Include source classes rule
          process , the Remove
          Feature rule expects one or more network source classes to process
          during the rule execution. All diagram features related to network
          features that belong to those classes are removed.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddRemoveFeatureRule_un(*gp_fixargs((in_utility_network, template_name, is_active, source_type, inverse_source_selection, network_source, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddReshapeDiagramEdgesLayout_un', None)
def AddReshapeDiagramEdgesLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, reshape_type=None, is_path_preserved=None, offset_between_segment_absolute=None, breakpoint_absolute=None, shift_between_edge_absolute=None, angle_threshold=None):
    """AddReshapeDiagramEdgesLayout_un(in_utility_network, template_name, is_active, {are_containers_preserved}, {reshape_type}, {is_path_preserved}, {offset_between_segment_absolute}, {breakpoint_absolute}, {shift_between_edge_absolute}, {angle_threshold})

        Adds the Reshape Diagram Edges Layout algorithm to the list of the
        layouts to be automatically chained at the end of the building of
        diagrams based on a given template. This tool also presets the Reshape
        Diagram Edges Layout algorithm parameters for any diagram based on
        that template.This layout is used to process simple operations on
        vertices along
        edges in network diagrams. It enables you to reduce all vertices or
        some vertices along diagram edges, square diagram edges with the
        addition of vertices on edges, and separate diagram edges that
        overlap.This tool is a configuration and administration tool that must
        be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Whether the layout algorithm must be automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagrams based on the input template. This is the
          default.The parameter values specified for the layout algorithm are
          those used to run the layout during the diagram generation. They also
          become those loaded by default when the algorithm is going to be run
          on any diagrams based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be those loaded by default when the algorithm is
          going to be run on any diagrams based on the input template.
      are_containers_preserved {Boolean}:
          How containers will be processed by the algorithm:

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          non-content features in the diagram. This is the default.
      reshape_type {String}:
          How edges will be reshaped.

          * REMOVE_VERTICES-Removes all vertices along any edges in the diagram.

          * SQUARE_EDGES-Inserts vertices along diagram edges so these edges are
          displayed with right angles. This is the default.

          * SEPARATE_OVERLAPPING_EDGES-Separates edges that connect the same
          origin and extremity junctions when they are overlapping.

          * REDUCE_VERTICES_BY_ANGLE-Removes some or all vertices displayed
          along diagram edges according to the angle that separates the segments
          incident to those vertices.
      is_path_preserved {Boolean}:
          . Determines whether or not the vertices along the edges that are
          going to be squared will be preserved. This parameter is required when
          reshape_type parameter is set to SQUARE_EDGES

          *  PRESERVE_PATH-The direction of any edge will be taken into account
          and vertices along that edge will be treated in turn, from the first
          vertex to the last one. This is the default.

          * IGNORE_PATH-Vertices along the diagram edges will not be considered;
          the vertices will be removed during execution.
      offset_between_segment_absolute {Linear Unit}:
          The spacing that will separate parallel segments of squared edges
          incident to the same junction. The default is 5 in the units of the
          diagram's coordinate system. This parameter is required when setting
          reshape_type to SQUARE_EDGES.
      breakpoint_absolute {Linear Unit}:
          The maximum distance between each junction to the 1st or last break
          point along edges incident to that junction when those edges are
          squared. The default is 8.66 in the units of the diagram's coordinate
          system. This parameter is required when setting reshape_type to
          SQUARE_EDGES.
      shift_between_edge_absolute {Linear Unit}:
          It specifies the absolute spacing that will separate two edges. The
          default is 0.5 in the units of the diagram's coordinate system. This
          parameter is required when setting reshape_type to
          SEPARATE_OVERLAPPING_EDGES.
      angle_threshold {Double}:
          It specifies the angle formed by the incident segments over which the
          vertex related to these segments is reduced. The wider the angle, the
          fewer vertices are reduced. The default is 160 degrees. This parameter
          is required when setting reshape_type to REDUCE_VERTICES_BY_ANGLE."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddReshapeDiagramEdgesLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, reshape_type, is_path_preserved, offset_between_segment_absolute, breakpoint_absolute, shift_between_edge_absolute, angle_threshold), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddSetRootJunctionByAttributeRule_un', None)
def AddSetRootJunctionByAttributeRule(in_utility_network=None, template_name=None, is_active=None, junction_source=None, where_clause=None, description=None):
    """AddSetRootJunctionByAttributeRule_un(in_utility_network, template_name, is_active, junction_source, {where_clause}, {description})

        Adds a diagram rule to automatically flag diagram junctions as root
        junctions during the building of diagrams based on an existing
        template. This rule specifies root junctions based on a particular
        source class and eventually filtered using their attributes.This tool
        is a configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes active during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not active during the generation or
          update of any diagrams based on the input template.
      junction_source (Feature Class):
          The network junction source class to process during the Set Root
          Junction By Attribute rule. All diagram junctions related to network
          features that belong to this source class are candidate to become root
          junctions.
      where_clause {SQL Expression}:
          An optional SQL expression used to filter out the expected root
          junctions among all the junctions candidate to become root junctions
          for the diagrams based on the input template. For more information on
          SQL syntax see the help topic SQL reference for query expressions used
          in ArcGIS
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddSetRootJunctionByAttributeRule_un(*gp_fixargs((in_utility_network, template_name, is_active, junction_source, where_clause, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddSmartTreeLayout_un', None)
def AddSmartTreeLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, tree_direction=None, is_unit_absolute=None, subtree_absolute=None, subtree_proportional=None, perpendicular_absolute=None, perpendicular_proportional=None, along_absolute=None, along_proportional=None, disjoined_graph_absolute=None, disjoined_graph_proportional=None, are_edges_orthogonal=None, breakpoint_position=None):
    """AddSmartTreeLayout_un(in_utility_network, template_name, is_active, {are_containers_preserved}, {tree_direction}, {is_unit_absolute}, {subtree_absolute}, {subtree_proportional}, {perpendicular_absolute}, {perpendicular_proportional}, {along_absolute}, {along_proportional}, {disjoined_graph_absolute}, {disjoined_graph_proportional}, {are_edges_orthogonal}, {breakpoint_position})

        Adds the Smart Tree Layout algorithm to the list of the layouts to be
        automatically chained at the end of the building of diagrams based on
        a given template. This tool also presets the Smart Tree Layout
        algorithm parameters for any diagram based on that template.This
        layout algorithm arranges the diagram features hierarchically and
        places them in a smart tree according to the direction and spacing
        distances specified.This tool is a configuration and administration
        tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Whether the layout algorithm must be automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagrams based on the input template. This is the
          default.The parameter values specified for the layout algorithm are
          those used to run the layout during the diagram generation. They also
          become those loaded by default when the algorithm is going to be run
          on any diagrams based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be those loaded by default when the algorithm is
          going to be run on any diagrams based on the input template.
      are_containers_preserved {Boolean}:
          How containers will be processed by the algorithm:

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          non-content features in the diagram. This is the default.
      tree_direction {String}:
          The direction of the tree.

          * FROM_LEFT_TO_RIGHT-The tree will be drawn from the left to the
          right. This is the default.

          * FROM_RIGHT_TO_LEFT-The tree will be drawn from the right to the
          left.

          * FROM_BOTTOM_TO_TOP-The tree will be drawn from the bottom to the
          top.

          * FROM_TOP_TO_BOTTOM-The tree will be drawn from the top to the
          bottom.
      is_unit_absolute {Boolean}:
          How parameters representing distances will be interpreted:

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the diagram when it is generated. This is the
          default.
      subtree_absolute {Linear Unit}:
          It determines the spacing between two neighboring subtrees; that is,
          the spacing between diagram junctions that are displayed
          perpendicularly to the smart tree direction and belong to a different
          subtree. The default is in the units of the diagram's coordinate
          system. This parameter is required when using absolute units.
      subtree_proportional {Double}:
          It determines the spacing between two neighboring subtrees; that is,
          the spacing between diagram junctions that are displayed
          perpendicularly to the smart tree direction and belong to a different
          subtree. The default is 2. This parameter is required when using
          proportional units.
      perpendicular_absolute {Linear Unit}:
          This parameter is required when using absolute units. It specifies
          the spacing between diagram junctions that are displayed
          perpendicularly to the smart tree direction and belong to the same
          subtree level. The default is 2 in the units of the diagram's
          coordinate system. This parameter is required when using absolute
          units.
      perpendicular_proportional {Double}:
          It specifies the spacing between diagram junctions that are displayed
          perpendicularly to the smart tree direction and belong to the same
          subtree level. The default is 2. This parameter is required when using
          proportional units.
      along_absolute {Linear Unit}:
          It specifies the spacing between diagram junctions that are displayed
          along the smart tree direction. The default is 2 in the units of the
          diagram's coordinate system. This parameter is required when using
          absolute units.
      along_proportional {Double}:
          It specifies the spacing between diagram junctions that are displayed
          along the smart tree direction. The default is 2. This parameter is
          required when using proportional units.
      disjoined_graph_absolute {Linear Unit}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using absolute units. The default is 4 in the units
          of the diagram's coordinate system.
      disjoined_graph_proportional {Double}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using proportional units. The default is 4.
      are_edges_orthogonal {Boolean}:
          How diagram edges are related to the tree branches display:

          *  ORTHOGONAL_EDGES-All diagram edges related to the tree branches
          will display with right angles.

          *  SLANTED_EDGES-All diagram edges related to the tree branches do not
          display with right angles. This is the default.
      breakpoint_position {Double}:
          The relative position of the break point on the diagram edges. It is
          a percentage between 0 and 100-50, by default.

          * With a Break Point Relative Position (%) value of 0, the break point
          is positioned at the x-coordinate of the edge's from"junction and at
          the y-coordinate of the edge's to junction for a horizontal tree. It
          is positioned at the y-coordinate of the edge's from junction and at
          the x-coordinate of the edge's to junction for a vertical tree

          * With a Break Point Relative Position (%) value of 100, there is no
          break point inserted on the diagram edges; each diagram edge directly
          connects its from and to junctions.

          * With a Break Point Relative Position (%) value of N between 0 and
          100, the break point is positioned at N% of the length of the [XY]
          segment, X being the x-coordinate of the edge's from junction and Y,
          the y-coordinate of the edge's to junction for an horizontal tree. It
          is positioned at N% of the length of the [YX] segment, Y being the
          y-coordinate of the edge's from junction and X, the x-coordinate of
          the edge's to junction for a vertical tree.
          The notion of the from and to junctions above is relative to the tree
          direction; it has nothing to do with the real topology of the network
          feature edge."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddSmartTreeLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, tree_direction, is_unit_absolute, subtree_absolute, subtree_proportional, perpendicular_absolute, perpendicular_proportional, along_absolute, along_proportional, disjoined_graph_absolute, disjoined_graph_proportional, are_edges_orthogonal, breakpoint_position), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddSpatialDispatchLayout_un', None)
def AddSpatialDispatchLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, iterations_number=None, maximum_shift_factor=None):
    """AddSpatialDispatchLayout_un(in_utility_network, template_name, is_active, {are_containers_preserved}, {iterations_number}, {maximum_shift_factor})

        Adds the Spatial Dispatch Layout algorithm to the list of the layouts
        to be automatically chained at the end of the building of diagrams
        based on a given template. This tool also presets the Spatial Dispatch
        Layout algorithm parameters for any diagram based on that
        template.This layout algorithm progressively separates diagram
        junctions that
        are visibly close to overlapping according to their current positions
        and to the shift factor specified.This tool is a configuration and
        administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Whether the layout algorithm must be automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagrams based on the input template. This is the
          default.The parameter values specified for the layout algorithm are
          those used to run the layout during the diagram generation. They also
          become those loaded by default when the algorithm is going to be run
          on any diagrams based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be those loaded by default when the algorithm is
          going to be run on any diagrams based on the input template.
      are_containers_preserved {Boolean}:
          How containers will be processed by the algorithm:

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          non-content features in the diagram. This is the default.
      iterations_number {Long}:
          The number of iterations to process. The default is 5.
      maximum_shift_factor {Double}:
          Increases the diagram junctions' displacement for junctions that are
          very close together. The larger the shift factor, the larger the
          separation between the diagram junctions that almost overlap. The
          default is 2."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddSpatialDispatchLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, iterations_number, maximum_shift_factor), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddStartIterationRule_un', None)
def AddStartIterationRule(in_utility_network=None, template_name=None, is_active=None, description=None):
    """AddStartIterationRule_un(in_utility_network, template_name, is_active, {description})

        Adds a diagram rule to specify the beginning of a rule sequence
        during the building of diagrams based on an existing template.This
        tool is a configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes active during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not active during the generation or
          update of any diagrams based on the input template.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddStartIterationRule_un(*gp_fixargs((in_utility_network, template_name, is_active, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddStopIterationRule_un', None)
def AddStopIterationRule(in_utility_network=None, template_name=None, is_active=None, description=None):
    """AddStopIterationRule_un(in_utility_network, template_name, is_active, {description})

        Adds a diagram rule to specify the end of a rule sequence during the
        building of diagrams based on an existing template.This tool is a
        configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes active during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not active during the generation or
          update of any diagrams based on the input template.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddStopIterationRule_un(*gp_fixargs((in_utility_network, template_name, is_active, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddStructuralAttachmentsRule_un', None)
def AddStructuralAttachmentsRule(in_utility_network=None, template_name=None, is_active=None, description=None):
    """AddStructuralAttachmentsRule_un(in_utility_network, template_name, is_active, {description})

        Adds a diagram rule to automatically represent structural attachments
        during the building of diagrams based on an existing template. This
        rule processes structural attachment associations for which both the
        attached feature and structure feature are currently represented in
        the diagrams.This tool is a configuration and administration tool that
        must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes active during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not active during the generation or
          update of any diagrams based on the input template.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddStructuralAttachmentsRule_un(*gp_fixargs((in_utility_network, template_name, is_active, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddTraceRule_un', None)
def AddTraceRule(in_utility_network=None, template_name=None, is_active=None, trace_type=None, domain_network=None, tier=None, target_tier=None, include_structures=None, include_barriers=None, condition_barriers=None, function_barriers=None, traversability_scope=None, filter_barriers=None, filter_function_barriers=None, filter_scope=None, filter_bitset_network_attribute_name=None, filter_nearest=None, nearest_count=None, nearest_cost_network_attribute=None, nearest_categories=None, nearest_assets=None, propagators=None, description=None):
    """AddTraceRule_un(in_utility_network, template_name, is_active, trace_type, {domain_network}, {tier}, {target_tier}, {include_structures}, {include_barriers}, {condition_barriers;condition_barriers...}, {function_barriers;function_barriers...}, {traversability_scope}, {filter_barriers;filter_barriers...}, {filter_function_barriers;filter_function_barriers...}, {filter_scope}, {filter_bitset_network_attribute_name}, {filter_nearest}, {nearest_count}, {nearest_cost_network_attribute}, {nearest_categories;nearest_categories...}, {nearest_assets;nearest_assets...}, {propagators;propagators...}, {description})

        Adds a diagram rule to automatically execute a trace on the network
        during the building of diagrams based on an existing template; the
        resulting traced network features are used to build the diagram
        content.This tool is a configuration and administration tool that must
        be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes active during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not active during the generation or
          update of any diagrams based on the input template.
      trace_type (String):
          The type of trace the rule must perform to build the diagram content.

          * CONNECTED-A connected trace is executed from the network features
          currently represented in the diagram when the rule starts and spans
          outward along connected features. This is the default.

          * SUBNETWORK-A subnetwork trace is executed from the network features
          currently represented in the diagram when the rule starts and spans
          outward along connected features to find sources or sinks from which
          it spans outward along the related subnetwork

          * UPSTREAM-An upstream trace is executed from the network features
          currently represented in the diagram when the rule starts to discover
          features upstream.

          * DOWNSTREAM-A downstream trace is executed from the network features
          currently represented in the diagram when the rule starts to discover
          features downstream.
      domain_network {String}:
          The name of the domain network to run the trace on. This parameter is
          needed when running the subnetwork, upstream, or downstream trace
          types.
      tier {String}:
          The name of the tier to start the trace. This parameter is optional
          only when running the connected trace type. It is required if running
          the subnetwork, upstream, or downstream trace types.
      target_tier {String}:
          The name of the target tier for which the input tier flows towards.
          If the parameter is missing for upstream and downstream traces, they
          will stop when they hit the boundary of the starting subnetwork. This
          parameter can be used to allow these traces to continue beyond, either
          farther up or farther down the hierarchy.
      include_structures {Boolean}:
          Define whether the structure features are included in the trace
          results.

          * INCLUDE_STRUCTURES-Structure features are included in the trace
          results.

          * EXCLUDE_STRUCTURES-Structure features are not included in the trace
          results. This is the default.
      include_barriers {Boolean}:
          Define whether the traversability barrier features are included in the
          trace results. Traversability barriers are optional even if they have
          been preset in the subnetwork definition.

          * INCLUDE_BARRIERS-Traversability barrier features are included in the
          trace results. This is the default.

          * EXCLUDE_BARRIERS-Traversability barrier features are not included in
          the trace results.
      condition_barriers {Value Table}:
          Condition barrier components:

          * Name-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Type-Choose a specific value or network attribute from the value
          that is specified in the name parameter.

          * Value-Specific value of the input attribute type which would cause
          termination based on the operator value.

          * Combine Using-You can set this value if you have multiple attributes
          to add. You can choose to combine them using an Add or an Or
          condition.
          The condition barriers operator values are:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          Possible values for the Type options are:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
          The Combine Using values are:

          * AND-Combine the condition barriers.

          * OR-Use if either of condition barrier is met.
      function_barriers {Value Table}:
          Function barrier components:

          * Function-Choose from a number of different calculation functions.

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Value-Specific value of the input attribute type that, if
          discovered, will cause the termination.

          * Use Local Values-Local values calculates values in each direction as
          opposed to an overall global value. For example, for a function
          barrier that is calculating the sum of Shape length where the trace
          terminates if the value is greater than or equal to 4. In the global
          case, after we have traversed two edges with a value of 2, we have
          already reached a shape length sum of 4, so the trace stops. If local
          values are used, the local values along each path changes, ro the
          trace goes further.
          Possible values for the function barrier function options are:

          * AVERAGE-The average of the input values.

          * COUNT-The number of features.

          * MAXIMUM-The maximum of the input values.

          * MINIMUM-The minimum of the input values.

          * ADD-Add the values.

          * SUBTRACT-Subtract the values.
          The function barrier operator value options are:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          The function barrier Use Local Values options are:

          * TRUE-Use local values.

          * FALSE-Use global values. This is the default.
      traversability_scope {String}:
          The type of traversability to enforce. Traversability scope dictates
          whether traversability is enforced at junctions, edges, or both. For
          example, if a condition barrier is defined to stop the trace if Device
          Status is equal to Open and traversability scope is set to edges only,
          then even if the trace encounters an open device the trace would not
          stop because the Device Status is only applicable for junctions. In
          other words, this parameter tells the trace whether or not to ignore
          junctions, edges, or both.

          * BOTH_JUNCTIONS_AND_EDGES-Apply traversability to both junctions and
          edges. This is the default.

          * JUNCTIONS_ONLY-Apply traversability to only junctions.

          * EDGES_ONLY-Apply traversability to only edges.
      filter_barriers {Value Table}:
          Filter barrier specifying when a trace should stop for a specific
          category or network attribute. For example, stop a trace at features
          that have a life cycle status attribute that is equal to a certain
          value. This parameter is used to set a terminator based on a value of
          a network attribute that is defined in the system. If using more than
          one attribute, you can use the Combine Using option to define an And
          or an Or condition.Filter barrier components:

          * Name-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Type-Choose a specific value or network attribute from the value
          that is specified in the name parameter.

          * Value-Specific value of the input attribute type which would cause
          termination based on the operator value.

          * Combine Using-You can set this value if you have multiple attributes
          to add. You can choose to combine them using an Add or an Or
          condition.
          The filter barriers operator values are:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          Possible values for the Type options are:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
          The Combine Using values are:

          * AND-Combine the condition barriers.

          * OR-Use if either of condition barrier is met.
      filter_function_barriers {Value Table}:
          The filter function barrier parameter allows you to filter the
          results of the trace for a specific category.Filter function barrier
          components:

          * Function-Choose from a number of different calculation functions.

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Value-Specific value of the input attribute type that, if
          discovered, will cause the termination.

          * Use Local Values-Local values calculates values in each direction as
          opposed to an overall global value. For example, for a function
          barrier that is calculating the sum of Shape length where the trace
          terminates if the value is greater than or equal to 4. In the global
          case, after we have traversed two edges with a value of 2, we have
          already reached a shape length sum of 4, so the trace stops. If local
          values are used, the local values along each path changes, or the
          trace goes further.
          Possible values for the function barrier function options are:

          * AVERAGE-The average of the input values.

          * COUNT-The number of features.

          * MAXIMUM-The maximum of the input values.

          * MINIMUM-The minimum of the input values.

          * ADD-Add the values.

          * SUBTRACT-Subtract the values.
          The function barrier operator value options are:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          The function barrier Use Local Values options are:

          * TRUE-Use local values.

          * FALSE-Use global values. This is the default.
      filter_scope {String}:
          Whether the filter for a specific category is enforced at junctions,
          edges, or both. For example, if a filter barrier is defined to stop
          the trace if Device Status is equal to Open and traversability scope
          is set to edges only, then even if the trace encounters an open device
          the trace will not stop because the Device Status is only applicable
          for junctions. In other words, this parameter tells the trace whether
          or not to ignore junctions, edges, or both.

          * BOTH_JUNCTIONS_AND_EDGES-Apply filter to both junctions and edges.
          This is the default.

          * JUNCTIONS_ONLY-Apply filter to only junctions.

          * EDGES_ONLY-Apply filter to only edges.
      filter_bitset_network_attribute_name {String}:
          The name of the network attribute that can be used to filter by
          bitset. This parameter is only applicable for upstream, downstream, or
          loops trace types. This parameter can be used to add special logic
          during a trace so the trace is more reflective of real world
          scenarios. For example, for a loops trace, the Phases current network
          attribute can determine if the loop is a true electrical loop (the
          same phase is energized all around the loop, ie. A) and return only
          real electrical loops for the trace results. An example for an
          upstream trace is; when tracing an electric distribution network, by
          specifying a Phases current network attribute, the trace results will
          only include valid paths that are the specified in the network
          attribute, not all paths.
      filter_nearest {Boolean}:
          Return a number of features of a certain type within a given distance
          by using k-nearest neighbors algorithm. When this parameter is used,
          you can specify a count, cost, and either a collection of categories
          or assets or both.

          * Checked-Use k-nearest neighbors to return a number of features as
          specified in the Count, Cost Network Attribute, Nearest Categories or
          Nearest Asset Groups/Types parameters.

          * Unchecked-Do not filter results by using k-nearest neighbors. This
          is the default.

          * TRUE-Use k-nearest neighbors to return a number of features as
          specified in the nearest_count, nearest_cost_network_attribute,
          nearest_categories, or nearest_assets parameters.

          * FALSE-Do not filter results by using k-nearest neighbors. This is
          the default.
      nearest_count {Long}:
          When filter_nearest is True, specify the number of features to be
          returned. For example, 4.
      nearest_cost_network_attribute {String}:
          When filter_nearest is True, specify the numeric network attribute
          that will be used to calculate nearness, cost, or distance. For
          example,  Shape length.
      nearest_categories {String}:
          When filter_nearest is True, specify the categories that will be
          returned. For example, Protective.
      nearest_assets {String}:
          When filter_nearest is True, specify the asset groups and asset types
          that will be returned. For example,
          ElectricDistributionDevice/Transformer/Step Down.
      propagators {Value Table}:
          Possible values for the propagators function are:

          * PROPAGATED_BITWISE_AND-Compare the values from one feature to the
          next.

          * PROPAGATED_MIN-Get the minimum value.

          * PROPAGATED_MAX-Get the maximum value.
          The propagator operator values are:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * INCLUDES_THE_VALUES-The attribute includes the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_ANY-The attribute includes any of the values.

          * DOES_NOT_INCLUDE_THE_VALUES-The attribute does not include the
          values.

          * DOES_NOT_INCLUDE_ANY-The attribute does not include any of the
          values.
          This parameter is only available via Python.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddTraceRule_un(*gp_fixargs((in_utility_network, template_name, is_active, trace_type, domain_network, tier, target_tier, include_structures, include_barriers, condition_barriers, function_barriers, traversability_scope, filter_barriers, filter_function_barriers, filter_scope, filter_bitset_network_attribute_name, filter_nearest, nearest_count, nearest_cost_network_attribute, nearest_categories, nearest_assets, propagators, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AlterDiagramTemplate_un', None)
def AlterDiagramTemplate(in_utility_network=None, template_name=None, out_name=None, is_default_template=None, are_rules_and_layouts_removed=None, are_vertices_kept=None, container_margin=None):
    """AlterDiagramTemplate_un(in_utility_network, template_name, {out_name}, {is_default_template}, {are_rules_and_layouts_removed}, {are_vertices_kept}, {container_margin})

        Alters the properties of a diagram template-for example, its name,
        how it handles vertices along input utility network edges, the margin
        between containers and their contents in the related diagrams, and the
        removal of its rules and layouts definition.This tool is a
        configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network of the diagram template to alter.
      template_name (String):
          The name of the diagram template to alter.
      out_name {String}:
          The new name of the template.
      is_default_template {Boolean}:
          Specify the default status of the template.

          *  DEFAULT_TEMPLATE-The input diagram template will become the default
          template.

          *  NOT_DEFAULT_TEMPLATE-The input diagram template will not be the
          default template. This is the default.
          The default template is the one used by default when generating a
          diagram if a template is not specified.
      are_rules_and_layouts_removed {Boolean}:
          Specify whether the template rules and layouts definition will be
          removed.

          *  REMOVE_RULES_AND_LAYOUTS-The rules and layouts definition related
          to the input diagram template will be removed.

          *  DO_NOT_REMOVE_RULES_AND_LAYOUTS-The rules and layouts definition
          related to the input diagram template will be maintained. This is the
          default.
      are_vertices_kept {Boolean}:
          Specify how vertices along the GIS vertices will be managed in the
          diagrams based on that template.

          *  KEEP_VERTICES-All vertices that display along GIS edges will be
          preserved on the associated edges in each network diagram based on
          this template.

          *  DO_NOT_KEEP_VERTICES-Diagram edges will be drawn as straight lines
          between their connected junctions. This is the default.
      container_margin {Linear Unit}:
          The container margin is the minimum distance between the center of any
          junctions inside the container and the container border."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AlterDiagramTemplate_un(*gp_fixargs((in_utility_network, template_name, out_name, is_default_template, are_rules_and_layouts_removed, are_vertices_kept, container_margin), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateDiagramLayerDefinition_un', None)
def CreateDiagramLayerDefinition(in_utility_network=None, template_name=None, system_junctions=None, connectivity_associations=None, structural_attachments=None, reduction_edges=None, point_subLayers=None, polygon_subLayers=None):
    """CreateDiagramLayerDefinition_un(in_utility_network, template_name, {system_junctions}, {connectivity_associations}, {structural_attachments}, {reduction_edges}, {point_subLayers;point_subLayers...}, {polygon_subLayers;polygon_subLayers...})

        Creates a diagram layer definition for the input diagram template
        considering the settings of the network feature layers present in the
        active map.This tools allows the following:

        * Import the appearance and labeling settings configured on each
        feature layer present in the active map when those layers are related
        to the utility network layer specified in input.

        * Control the set of extra layers which are created by default to
        represent pure schematic features-for example, reduction edges,
        connectivity associations, structural attachments, and so on-when
        those layers have no meaning for your template.
        This tool is a configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network Layer):
          The utility network layer in the active map.
      template_name (String):
          The name of the diagram template to modify.
      system_junctions {Boolean}:
          The visualisation of the system junctions or not in the diagrams
          based on the specified template:

          *  SHOW-The diagram layer will include a System Junctions sublayer to
          represent the system junctions in the diagrams. This is the default.

          *  HIDE-No sublayer will exist under the diagram layer to represent
          the system junctions in the diagrams.
      connectivity_associations {Boolean}:
          The visualisation of the connectivity associations or not in the
          diagrams based on the specified template:

          *  SHOW-The diagram layer will include a Connectivity Associations
          sublayer to represent the connectivity associations in the diagrams.
          This is the default.

          *  HIDE-No sublayer will exist under the diagram layer to represent
          the connectivity associations in the diagrams.
      structural_attachments {Boolean}:
          The visualisation of the connectivity associations or not in the
          diagrams based on the specified template:

          *  SHOW-The diagram layer will include a Structural Attachments
          sublayer to represent the  structural attachment associations in the
          diagrams. This is the default.

          *  HIDE-No sublayer will exist under the diagram layer to represent
          the structural attachment associations in the diagrams.
      reduction_edges {Boolean}:
          The visualisation of the reduction edges or not in the diagrams based
          on the specified template:

          *  SHOW-The diagram layer will include a Reduction Edges sublayer to
          represent the reduction edges in the diagrams. This is the default.

          *  HIDE-No sublayer will exist under the diagram layer to represent
          the reduction edges in the diagrams.
      point_subLayers {Value Table}:
          The sublayers that will be added to represent container polygon or
          line network features as point features in the diagrams.The Subtype
          Layer column is used as following:

          * True-The layer will be created with subtype group layers.

          * False-The layer will be created as a simple layer. This is the
          default.
      polygon_subLayers {Value Table}:
          The sublayers that will be added to represent container point network
          features as polygon features in the diagrams.The Subtype Layer column
          is used as following:

          * True-The layer will be created with subtype group layers.

          * False-The layer will be created as a simple layer. This is the
          default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateDiagramLayerDefinition_un(*gp_fixargs((in_utility_network, template_name, system_junctions, connectivity_associations, structural_attachments, reduction_edges, point_subLayers, polygon_subLayers), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DeleteDiagramTemplate_un', None)
def DeleteDiagramTemplate(in_utility_network=None, template_name=None):
    """DeleteDiagramTemplate_un(in_utility_network, template_name)

        Deletes a diagram template and all diagrams  based on that
        template.This tool is a configuration and administration tool that
        must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network of the template to delete.
      template_name (String):
          The name of the diagram template to delete."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DeleteDiagramTemplate_un(*gp_fixargs((in_utility_network, template_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExportDiagramLayerDefinition_un', None)
def ExportDiagramLayerDefinition(in_network_diagram_layer=None, out_ndld_file=None):
    """ExportDiagramLayerDefinition_un(in_network_diagram_layer, out_ndld_file)

        Exports the diagram layer definition currently set up for the input
        diagram layer into a diagram layer definition file (.ndld).

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram layer which layer definition must be exported.

     OUTPUTS:
      out_ndld_file (File):
          The network diagram layer definition file (.ndld) file to be created."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportDiagramLayerDefinition_un(*gp_fixargs((in_network_diagram_layer, out_ndld_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExportDiagramTemplateDefinitions_un', None)
def ExportDiagramTemplateDefinitions(in_utility_network=None, template_name=None, out_ndbd_file=None, out_ndld_file=None):
    """ExportDiagramTemplateDefinitions_un(in_utility_network, template_name, {out_ndbd_file}, {out_ndld_file})

        Exports the network diagram rules and layouts definition and/or the
        network diagram layer definition to .ndbd and .ndld files.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template definition to
          export.
      template_name (String):
          The name of the diagram template with definitions to be exported.

     OUTPUTS:
      out_ndbd_file {File}:
          The network diagram rules and layouts definition file (.ndbd) to be
          created.
      out_ndld_file {File}:
          The network diagram layer definition file (.ndld) to be created."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportDiagramTemplateDefinitions_un(*gp_fixargs((in_utility_network, template_name, out_ndbd_file, out_ndld_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GetDiagramTemplateNames_un', None)
def GetDiagramTemplateNames(in_utility_network=None):
    """GetDiagramTemplateNames_un(in_utility_network)

        Returns the names of all diagram templates related to a utility
        network.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network for which you want to get the diagram template
          names."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GetDiagramTemplateNames_un(*gp_fixargs((in_utility_network,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportDiagramTemplateDefinitions_un', None)
def ImportDiagramTemplateDefinitions(in_utility_network=None, template_name=None, ndbd_file=None, ndld_file=None):
    """ImportDiagramTemplateDefinitions_un(in_utility_network, template_name, {ndbd_file}, {ndld_file})

        Imports a network diagram rules and layouts definition file (.ndbd)
        and/or a network diagram layer definition file (.ndld) into an
        existing template.This tool is a configuration and administration tool
        that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to those requirements,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template onto which the definition will be
          imported.
      ndbd_file {File}:
          The network diagram rules and layouts definition file (.ndbd) to
          import.Such a file results from the execution of the Export Diagram
          Template
          Definitions tool on an existing template.At least one of the two
          definition file input parameters need to be
          completed; that is, either the network diagram rules and layouts
          definition file (.ndbd) or the network diagram layer definition file
          (.ndld).
      ndld_file {File}:
          The network diagram layer definition file (.ndld) to import.Such a
          file results from the execution of the Export Diagram Template
          Definitions or Export Diagram Layer Definition geoprocessing tools on
          an existing template.At least one of the two definition file input
          parameters need to be
          completed; that is, either the network diagram rules and layouts
          definition file (.ndbd) or the network diagram layer definition file
          (.ndld)."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportDiagramTemplateDefinitions_un(*gp_fixargs((in_utility_network, template_name, ndbd_file, ndld_file), True)))
        return retval
    except Exception as e:
        raise e


# Network Diagrams\Layout toolset
@gptooldoc('ApplyAngleDirectedLayout_un', None)
def ApplyAngleDirectedLayout(in_network_diagram_layer=None, are_containers_preserved=None, iterations_number=None, number_of_directions=None):
    """ApplyAngleDirectedLayout_un(in_network_diagram_layer, {are_containers_preserved}, {iterations_number}, {number_of_directions})

        Moves a diagram's edges in specified alignment directions.If you have
        an open edit session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which to apply the layout.
      are_containers_preserved {Boolean}:
          How containers will be processed by the algorithm:

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          non-content features in the diagram. This is the default.
      iterations_number {Long}:
          The number of iterations to process. The default is 1.
      number_of_directions {String}:
          The number of directions that must be used to align the diagram edges
          and their connected junctions.

          * TWELVE_DIRECTIONS-The edges will move so they progressively approach
          one of the 12 axes, starting with the edge's origin junction and
          inclined at 30, 60, 90, 120, 150, 180, 210, 240, 270, 300, 330, or 360
          degrees.

          * EIGHT_DIRECTIONS-The edges will move so they progressively approach
          one of the 8 axes, starting with the edge's origin junction and
          inclined at 45, 90, 135, 180, 225, 270, 315, or 360 degrees. This is
          the default.

          * FOUR_DIRECTIONS-The edges will move so they progressively approach
          one of the 4 axes, starting with the edge's origin junction and
          inclined at 90, 180, 270, or 360 degrees."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyAngleDirectedLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, iterations_number, number_of_directions), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyCompressionLayout_un', None)
def ApplyCompressionLayout(in_network_diagram_layer=None, are_containers_preserved=None, grouping_distance_absolute=None, vertices_removal_rule=None):
    """ApplyCompressionLayout_un(in_network_diagram_layer, {are_containers_preserved}, {grouping_distance_absolute}, {vertices_removal_rule})

        Compresses the diagram features toward the middle of the diagram.If
        you have an open edit session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which to apply the layout.
      are_containers_preserved {Boolean}:
          How containers will be processed by the Compression algorithm:

          * PRESERVE_CONTAINERS-The Compression layout algorithm executes on
          the top graph of the diagram and preserves the containers. This is the
          default.

          * IGNORE_CONTAINERS-The Compression layout algorithm executes on the
          both content and non-content features in the diagram.
      grouping_distance_absolute {Linear Unit}:
          The grouping distance is used to determine whether two connected
          junctions are close enough to be considered part of the same junctions
          group. A junctions group represents many junctions that are moved as a
          group during execution. The group may contain both junctions and
          containers. To group two junctions together, they must also be
          connected in the diagram by an edge. The default is 20 units in the
          diagram's coordinate system.
      vertices_removal_rule {String}:
          How vertices along edges in the diagram will be processed.

          * ALL-All vertices on all edges will be removed from the diagram.

          * OUTER-Any edge vertices that are within the detected junctions'
          groups will be maintained, while edge vertices that are outside will
          be removed.When there are containers in the diagram that have edges
          that intersect the container polygons, a vertex is added at the
          intersection of the edge and container polygon. This is the default.

          * OUTER_EXCEPT_FIRST-Any edge vertices that are within the detected
          junctions' groups will be maintained, while edge vertices that are
          outside will be removed.When there are containers in the diagram that
          have edges that intersect the container polygons, the first (or last)
          outside vertex is preserved on edges that insect a container polygon.
          A vertex is automatically inserted at the intersection of the edges
          and container polygons."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyCompressionLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, grouping_distance_absolute, vertices_removal_rule), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyForceDirectedLayout_un', None)
def ApplyForceDirectedLayout(in_network_diagram_layer=None, are_containers_preserved=None, iterations_number=None, repel_factor=None, degree_freedom=None):
    """ApplyForceDirectedLayout_un(in_network_diagram_layer, {are_containers_preserved}, {iterations_number}, {repel_factor}, {degree_freedom})

        Emphasizes loops contained in a network diagramIf you have an open
        edit session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which to apply the layout.
      are_containers_preserved {Boolean}:
          How containers will be processed by the algorithm:

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          non-content features in the diagram. This is the default.
      iterations_number {Long}:
          The number of iterations to process. The default is 20.
      repel_factor {Double}:
          The repel factor is used to add distance between diagram junctions
          that are close together. The larger the repel factor, the greater the
          distance that will be added between nearly overlapping diagram
          junctions. The default is 1.
      degree_freedom {String}:
          Limits the area used to move the diagram junctions during each
          algorithm iteration.

          * LOW-The area used to move the diagram junctions will be very
          limited. This is the default.

          * HIGH-The area used to move the diagram junctions will be very large.

          * MEDIUM-The area use to move the diagram junctions will be moderate."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyForceDirectedLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, iterations_number, repel_factor, degree_freedom), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyGeoPositionsLayout_un', None)
def ApplyGeoPositionsLayout(in_network_diagram_layer=None, restore_edges_geo_positions=None):
    """ApplyGeoPositionsLayout_un(in_network_diagram_layer, {restore_edges_geo_positions})

        Moves each diagram junction and edge feature so they match the
        geographical positions of the associated network features.If you have
        an open edit session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which to apply the layout.
      restore_edges_geo_positions {Boolean}:
          Whether or not diagram edges will be restored to the geographic
          position of their vertices:

          *  RESTORE_EDGES_GEO_POSITIONS-The vertices along diagram edges will
          be restored, when possible, moving them to match the geographic
          positions of the network features. This is the default.

          *  DO_NOT_RESTORE_EDGES_GEO_POSITIONS-Vertices along diagram edges
          will not be restored. They will appear as straight lines between their
          connecting junctions."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyGeoPositionsLayout_un(*gp_fixargs((in_network_diagram_layer, restore_edges_geo_positions), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyGridLayout_un', None)
def ApplyGridLayout(in_network_diagram_layer=None, are_containers_preserved=None, cell_width_absolute=None, cell_height_absolute=None):
    """ApplyGridLayout_un(in_network_diagram_layer, {are_containers_preserved}, {cell_width_absolute}, {cell_height_absolute})

        Positions diagram junctions relative to a predefined magnetic grid.If
        you have an open edit session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which to apply the layout.
      are_containers_preserved {Boolean}:
          How containers will be processed by the algorithm:

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          non-content features in the diagram. This is the default.
      cell_width_absolute {Linear Unit}:
          The width of each grid cell. The default is 2 in the units of the
          diagram's coordinate system.
      cell_height_absolute {Linear Unit}:
          The height of each grid cell. The default is 2 in the units of the
          diagram's coordinate system."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyGridLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, cell_width_absolute, cell_height_absolute), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyLinearDispatchLayout_un', None)
def ApplyLinearDispatchLayout(in_network_diagram_layer=None, junction_placement_type=None, is_unit_absolute=None, maximum_shift_absolute=None, maximum_shift_proportional=None, minimum_shift_absolute=None, minimum_shift_proportional=None, iterations_number=None, is_path_preserved=None, are_leaves_moved=None, are_leaves_expanded=None, expand_shift_absolute=None, expand_shift_proportional=None):
    """ApplyLinearDispatchLayout_un(in_network_diagram_layer, {junction_placement_type}, {is_unit_absolute}, {maximum_shift_absolute}, {maximum_shift_proportional}, {minimum_shift_absolute}, {minimum_shift_proportional}, {iterations_number}, {is_path_preserved}, {are_leaves_moved}, {are_leaves_expanded}, {expand_shift_absolute}, {expand_shift_proportional})

        Spaces out diagram junctions that are visually too close, overlapping
        or coincident.If you have an open edit session, you must save your
        edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which to apply the layout.
      junction_placement_type {String}:
          How the junctions will move.

          * EQUAL_DISTANCE-All junctions with two connected edges will move so
          the distances between them and their two connected junctions are
          equal. This is the default.

          * USER_DEFINE_DISTANCE-All junctions with two connected edges will
          move so there is a minimum distance (Minimum Shift value) between them
          and the other end of the edges they connect to. This occurs at the end
          of the layout execution.

          * ITERATIVE_DISTANCE-All the junctions with two connected edges will
          move slightly  according to the Number of Iterations and Maximum Shift
          parameter values.
      is_unit_absolute {Boolean}:
          How parameters representing distances will be interpreted:

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the diagram when it is generated. This is the
          default.
      maximum_shift_absolute {Linear Unit}:
          The maximum distance the junctions with two connections can be spaced
          from the junctions to which they connect to. The default is 2 in the
          units of the diagram's coordinate system. At the time this distance is
          reached, junctions are no longer moved during following iterations.
          This parameter is required when using the Iterative distance  junction
          placement type and working with absolute units.
      maximum_shift_proportional {Double}:
          . It specifies the maximum distance the junctions with two
          connections can be spaced from the junctions to which they connect to.
          The default is 2. At the time this distance is reached, junctions are
          no longer moved during the following iterations. This parameter is
          required when using the Iterative distance  junction placement type
          and working with proportional units
      minimum_shift_absolute {Linear Unit}:
          It determines the minimum distance that will separate each junction
          with two connected edges from its two edge extremities after the
          layout execution. The default is 2 units in the units of the diagram's
          coordinate system. When the Minimum Shift parameter value is too
          large, the junctions with two connections are moved so the distances
          between each moved junction and its edge extremities are equal along
          the path defined by its two connected edges. This parameter is
          required when using the User define distance  junction placement type
          and working with absolute units.
      minimum_shift_proportional {Double}:
          It determines the minimum distance that will separate each junction
          with two connected edges from its two edge extremities after the
          layout execution. The default is 2. Note that when the Minimum shift
          parameter value is too large, the junctions with two connections are
          moved so the distances between each moved junction and its edge
          extremities are equal along the path defined by its two connected
          edges. This parameter is expected when using the User define distance
          junction placement type and working with proportional units.
      iterations_number {Long}:
          The number of iterations to process. The default is 5. This parameter
          is required when using the Iterative distance  junction placement type
      is_path_preserved {Boolean}:
          How vertices along edges will be processed:

          *  PRESERVE_PATH-All vertices along the connected edges will be kept,
          and new vertices will be added at the moved junctions' original
          location. This is the default.

          *  IGNORE_PATH-Vertices along edges will not be preserved.
      are_leaves_moved {Boolean}:
          This option determines whether the leaf junctions; that is, the
          junctions with one connection, can be moved or not during the
          algorithm execution:

          *  MOVE_LEAVES-Leaf junctions will be moved

          *  DO_NOT_MOVE_LEAVES-Leaf junctions will not be moved. This is the
          default, unless the specified input network diagram is based on a
          template for which the Linear Dispatch Layout algorithm has been
          configured with another parameter value.
      are_leaves_expanded {Boolean}:
          Whether the leaf junctions can be expanded or not:

          *  EXPAND_LEAVES-The leaves can be expanded. The Maximum Expand Shift
          value specifies the maximum distance those leaf junctions can be
          expanded away from the junctions they connect to.

          *  DO_NOT_EXPAND_LEAVES-The leaves cannot be expanded. This is the
          default, unless the specified input network diagram is based on a
          template for which the Linear Dispatch Layout algorithm has been
          configured with another parameter value.
      expand_shift_absolute {Linear Unit}:
          It specifies the maximum distance the leaf junctions must be expanded
          from the junctions to which they connect to. The default is 2 in the
          units of the diagram's coordinate system, unless the specified input
          network diagram is based on a template for which the Linear Dispatch
          Layout algorithm has been configured with another parameter value. At
          the time this distance is reached, leaf nodes are no longer moved
          during the following iterations. This parameter is required when
          enabling the Expand leaves mode and working with absolute units.
      expand_shift_proportional {Double}:
          It specifies the maximum distance the leaf junctions must be expanded
          from the junctions to which they connect to. The default is 2, unless
          the specified input network diagram is based on a template for which
          the Linear Dispatch Layout algorithm has been configured with another
          parameter value. At the time this distance is reached, leaf nodes are
          no longer moved during the next iterations. This parameter is required
          when enabling the Expand leaves mode and working with proportional
          units."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyLinearDispatchLayout_un(*gp_fixargs((in_network_diagram_layer, junction_placement_type, is_unit_absolute, maximum_shift_absolute, maximum_shift_proportional, minimum_shift_absolute, minimum_shift_proportional, iterations_number, is_path_preserved, are_leaves_moved, are_leaves_expanded, expand_shift_absolute, expand_shift_proportional), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyMainlineTreeLayout_un', None)
def ApplyMainlineTreeLayout(in_network_diagram_layer=None, are_containers_preserved=None, tree_direction=None, branches_placement=None, is_unit_absolute=None, perpendicular_absolute=None, perpendicular_proportional=None, along_absolute=None, along_proportional=None, disjoined_graph_absolute=None, disjoined_graph_proportional=None, are_edges_orthogonal=None, breakpoint_position=None):
    """ApplyMainlineTreeLayout_un(in_network_diagram_layer, {are_containers_preserved}, {tree_direction}, {branches_placement}, {is_unit_absolute}, {perpendicular_absolute}, {perpendicular_proportional}, {along_absolute}, {along_proportional}, {disjoined_graph_absolute}, {disjoined_graph_proportional}, {are_edges_orthogonal}, {breakpoint_position})

        Arranges diagram junctions and edges hierarchically along a main
        line.If you have an open edit session, you must save your edits prior
        to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which to apply the layout.
      are_containers_preserved {Boolean}:
          How containers will be processed by the algorithm:

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          non-content features in the diagram. This is the default.
      tree_direction {String}:
          The direction of the mainline.

          * FROM_LEFT_TO_RIGHT-The mainline will be drawn as a horizontal line
          starting from the left and ending on the right. This is the default.

          * FROM_RIGHT_TO_LEFT-The mainline will be drawn as a horizontal line
          starting from the right and ending on the left.

          * FROM_BOTTOM_TO_TOP-The mainline will be drawn as a vertical line
          starting from the bottom and ending at the top.

          * FROM_TOP_TO_BOTTOM-The mainline will be drawn as a vertical line
          starting from the top and ending at the bottom.
      branches_placement {String}:
          How branches from the mainline are relatively placed regarding to its
          direction.

          * BOTH_SIDES-Branches will be placed on both the left and right sides
          of the mainline. This is the default.

          * LEFT_SIDE-Branches will only be placed on the left side of the
          mainline.

          * RIGHT_SIDE-Branches will only be placed on the right side of the
          mainline.
      is_unit_absolute {Boolean}:
          How parameters representing distances will be interpreted:

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the diagram when it is generated. This is the
          default.
      perpendicular_absolute {Linear Unit}:
          The spacing between diagram junctions that are displayed along the
          axis perpendicular to the mainline. The default is 2 in the diagram's
          coordinate system. This parameter is required when using absolute
          units.
      perpendicular_proportional {Double}:
          The spacing between diagram junctions that are displayed along the
          axis perpendicular to the mainline. The default is 2.This parameter is
          required when using proportional units.
      along_absolute {Linear Unit}:
          The spacing between diagram junctions that are displayed along the
          mainline. It also dictates the spacing between diagram junctions that
          are displayed along the axis parallel to this mainline. This parameter
          is required when using absolute units. The default is 2 in the units
          of the diagram's coordinate system.
      along_proportional {Double}:
          The spacing between diagram junctions that are displayed along the
          mainline and diagram junctions that are displayed along the axis
          parallel to this mainline. This parameter is expected when using
          proportional units. The default is 2.
      disjoined_graph_absolute {Linear Unit}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using absolute units. The default is 4 in the units
          of the diagram's coordinate system.
      disjoined_graph_proportional {Double}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using proportional units. The default is 4.
      are_edges_orthogonal {Boolean}:
          How diagram edges are related to the tree branches display:

          *  ORTHOGONAL_EDGES-All diagram edges related to the tree branches
          will display with right angles.

          *  SLANTED_EDGES-All diagram edges related to the tree branches do not
          display with right angles. This is the default.
      breakpoint_position {Double}:
          The relative position of the break point on the diagram edges. It is
          a percentage between 0 and 100-50, by default.

          * With a Break Point Relative Position (%) value of 0, the break point
          is positioned at the x-coordinate of the edge's from"junction and at
          the y-coordinate of the edge's to junction for a horizontal tree. It
          is positioned at the y-coordinate of the edge's from junction and at
          the x-coordinate of the edge's to junction for a vertical tree

          * With a Break Point Relative Position (%) value of 100, there is no
          break point inserted on the diagram edges; each diagram edge directly
          connects its from and to junctions.

          * With a Break Point Relative Position (%) value of N between 0 and
          100, the break point is positioned at N% of the length of the [XY]
          segment, X being the x-coordinate of the edge's from junction and Y,
          the y-coordinate of the edge's to junction for an horizontal tree. It
          is positioned at N% of the length of the [YX] segment, Y being the
          y-coordinate of the edge's from junction and X, the x-coordinate of
          the edge's to junction for a vertical tree.
          The notion of the from and to junctions above is relative to the tree
          direction; it has nothing to do with the real topology of the network
          feature edge."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyMainlineTreeLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, tree_direction, branches_placement, is_unit_absolute, perpendicular_absolute, perpendicular_proportional, along_absolute, along_proportional, disjoined_graph_absolute, disjoined_graph_proportional, are_edges_orthogonal, breakpoint_position), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyPartialOverlappingEdgesLayout_un', None)
def ApplyPartialOverlappingEdgesLayout(in_network_diagram_layer=None, buffer_width_absolute=None, offset_absolute=None, optimize_edges=None):
    """ApplyPartialOverlappingEdgesLayout_un(in_network_diagram_layer, buffer_width_absolute, offset_absolute, {optimize_edges})

        Spaces out collinear edges or collinear portions of edges (edge
        segments) inside a given buffer zone.If you have an open edit session,
        you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which to apply the layout.
      buffer_width_absolute (Linear Unit):
          The width of the buffer zones in which to search for collinear edge
          segments.
      offset_absolute (Linear Unit):
          The distance that will separate the detected edge segments.
      optimize_edges {Boolean}:
          How segments are placed along edges:

          *  OPTIMIZE_EDGES-The placement of segments is optimized in each set
          of collinear segments. This is done by focusing on their connections
          instead of their positions. Segments that cross each other have a
          chance to be repositioned so they do not cross.

          *  DO_NOT_OPTIMIZE_EDGES-The initial position of each segment is
          maintained in the collinear segment set and crossings are kept. This
          is the default option."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyPartialOverlappingEdgesLayout_un(*gp_fixargs((in_network_diagram_layer, buffer_width_absolute, offset_absolute, optimize_edges), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyRadialTreeLayout_un', None)
def ApplyRadialTreeLayout(in_network_diagram_layer=None, are_containers_preserved=None, is_unit_absolute=None, initial_radius_absolute=None, initial_radius_proportional=None, disjoined_graph_absolute=None, disjoined_graph_proportional=None, radius_factor=None):
    """ApplyRadialTreeLayout_un(in_network_diagram_layer, {are_containers_preserved}, {is_unit_absolute}, {initial_radius_absolute}, {initial_radius_proportional}, {disjoined_graph_absolute}, {disjoined_graph_proportional}, {radius_factor})

        Arranges diagram features hierarchically and places them in a radial
        tree.If you have an open edit session, you must save your edits prior
        to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which to apply the layout.
      are_containers_preserved {Boolean}:
          How containers will be processed by the algorithm:

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          non-content features in the diagram. This is the default.
      is_unit_absolute {Boolean}:
          How parameters representing distances will be interpreted:

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the diagram when it is generated. This is the
          default.
      initial_radius_absolute {Linear Unit}:
          The radius of the first concentric circle whose center is the radial
          tree root junction; that is, the radius of the circle around which the
          diagram junctions belonging to the first hierarchical level are
          placed. The default is 5 in the units of the diagram's coordinate
          system. This parameter is required when using absolute units.
      initial_radius_proportional {Double}:
          The radius of the first concentric circle whose center is the radial
          tree root junction; that is, the radius of the circle around which the
          diagram junctions belonging to the first hierarchical level are
          placed. The default is 5. This parameter is required when using
          proportional units.
      disjoined_graph_absolute {Linear Unit}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using absolute units. The default is 4 in the units
          of the diagram's coordinate system.
      disjoined_graph_proportional {Double}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using proportional units. The default is 4.
      radius_factor {Double}:
          Represents the multiplicative factor used to increase or decrease the
          radius of each concentric circle. It also represents the distance that
          separates each concentric circle related to a hierarchical level. When
          using a radius factor less than 1, the distance that separates the
          diagram junctions belonging to the (n) hierarchical level and the
          (n+1) hierarchical level progressively decreases. With a factor
          greater than 1, the distance between the hierarchical levels increases
          progressively. The default is 1."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyRadialTreeLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, is_unit_absolute, initial_radius_absolute, initial_radius_proportional, disjoined_graph_absolute, disjoined_graph_proportional, radius_factor), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyRotateTreeLayout_un', None)
def ApplyRotateTreeLayout(in_network_diagram_layer=None, are_containers_preserved=None, rotation_angle=None):
    """ApplyRotateTreeLayout_un(in_network_diagram_layer, {are_containers_preserved}, {rotation_angle})

        Rotates the tree or trees related to pivot junctions currently set up
        in that diagram to the specified angle.If you have an open edit
        session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which to apply the layout.
      are_containers_preserved {Boolean}:
          How containers will be processed by the algorithm:

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          non-content features in the diagram. This is the default.
      rotation_angle {Double}:
          The angle in degrees that will be used to rotate the tree. The default
          is 45 degrees."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyRotateTreeLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, rotation_angle), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplySmartTreeLayout_un', None)
def ApplySmartTreeLayout(in_network_diagram_layer=None, are_containers_preserved=None, tree_direction=None, is_unit_absolute=None, subtree_absolute=None, subtree_proportional=None, perpendicular_absolute=None, perpendicular_proportional=None, along_absolute=None, along_proportional=None, disjoined_graph_absolute=None, disjoined_graph_proportional=None, are_edges_orthogonal=None, breakpoint_position=None):
    """ApplySmartTreeLayout_un(in_network_diagram_layer, {are_containers_preserved}, {tree_direction}, {is_unit_absolute}, {subtree_absolute}, {subtree_proportional}, {perpendicular_absolute}, {perpendicular_proportional}, {along_absolute}, {along_proportional}, {disjoined_graph_absolute}, {disjoined_graph_proportional}, {are_edges_orthogonal}, {breakpoint_position})

        Arranges diagram features hierarchically and places them in a smart
        tree.If you have an open edit session, you must save your edits prior
        to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which to apply the layout.
      are_containers_preserved {Boolean}:
          How containers will be processed by the algorithm:

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          non-content features in the diagram. This is the default.
      tree_direction {String}:
          The direction of the tree.

          * FROM_LEFT_TO_RIGHT-The tree will be drawn from the left to the
          right. This is the default.

          * FROM_RIGHT_TO_LEFT-The tree will be drawn from the right to the
          left.

          * FROM_BOTTOM_TO_TOP-The tree will be drawn from the bottom to the
          top.

          * FROM_TOP_TO_BOTTOM-The tree will be drawn from the top to the
          bottom.
      is_unit_absolute {Boolean}:
          How parameters representing distances will be interpreted:

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the diagram when it is generated. This is the
          default.
      subtree_absolute {Linear Unit}:
          It determines the spacing between two neighboring subtrees; that is,
          the spacing between diagram junctions that are displayed
          perpendicularly to the smart tree direction and belong to a different
          subtree. The default is in the units of the diagram's coordinate
          system. This parameter is required when using absolute units.
      subtree_proportional {Double}:
          It determines the spacing between two neighboring subtrees; that is,
          the spacing between diagram junctions that are displayed
          perpendicularly to the smart tree direction and belong to a different
          subtree. The default is 2. This parameter is required when using
          proportional units.
      perpendicular_absolute {Linear Unit}:
          This parameter is required when using absolute units. It specifies
          the spacing between diagram junctions that are displayed
          perpendicularly to the smart tree direction and belong to the same
          subtree level. The default is 2 in the units of the diagram's
          coordinate system. This parameter is required when using absolute
          units.
      perpendicular_proportional {Double}:
          It specifies the spacing between diagram junctions that are displayed
          perpendicularly to the smart tree direction and belong to the same
          subtree level. The default is 2. This parameter is required when using
          proportional units.
      along_absolute {Linear Unit}:
          It specifies the spacing between diagram junctions that are displayed
          along the smart tree direction. The default is 2 in the units of the
          diagram's coordinate system. This parameter is required when using
          absolute units.
      along_proportional {Double}:
          It specifies the spacing between diagram junctions that are displayed
          along the smart tree direction. The default is 2. This parameter is
          required when using proportional units.
      disjoined_graph_absolute {Linear Unit}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using absolute units. The default is 4 in the units
          of the diagram's coordinate system.
      disjoined_graph_proportional {Double}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using proportional units. The default is 4.
      are_edges_orthogonal {Boolean}:
          How diagram edges are related to the tree branches display:

          *  ORTHOGONAL_EDGES-All diagram edges related to the tree branches
          will display with right angles.

          *  SLANTED_EDGES-All diagram edges related to the tree branches do not
          display with right angles. This is the default.
      breakpoint_position {Double}:
          The relative position of the break point on the diagram edges. It is
          a percentage between 0 and 100-50, by default.

          * With a Break Point Relative Position (%) value of 0, the break point
          is positioned at the x-coordinate of the edge's from"junction and at
          the y-coordinate of the edge's to junction for a horizontal tree. It
          is positioned at the y-coordinate of the edge's from junction and at
          the x-coordinate of the edge's to junction for a vertical tree

          * With a Break Point Relative Position (%) value of 100, there is no
          break point inserted on the diagram edges; each diagram edge directly
          connects its from and to junctions.

          * With a Break Point Relative Position (%) value of N between 0 and
          100, the break point is positioned at N% of the length of the [XY]
          segment, X being the x-coordinate of the edge's from junction and Y,
          the y-coordinate of the edge's to junction for an horizontal tree. It
          is positioned at N% of the length of the [YX] segment, Y being the
          y-coordinate of the edge's from junction and X, the x-coordinate of
          the edge's to junction for a vertical tree.
          The notion of the from and to junctions above is relative to the tree
          direction; it has nothing to do with the real topology of the network
          feature edge."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplySmartTreeLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, tree_direction, is_unit_absolute, subtree_absolute, subtree_proportional, perpendicular_absolute, perpendicular_proportional, along_absolute, along_proportional, disjoined_graph_absolute, disjoined_graph_proportional, are_edges_orthogonal, breakpoint_position), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplySpatialDispatchLayout_un', None)
def ApplySpatialDispatchLayout(in_network_diagram_layer=None, are_containers_preserved=None, iterations_number=None, maximum_shift_factor=None):
    """ApplySpatialDispatchLayout_un(in_network_diagram_layer, {are_containers_preserved}, {iterations_number}, {maximum_shift_factor})

        Separates diagram junctions that are visibly close to overlapping.If
        you have an open edit session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which to apply the layout.
      are_containers_preserved {Boolean}:
          How containers will be processed by the algorithm:

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          non-content features in the diagram. This is the default.
      iterations_number {Long}:
          The number of iterations to process. The default is 5.
      maximum_shift_factor {Double}:
          Increases the diagram junctions' displacement for junctions that are
          very close together. The larger the shift factor, the larger the
          separation between the diagram junctions that almost overlap. The
          default is 2."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplySpatialDispatchLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, iterations_number, maximum_shift_factor), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyTemplateLayouts_un', None)
def ApplyTemplateLayouts(in_network_diagram_layer=None):
    """ApplyTemplateLayouts_un(in_network_diagram_layer)

        Applies the list of layout algorithms currently configured for the
        diagram template to the input network diagram layer.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which to apply the layout."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyTemplateLayouts_un(*gp_fixargs((in_network_diagram_layer,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ReshapeDiagramEdgesLayout_un', None)
def ReshapeDiagramEdgesLayout(in_network_diagram_layer=None, are_containers_preserved=None, reshape_type=None, is_path_preserved=None, offset_between_segment_absolute=None, breakpoint_absolute=None, shift_between_edge_absolute=None, angle_threshold=None):
    """ReshapeDiagramEdgesLayout_un(in_network_diagram_layer, {are_containers_preserved}, {reshape_type}, {is_path_preserved}, {offset_between_segment_absolute}, {breakpoint_absolute}, {shift_between_edge_absolute}, {angle_threshold})

        Processes simple operations on vertices along edges.If you have an
        open edit session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which to apply the layout.
      are_containers_preserved {Boolean}:
          How containers will be processed by the algorithm:

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          non-content features in the diagram. This is the default.
      reshape_type {String}:
          How edges will be reshaped.

          * REMOVE_VERTICES-Removes all vertices along any edges in the diagram.

          * SQUARE_EDGES-Inserts vertices along diagram edges so these edges are
          displayed with right angles. This is the default.

          * SEPARATE_OVERLAPPING_EDGES-Separates edges that connect the same
          origin and extremity junctions when they are overlapping.

          * REDUCE_VERTICES_BY_ANGLE-Removes some or all vertices displayed
          along diagram edges according to the angle that separates the segments
          incident to those vertices.
      is_path_preserved {Boolean}:
          . Determines whether or not the vertices along the edges that are
          going to be squared will be preserved. This parameter is required when
          reshape_type parameter is set to SQUARE_EDGES

          *  PRESERVE_PATH-The direction of any edge will be taken into account
          and vertices along that edge will be treated in turn, from the first
          vertex to the last one. This is the default.

          * IGNORE_PATH-Vertices along the diagram edges will not be considered;
          the vertices will be removed during execution.
      offset_between_segment_absolute {Linear Unit}:
          The spacing that will separate parallel segments of squared edges
          incident to the same junction. The default is 5 in the units of the
          diagram's coordinate system. This parameter is required when setting
          reshape_type to SQUARE_EDGES.
      breakpoint_absolute {Linear Unit}:
          The maximum distance between each junction to the 1st or last break
          point along edges incident to that junction when those edges are
          squared. The default is 8.66 in the units of the diagram's coordinate
          system. This parameter is required when setting reshape_type to
          SQUARE_EDGES.
      shift_between_edge_absolute {Linear Unit}:
          It specifies the absolute spacing that will separate two edges. The
          default is 0.5 in the units of the diagram's coordinate system. This
          parameter is required when setting reshape_type to
          SEPARATE_OVERLAPPING_EDGES.
      angle_threshold {Double}:
          It specifies the angle formed by the incident segments over which the
          vertex related to these segments is reduced. The wider the angle, the
          fewer vertices are reduced. The default is 160 degrees. This parameter
          is required when setting reshape_type to REDUCE_VERTICES_BY_ANGLE."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ReshapeDiagramEdgesLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, reshape_type, is_path_preserved, offset_between_segment_absolute, breakpoint_absolute, shift_between_edge_absolute, angle_threshold), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject